/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
import java.awt.*;
import java.util.*;
import javax.swing.*;
import org.pdbj.viewer.gui.*;

/**
 * Application entry class.
 */
public class jV
{
    /**
     * Application entry point.
     */
    public static void main(String[] args)
    {
        CommandLineArgs commandLineArgs = parseArgs(args);
        String[] initCommands = commandLineArgs.getInitCommands();
        boolean stdin = commandLineArgs.getStdin();

        ViewerFrame frame = new ViewerFrame(initCommands, stdin);

        frame.validate();

        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        int maxHeight = (int)(0.9f*screenSize.height);
        int maxWidth = (int)(0.9f*screenSize.width);
        int maxSize = (maxHeight < maxWidth) ? maxHeight : maxWidth;
        
        Dimension frameSize = frame.getSize();
        if(frameSize.height>maxSize || frameSize.width>maxSize){
            frameSize.height = maxSize;
            frameSize.width = maxSize;
            frame.setSize(frameSize);
        }
        
        frame.setLocation(
            (screenSize.width - frameSize.width)/2,
            (screenSize.height - frameSize.height)/2 );

        // start
        if( frame.graphicsReady() )
        {
            frame.setVisible(true);
        }
        else
        {
            JOptionPane.showMessageDialog(
                frame, 
                "Cannot find JOGL",
                "Error", 
                JOptionPane.ERROR_MESSAGE
            );

            frame.dispose();
            System.exit(0);
        }
    }

    //--------------------------------------------------------------------
    // Parse commandline arguments
    //--------------------------------------------------------------------
    private static CommandLineArgs parseArgs(String[] args)
    {
        ArrayList list = new ArrayList();
        String type = null;    
        String scriptCommand = null;
        boolean stdin = false;
        
        for(int i=0; i<args.length; i++)
        {
            String curr = args[i].toLowerCase();
            if( curr.equals("-pdbml") )          type = "pdbml";
            else if( curr.equals("-pdb") )       type = "pdb";
            else if( curr.equals("-polygon") )   type = "polygon";
            else if( curr.equals("-animation") ) type = "animation";
            else if( curr.equals("-ftp") )       type = "ftp";
            else if( curr.equals("-script") )    type = "script";
            else if( curr.equals("-stdin") )
            {
                stdin = true;
            }
            else if(type != null)
            {
                if(type.equals("script")){
                    if(scriptCommand == null){
                        scriptCommand = "script " + args[i];
                    }
                }
                else{
                    list.add("load " + type + " " + args[i]);
                }
            }
        }

        if(scriptCommand != null){
            list.add(scriptCommand);
        }

        String[] initCommands = (String[])list.toArray( new String[0] );
        CommandLineArgs commandLineArgs = new CommandLineArgs();
        commandLineArgs.setInitCommands(initCommands);
        commandLineArgs.setStdin(stdin);
        return commandLineArgs;
    }
}
