/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.commands;

/**
 * Animation controller.
 */
public interface AnimationController
{
    public static final int MIN_SPEED = 1;
    public static final int MAX_SPEED = 20;

    /**
     * Starts animation.
     */
    public void start(boolean reverse);

    /**
     * Stops animation.
     */
    public void stop();

    /**
     * Moves frmae.
     */
    public void move(int frame, boolean reverse);

    /**
     * Selects files.
     */
    public boolean select(int[] fileIds);

    /**
     * Changes selection status.
     */
    public boolean select(boolean enable, int[] fileIds);

    /**
     * Sets 'once' mode.
     */
    public void setOnceMode();

    /**
     * Sets 'loop' mode.
     */
    public void setLoopMode();

    /**
     * Sets 'swing' mode.
     */
    public void setSwingMode();

    /**
     * Sets animation speed.
     */
    public void setSpeed(int speed);

    /**
     * Sets the step for all files.
     */
    public void setStep(int step);

    /**
     * Sets the step for the specified file.
     */
    public boolean setStep(int step, int fileId);

    /**
     * Sets the frame for all files.
     */
    public void setFrame(int frame);

    /**
     * Sets the frame for the specified file.
     */
    public boolean setFrame(int frame, int fileId);

    /**
     * Sets the range for all files.
     */
    public void setRange(int init, int term);

    /**
     * Sets the range for the specified file.
     */
    public boolean setRange(int init, int term, int fileId);
}
