/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.commands;

/**
 * Command list.
 */
public abstract class CommandList
{
    public static final String[] ROOT             = new String[]{""};
    public static final String[] HELP             = new String[]{"help"};

    public static final String[] ADD_BACKBONE     = new String[]{"add_backbone"};
    public static final String[] ANIM             = new String[]{"anim"};
    public static final String[] ANIM_FORWARD     = new String[]{"forward"};
    public static final String[] ANIM_BACKWARD    = new String[]{"backward"};
    public static final String[] ANIM_STOP        = new String[]{"stop"};
    public static final String[] ANIMFRAME        = new String[]{"animframe"};
    public static final String[] ANIMSELECT       = new String[]{"animselect"};
    public static final String[] ANIMMODE         = new String[]{"animmode"};
    public static final String[] ANIMMODE_ONCE    = new String[]{"once"};
    public static final String[] ANIMMODE_LOOP    = new String[]{"loop"};
    public static final String[] ANIMMODE_SWING   = new String[]{"swing"};
    public static final String[] ANIMRANGE        = new String[]{"animrange"};
    public static final String[] ANIMSPEED        = new String[]{"animspeed"};
    public static final String[] ANIMSTEP         = new String[]{"animstep"};
    
    public static final String[] BACKBONE         = new String[]{"backbone"};
    public static final String[] BACKGROUND       = new String[]{"background"};
    public static final String[] BALL_AND_STICK   = new String[]{"ball_and_stick"};
    public static final String[] CARTOON          = new String[]{"cartoon", "cartoons"};
    public static final String[] CENTER           = new String[]{"center", "centre"};
    public static final String[] COLOR            = new String[]{"color", "colour"};
    public static final String[] COLORVERTEX      = new String[]{"colorvertex", "colourvertex"};
    public static final String[] CPK              = new String[]{"cpk"};
    public static final String[] DEFINE           = new String[]{"define"};
    public static final String[] DISPLAY          = new String[]{"display"};
    public static final String[] DISPLAYATOM      = new String[]{"displayatom"};
    public static final String[] DISPLAYVERTEX    = new String[]{"displayvertex"};
    public static final String[] ECHO             = new String[]{"echo"};
    public static final String[] EXIT             = new String[]{"exit"};
    public static final String[] FSELECT          = new String[]{"fselect"};
    public static final String[] FIT              = new String[]{"fit"};
    public static final String[] HBOND            = new String[]{"hbonds", "hbond"};
    public static final String[] LOAD             = new String[]{"load"};
    public static final String[] LOAD_EFSITE      = new String[]{"efsite"};
    public static final String[] LOAD_PDBML       = new String[]{"pdbml"};
    public static final String[] LOAD_PDB         = new String[]{"pdb"};
    public static final String[] LOAD_POLYGON     = new String[]{"polygon"};
    public static final String[] LOAD_POLYGON_CGO = new String[]{"polygon_cgo"};
    public static final String[] LOAD_ANIMATION   = new String[]{"animation"};
    public static final String[] LOAD_FTP         = new String[]{"ftp"};
    public static final String[] PAUSE            = new String[]{"pause"};
    public static final String[] PDBJ_DESCRIBE    = new String[]{"pdbj_describe"};
    public static final String[] PDBJ_EXECUTE     = new String[]{"pdbj_execute"};
    public static final String[] QUIT             = new String[]{"quit"};
    public static final String[] REFRESH          = new String[]{"refresh"};

    public static final String[] RESET                       = new String[]{"reset"};
    public static final String[] RESET_DEFAULT               = new String[]{""};
    public static final String[] RESET_CARTOON               = new String[]{"cartoon", "cartoons"};
    public static final String[] RESET_TRANSPARENCY          = new String[]{"transparency"};
    public static final String[] RESET_POINT_TRANSPARENCY    = new String[]{"point_transparency"};
    public static final String[] RESET_LINE_TRANSPARENCY     = new String[]{"line_transparency"};
    public static final String[] RESET_TRIANGLE_TRANSPARENCY = new String[]{"triangle_transparency"};
    public static final String[] RESET_QUAD_TRANSPARENCY     = new String[]{"quad_transparency"};
    public static final String[] RESET_POLYLINE_TRANSPARENCY = new String[]{"polyline_transparency"};
    public static final String[] RESET_POINT_SIZE            = new String[]{"point_size"};
    public static final String[] RESET_LINE_WIDTH            = new String[]{"line_width"};
    public static final String[] RESET_POLYLINE_WIDTH        = new String[]{"polyline_width"};
    public static final String[] RESET_PICKRADIUS            = new String[]{"pickradius"};

    public static final String[] RIBBON           = new String[]{"ribbons", "ribbon"};
    public static final String[] ROTATE           = new String[]{"rotate"};
    public static final String[] ROTATE_X         = new String[]{"x"};
    public static final String[] ROTATE_Y         = new String[]{"y"};
    public static final String[] ROTATE_Z         = new String[]{"z"};
    public static final String[] SAVE             = new String[]{"save"};
    public static final String[] SAVE_PDB         = new String[]{"pdb"};
    public static final String[] SAVE_SCRIPT      = new String[]{"script"};
    public static final String[] SAVE_PNG         = new String[]{"png"};
    public static final String[] SAVE_JPEG        = new String[]{"jpeg"};
    public static final String[] SCRIPT           = new String[]{"script"};
    public static final String[] SELECT           = new String[]{"select"};
    public static final String[] SELECTVERTEX     = new String[]{"selectvertex"};

    public static final String[] SET                        = new String[]{"set"};
    public static final String[] SET_ADJUSTVIEW             = new String[]{"adjustview"};
    public static final String[] SET_ADJUSTVIEW_ON          = new String[]{"on", "true"};
    public static final String[] SET_ADJUSTVIEW_OFF         = new String[]{"off", "false"};
    public static final String[] SET_AMBIENT                = new String[]{"ambient"};
    public static final String[] SET_BACKGROUND             = new String[]{"background"};
    public static final String[] SET_BONDMODE               = new String[]{"bondmode"};
    public static final String[] SET_BONDMODE_AND           = new String[]{"and"};
    public static final String[] SET_BONDMODE_OR            = new String[]{"or"};
    public static final String[] SET_CARTOON                = new String[]{"cartoon", "cartoons"};
    public static final String[] SET_CARTOON_LOOP_TUBE      = new String[]{"cartoon_loop_tube"};
    public static final String[] SET_CARTOON_LOOP_TUBE_ON   = new String[]{"on", "true"};
    public static final String[] SET_CARTOON_LOOP_TUBE_OFF  = new String[]{"off", "false"};
    public static final String[] SET_CARTOON_ROUND          = new String[]{"cartoon_round"};
    public static final String[] SET_CARTOON_ROUND_ON       = new String[]{"on", "true"};
    public static final String[] SET_CARTOON_ROUND_OFF      = new String[]{"off", "false"};
    public static final String[] SET_CENTER                 = new String[]{"center", "centre"};
    public static final String[] SET_DIFFUSE1               = new String[]{"diffuse1"};
    public static final String[] SET_DIFFUSE2               = new String[]{"diffuse2"};
    public static final String[] SET_DIFFUSE1_DIRECTION     = new String[]{"diffuse1_direction"};
    public static final String[] SET_DIFFUSE2_DIRECTION     = new String[]{"diffuse2_direction"};
    public static final String[] SET_DRAWLEVEL              = new String[]{"drawlevel"};
    public static final String[] SET_EFSITE_URL             = new String[]{"efsite_url"};
    public static final String[] SET_EXT_SITE_URL           = new String[]{"ext_site_url"};
    public static final String[] SET_HBOND                  = new String[]{"hbonds", "hbond"};
    public static final String[] SET_HBOND_BACKBONE         = new String[]{"backbone", "mainchain"};
    public static final String[] SET_HBOND_SIDECHAIN        = new String[]{"sidechain"};
    public static final String[] SET_HETERO                 = new String[]{"hetero"};
    public static final String[] SET_HETERO_ON              = new String[]{"on", "true"};
    public static final String[] SET_HETERO_OFF             = new String[]{"off", "false"};
    public static final String[] SET_HYDROGEN               = new String[]{"hydrogen"};
    public static final String[] SET_HYDROGEN_ON            = new String[]{"on", "true"};
    public static final String[] SET_HYDROGEN_OFF           = new String[]{"off", "false"};
    public static final String[] SET_IMAGESIZE              = new String[]{"imagesize"};
    public static final String[] SET_LOADCENTER             = new String[]{"loadcenter"};
    public static final String[] SET_LOADCENTER_ON          = new String[]{"on", "true"};
    public static final String[] SET_LOADCENTER_OFF         = new String[]{"off", "false"};
    public static final String[] SET_PDBML_NOATOM_URL       = new String[]{"pdbml_noatom_url"};
    public static final String[] SET_PDBML_EXTATOM_URL      = new String[]{"pdbml_extatom_url"};
    public static final String[] SET_PDBML_PLUS_URL         = new String[]{"pdbml_plus_url"};
    public static final String[] SET_PICKING                = new String[]{"picking"};
    public static final String[] SET_PICK_OFF               = new String[]{"off", "false"};
    public static final String[] SET_PICK_IDENT             = new String[]{"ident", "id"};
    public static final String[] SET_PICK_COORD             = new String[]{"coord", "coordinates"};
    public static final String[] SET_PICK_DISTANCE          = new String[]{"distance"};
    public static final String[] SET_PICK_CENTER            = new String[]{"center", "centre"};
    public static final String[] SET_PICK_SELECT            = new String[]{"select"};
    public static final String[] SET_PICKRADIUS             = new String[]{"pickradius"};
    public static final String[] SET_PROJECTION             = new String[]{"projection"};
    public static final String[] SET_PROJECTION_PERSPECTIVE = new String[]{"perspective"};
    public static final String[] SET_PROJECTION_PARALLEL    = new String[]{"parallel"};
    public static final String[] SET_RIBBONBACK             = new String[]{"ribbonback", "cartoonback"};
    public static final String[] SET_SPECPOWER              = new String[]{"specpower"};
    public static final String[] SET_SPECULAR               = new String[]{"specular"};
    public static final String[] SET_SSBOND                 = new String[]{"ssbonds", "ssbond"};
    public static final String[] SET_SSBOND_BACKBONE        = new String[]{"backbone", "mainchain"};
    public static final String[] SET_SSBOND_SIDECHAIN       = new String[]{"sidechain"};
    public static final String[] SET_STEREO                 = new String[]{"stereo"};
    public static final String[] SET_TRANSPARENCY           = new String[]{"transparency"};
    public static final String[] SET_POINT_TRANSPARENCY     = new String[]{"point_transparency"};
    public static final String[] SET_LINE_TRANSPARENCY      = new String[]{"line_transparency"};
    public static final String[] SET_TRIANGLE_TRANSPARENCY  = new String[]{"triangle_transparency"};
    public static final String[] SET_QUAD_TRANSPARENCY      = new String[]{"quad_transparency"};
    public static final String[] SET_POLYLINE_TRANSPARENCY  = new String[]{"polyline_transparency"};
    public static final String[] SET_POINT_SIZE             = new String[]{"point_size"};
    public static final String[] SET_LINE_WIDTH             = new String[]{"line_width"};
    public static final String[] SET_POLYLINE_WIDTH         = new String[]{"polyline_width"};
    public static final String[] SET_VIEWPOINT              = new String[]{"viewpoint"};

    public static final String[] SHOW             = new String[]{"show"};
    public static final String[] SHOW_EFSITE_URL  = new String[]{"efsite_url"};
    public static final String[] SHOW_EXT_SITE_URL = new String[]{"ext_site_url"};
    public static final String[] SHOW_GODATA      = new String[]{"godata"};
    public static final String[] SHOW_IMAGESIZE   = new String[]{"imagesize"};
    public static final String[] SHOW_INFORMATION = new String[]{"information"};
    public static final String[] SHOW_PDBML_URL   = new String[]{"pdbml_url"};
    public static final String[] SHOW_SITE        = new String[]{"site"};
    public static final String[] SHOW_TRANSFORM   = new String[]{"transform"};
    public static final String[] SHOW_VIEWPOINT   = new String[]{"viewpoint"};
    public static final String[] SHOW_XPS3        = new String[]{"pdbj", "xps3"};
    public static final String[] SLAB             = new String[]{"slab"};
    public static final String[] SPACEFILL        = new String[]{"spacefill"};
    public static final String[] SSBOND           = new String[]{"ssbonds", "ssbond"};
    public static final String[] STEREO           = new String[]{"stereo"};
    public static final String[] STRUCTURE        = new String[]{"structure"};
    public static final String[] TRACE            = new String[]{"trace"};
    public static final String[] TRANSLATE        = new String[]{"translate"};
    public static final String[] TRANSLATE_X      = new String[]{"x"};
    public static final String[] TRANSLATE_Y      = new String[]{"y"};
    public static final String[] TRANSLATE_Z      = new String[]{"z"};
    public static final String[] WIREFRAME        = new String[]{"wireframe"};
    public static final String[] WRITE            = new String[]{"write"};
    public static final String[] ZAP              = new String[]{"zap"};
    public static final String[] ZOOM             = new String[]{"zoom"};
}
