/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.commands;

/**
 * Tokenizes command expression.
 */
public class CommandTokenizer
{
    private String   _command;
    private String[] _tokens;
    private int[]    _positions;

    private boolean _endsWithSpace;

    private int _index;

    /**
    * Returns the command.
    */
    public String getCommand()
    {
        return _command;
    }

    /**
    * Returns the current position.
    */
    public int getPosition()
    {
        return this.hasMoreTokens() ? _positions[_index] : -1;
    }

    /**
    * Tests whether the command ends with space.
    */
    public boolean endsWithSpace()
    {
        return _endsWithSpace;
    }

    /**
    * Constructor.
    */
    public CommandTokenizer(String command)
    {
        _command = (command == null) ? "" : command;

        this.setup();
        this.reset();
    }

    /**
    * Returns the number of tokens left.
    */
    public int countTokens()
    {
        return _tokens.length - _index;
    }

    /**
    * Tests whether there exist more tokens.
    */
    public boolean hasMoreTokens()
    {
        return (_index != _tokens.length);
    }

    /**
    * Returns the next token.
    */
    public String nextToken()
    {
        return _tokens[_index++];
    }

    /**
    * Reset.
    */
    public void reset()
    {
        _index = 0;
    }

    /**
    * Moves to the previous token.
    */
    public boolean movePrevious()
    {
        if(_index > 0){
            _index--;
            return true;
        }
        else return false;
    }

    //--------------------------------------------------------------------
    // Set up
    //--------------------------------------------------------------------
    private void setup()
    {
        int len = _command.length();

        int num = 0;
        boolean space = true;
        for(int pos=0; pos<len; pos++){
            if( _command.charAt(pos) != ' ' ){
                if(space) num++;
                space = false;
            }
            else space = true;
        }
        if(space){
            _endsWithSpace = true;
            num++;
        }

        _tokens = new String[num];
        _positions = new int[num];

        int cnt = 0;
        space = true;
        for(int pos=0; pos<len; pos++){
            if( _command.charAt(pos) != ' ' ){
                if(space){
                    _positions[cnt] = pos;
                }
                space = false;
            }
            else{
                if(!space){
                    _tokens[cnt] = _command.substring(_positions[cnt], pos);
                    cnt++;
                }
                space = true;
            }
        }
        if(space){
            _positions[cnt] = len;
            _tokens[cnt] = "";
        }
        else{
            _tokens[cnt] = _command.substring(_positions[cnt], len);
        }
    }
}
