/*
 * Modified at March 2014.
 * RIKEN, Japan
 */

/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.commands;

import java.util.*;

/**
 * Command tree.
 */
public class CommandTree extends CommandList
{
    /**
     * Creates root command.
     */
    public static Command createRoot()
    {
        Command root = new Command(CommandList.ROOT);
        HelpCommand help = new HelpCommand(CommandList.HELP);
        
        ArrayList list = new ArrayList();
        
        list.add( create(CommandList.ADD_BACKBONE) );
        //list.add( create(CommandList.ANIM) );
        //list.add( create(CommandList.ANIMFRAME) );
        //list.add( create(CommandList.ANIMSELECT) );
        //list.add( create(CommandList.ANIMMODE) );
        //list.add( create(CommandList.ANIMRANGE) );
        //list.add( create(CommandList.ANIMSPEED) );
        //list.add( create(CommandList.ANIMSTEP) );        
        list.add( create(CommandList.BACKBONE) );
        list.add( create(CommandList.BACKGROUND) );
        list.add( create(CommandList.BALL_AND_STICK) );
        list.add( create(CommandList.CARTOON) );
        list.add( create(CommandList.CENTER) );
        list.add( create(CommandList.COLOR) );
        //list.add( create(CommandList.COLORVERTEX) );
        list.add( create(CommandList.CPK) );
        list.add( create(CommandList.DEFINE) );
        //list.add( create(CommandList.DISPLAY) );
        list.add( create(CommandList.DISPLAYATOM) );
        //list.add( create(CommandList.DISPLAYVERTEX) );
        list.add( create(CommandList.ECHO) );
        list.add( create(CommandList.EXIT) );
        //list.add( create(CommandList.FIT) );
        //list.add( create(CommandList.FSELECT) );
        list.add( create(CommandList.HBOND) );
        //list.add( create(CommandList.LOAD) );
        //list.add( create(CommandList.PAUSE) );
        //list.add( create(CommandList.PDBJ_DESCRIBE) );
        //list.add( create(CommandList.PDBJ_EXECUTE) );
        list.add( create(CommandList.QUIT) );
        list.add( create(CommandList.REFRESH) );
        list.add( create(CommandList.RESET) );
        list.add( create(CommandList.RIBBON) );
        list.add( create(CommandList.ROTATE) );
        list.add( create(CommandList.SAVE) );
        list.add( create(CommandList.SCRIPT) );
        list.add( create(CommandList.SELECT) );
        //list.add( create(CommandList.SELECTVERTEX) );
        list.add( create(CommandList.SET) );
        list.add( create(CommandList.SHOW) );
        list.add( create(CommandList.SLAB) );
        list.add( create(CommandList.SPACEFILL) );
        list.add( create(CommandList.SSBOND) );
        //list.add( create(CommandList.STEREO) );
        list.add( create(CommandList.STRUCTURE) );
        list.add( create(CommandList.TRACE) );
        list.add( create(CommandList.TRANSLATE) );
        list.add( create(CommandList.WIREFRAME) );
        list.add( create(CommandList.WRITE) );
        //list.add( create(CommandList.ZAP) );
        list.add( create(CommandList.ZOOM) );

        for(int i=0; i<list.size(); i++){
            Command command = (Command)list.get(i);
            root.addChild(command);
            help.addChild(command);
        }

        help.addChild( new HelpCommand(CommandList.HELP) );
        root.addChild(help);
        
        root.requiresPreExecute = true;

        return root;
    }

    private static Command create(String[] names)
    {
        Command command = new Command(names);
        
        if(names == ANIM)
        {
            command.addChild( create(CommandList.ANIM_FORWARD) );
            command.addChild( create(CommandList.ANIM_BACKWARD) );
            command.addChild( create(CommandList.ANIM_STOP) );
        }
        else if(names == ANIMMODE)
        {
            command.addChild( create(CommandList.ANIMMODE_ONCE) );
            command.addChild( create(CommandList.ANIMMODE_LOOP) );
            command.addChild( create(CommandList.ANIMMODE_SWING) );
        }
        else if(names == LOAD)
        {
            command.addChild( create(CommandList.LOAD_PDBML) );
            command.addChild( create(CommandList.LOAD_PDB) );
            command.addChild( create(CommandList.LOAD_POLYGON) );
            command.addChild( create(CommandList.LOAD_POLYGON_CGO) );
            command.addChild( create(CommandList.LOAD_ANIMATION) );
            command.addChild( create(CommandList.LOAD_FTP) );
            command.addChild( create(CommandList.LOAD_EFSITE) );
            
            command.setDefault( command.getChild(0) );
        }
        else if(names == RESET)
        {
            command.addChild( create(CommandList.RESET_DEFAULT) );
            command.addChild( create(CommandList.RESET_CARTOON) );
            //command.addChild( create(CommandList.RESET_TRANSPARENCY) );
            //command.addChild( create(CommandList.RESET_POINT_TRANSPARENCY) );
            //command.addChild( create(CommandList.RESET_LINE_TRANSPARENCY) );
            //command.addChild( create(CommandList.RESET_TRIANGLE_TRANSPARENCY) );
            //command.addChild( create(CommandList.RESET_QUAD_TRANSPARENCY) );
            //command.addChild( create(CommandList.RESET_POLYLINE_TRANSPARENCY) );
            //command.addChild( create(CommandList.RESET_POINT_SIZE) );
            //command.addChild( create(CommandList.RESET_LINE_WIDTH) );
            //command.addChild( create(CommandList.RESET_POLYLINE_WIDTH) );
            command.addChild( create(CommandList.RESET_PICKRADIUS) );
            
            command.setDefault( command.getChild(0) );
        }
        else if(names == ROTATE)
        {
            command.addChild( create(CommandList.ROTATE_X) );
            command.addChild( create(CommandList.ROTATE_Y) );
            command.addChild( create(CommandList.ROTATE_Z) );
        }
        else if(names == SAVE || names == WRITE)
        {
            //command.addChild( create(CommandList.SAVE_PDB) );
            //command.addChild( create(CommandList.SAVE_SCRIPT) );
            command.addChild( create(CommandList.SAVE_PNG) );
            command.addChild( create(CommandList.SAVE_JPEG) );
            
            //command.setDefault( command.getChild(0) );
        }
        else if(names == SET)
        {
            command.addChild( create(CommandList.SET_ADJUSTVIEW) );
            command.addChild( create(CommandList.SET_AMBIENT) );
            command.addChild( create(CommandList.SET_BACKGROUND) );
            command.addChild( create(CommandList.SET_BONDMODE) );
            command.addChild( create(CommandList.SET_CARTOON) );
            command.addChild( create(CommandList.SET_CARTOON_LOOP_TUBE) );
            command.addChild( create(CommandList.SET_CARTOON_ROUND) );
            command.addChild( create(CommandList.SET_CENTER) );
            command.addChild( create(CommandList.SET_DIFFUSE1) );
            command.addChild( create(CommandList.SET_DIFFUSE2) );
            command.addChild( create(CommandList.SET_DIFFUSE1_DIRECTION) );
            command.addChild( create(CommandList.SET_DIFFUSE2_DIRECTION) );
            command.addChild( create(CommandList.SET_DRAWLEVEL) );
            //command.addChild( create(CommandList.SET_EFSITE_URL) );
            //command.addChild( create(CommandList.SET_EXT_SITE_URL) );
            command.addChild( create(CommandList.SET_HBOND) );
            command.addChild( create(CommandList.SET_HETERO) );
            command.addChild( create(CommandList.SET_HYDROGEN) );
            command.addChild( create(CommandList.SET_IMAGESIZE) );
            //command.addChild( create(CommandList.SET_LOADCENTER) );
            //command.addChild( create(CommandList.SET_PDBML_NOATOM_URL) );
            //command.addChild( create(CommandList.SET_PDBML_EXTATOM_URL) );
            //command.addChild( create(CommandList.SET_PDBML_PLUS_URL) );
            command.addChild( create(CommandList.SET_PICKING) );
            command.addChild( create(CommandList.SET_PICKRADIUS) );
            command.addChild( create(CommandList.SET_PROJECTION) );
            command.addChild( create(CommandList.SET_RIBBONBACK) );
            command.addChild( create(CommandList.SET_SPECPOWER) );
            command.addChild( create(CommandList.SET_SPECULAR) );
            command.addChild( create(CommandList.SET_SSBOND) );
            //command.addChild( create(CommandList.SET_STEREO) );
            //command.addChild( create(CommandList.SET_TRANSPARENCY) );
            //command.addChild( create(CommandList.SET_POINT_TRANSPARENCY) );
            //command.addChild( create(CommandList.SET_LINE_TRANSPARENCY) );
            //command.addChild( create(CommandList.SET_TRIANGLE_TRANSPARENCY) );
            //command.addChild( create(CommandList.SET_QUAD_TRANSPARENCY) );
            //command.addChild( create(CommandList.SET_POLYLINE_TRANSPARENCY) );
            //command.addChild( create(CommandList.SET_POINT_SIZE) );
            //command.addChild( create(CommandList.SET_LINE_WIDTH) );
            //command.addChild( create(CommandList.SET_POLYLINE_WIDTH) );
            command.addChild( create(CommandList.SET_VIEWPOINT) );
        }
        else if(names == SET_ADJUSTVIEW)
        {
            command.addChild( create(CommandList.SET_ADJUSTVIEW_ON) );
            command.addChild( create(CommandList.SET_ADJUSTVIEW_OFF) );
        }
        else if(names == SET_BONDMODE)
        {
            command.addChild( create(CommandList.SET_BONDMODE_AND) );
            command.addChild( create(CommandList.SET_BONDMODE_OR) );
        }
        else if(names == SET_CARTOON_LOOP_TUBE)
        {
            command.addChild( create(CommandList.SET_CARTOON_LOOP_TUBE_ON) );
            command.addChild( create(CommandList.SET_CARTOON_LOOP_TUBE_OFF) );
        }
        else if(names == SET_CARTOON_ROUND)
        {
            command.addChild( create(CommandList.SET_CARTOON_ROUND_ON) );
            command.addChild( create(CommandList.SET_CARTOON_ROUND_OFF) );
        }
        else if(names == SET_HBOND)
        {
            command.addChild( create(CommandList.SET_HBOND_BACKBONE) );
            command.addChild( create(CommandList.SET_HBOND_SIDECHAIN) );
        }
        else if(names == SET_HETERO)
        {
            command.addChild( create(CommandList.SET_HETERO_ON) );
            command.addChild( create(CommandList.SET_HETERO_OFF) );
        }
        else if(names == SET_HYDROGEN)
        {
            command.addChild( create(CommandList.SET_HYDROGEN_ON) );
            command.addChild( create(CommandList.SET_HYDROGEN_OFF) );
        }
        else if(names == SET_LOADCENTER)
        {
            command.addChild( create(CommandList.SET_LOADCENTER_ON) );
            command.addChild( create(CommandList.SET_LOADCENTER_OFF) );
        }
        else if(names == SET_PICKING)
        {
            command.addChild( create(CommandList.SET_PICK_OFF) );
            command.addChild( create(CommandList.SET_PICK_IDENT) );
            command.addChild( create(CommandList.SET_PICK_COORD) );
            command.addChild( create(CommandList.SET_PICK_DISTANCE) );
            command.addChild( create(CommandList.SET_PICK_CENTER) );
            command.addChild( create(CommandList.SET_PICK_SELECT) );
        }
        else if(names == SET_PROJECTION)
        {
            command.addChild( create(CommandList.SET_PROJECTION_PERSPECTIVE) );
            command.addChild( create(CommandList.SET_PROJECTION_PARALLEL) );
        }
        else if(names == SET_SSBOND)
        {
            command.addChild( create(CommandList.SET_SSBOND_BACKBONE) );
            command.addChild( create(CommandList.SET_SSBOND_SIDECHAIN) );
        }
        else if(names == SHOW)
        {
            //command.addChild( create(CommandList.SHOW_EFSITE_URL) );
            //command.addChild( create(CommandList.SHOW_EXT_SITE_URL) );
            //command.addChild( create(CommandList.SHOW_GODATA) );
            command.addChild( create(CommandList.SHOW_IMAGESIZE) );
            command.addChild( create(CommandList.SHOW_INFORMATION) );
            //command.addChild( create(CommandList.SHOW_PDBML_URL) );
            //command.addChild( create(CommandList.SHOW_SITE) );
            command.addChild( create(CommandList.SHOW_TRANSFORM) );
            command.addChild( create(CommandList.SHOW_VIEWPOINT) );
            //command.addChild( create(CommandList.SHOW_XPS3) );
        }
        else if(names == TRANSLATE)
        {
            command.addChild( create(CommandList.TRANSLATE_X) );
            command.addChild( create(CommandList.TRANSLATE_Y) );
            command.addChild( create(CommandList.TRANSLATE_Z) );
        }

        if( names == CPK ||
            names == QUIT ||
            names == SET_STEREO ||
            names == WRITE)
        {
            command.useUsage = true;
        }

        if( names == PDBJ_DESCRIBE || names == PDBJ_EXECUTE ||
            names == SELECT || names == SELECTVERTEX ||
            names == SHOW || names == SHOW_GODATA || names == SHOW_XPS3 ||
            names == SHOW_SITE )
        {
            command.requiresPreExecute = true;
        }

        return command;
    }
}
