/*
 * Modified at March 2014.
 * RIKEN, Japan
 */

/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.commands;

import org.pdbj.viewer.controller.*;

/**
 * Command usage.
 */
public class CommandUsage extends CommandList
{
    private static final int AXIS_X = 1;
    private static final int AXIS_Y = 2;
    private static final int AXIS_Z = 3;

    /**
     * Creates usage.
     */
    public static Usage[] create(Command command)
    {
        String[] names = command.getNames();
        
        if(names == HELP)                return help(command);
        else if(names == ADD_BACKBONE)   return addBackbone(command);
        else if(names == ANIM_FORWARD)   return animForward(command);
        else if(names == ANIM_BACKWARD)  return animBackward(command);
        else if(names == ANIM_STOP)      return animStop(command);
        else if(names == ANIMFRAME)      return animframe(command);
        else if(names == ANIMSELECT)     return animselect(command);
        else if(names == ANIMMODE_ONCE)  return animmodeOnce(command);
        else if(names == ANIMMODE_LOOP)  return animmodeLoop(command);
        else if(names == ANIMMODE_SWING) return animmodeSwing(command);
        else if(names == ANIMRANGE)      return animrange(command);
        else if(names == ANIMSPEED)      return animspeed(command);
        else if(names == ANIMSTEP)       return animstep(command);
        else if(names == BACKBONE)       return backbone(command);
        else if(names == BACKGROUND)     return background(command);
        else if(names == BALL_AND_STICK) return ballAndStick(command);
        else if(names == CARTOON)        return cartoon(command);
        else if(names == CENTER)         return center(command);
        else if(names == COLOR)          return color(command);
        else if(names == COLORVERTEX)    return colorvertex(command);
        else if(names == CPK)            return cpk(command);
        else if(names == DEFINE)         return define(command);
        else if(names == DISPLAY)        return display(command);
        else if(names == DISPLAYATOM)    return displayatom(command);
        else if(names == DISPLAYVERTEX)  return displayvertex(command);
        else if(names == ECHO)           return echo(command);
        else if(names == EXIT)           return exit(command);
        else if(names == FIT)            return fit(command);
        else if(names == FSELECT)        return fselect(command);
        else if(names == HBOND)          return hbond(command);
        else if(names == LOAD_EFSITE)    return loadEfsite(command);
        else if(names == LOAD_PDBML)     return loadPDBml(command);
        else if(names == LOAD_PDB)       return loadPDB(command);
        else if(names == LOAD_POLYGON)   return loadPolygon(command);
        else if(names == LOAD_POLYGON_CGO) return loadPolygonCgo(command);
        else if(names == LOAD_ANIMATION) return loadAnimation(command);
        else if(names == LOAD_FTP)       return loadFtp(command);
        else if(names == PAUSE)          return pause(command);
        else if(names == PDBJ_DESCRIBE)  return pdbjDescribe(command);
        else if(names == PDBJ_EXECUTE)   return pdbjExecute(command);
        else if(names == QUIT)           return quit(command);
        else if(names == REFRESH)        return refresh(command);
        else if(names == RESET_DEFAULT)  return reset(command);
        else if(names == RESET_CARTOON)  return resetCartoon(command);
        else if(names == RESET_TRANSPARENCY)          return resetTransparency(command); 
        else if(names == RESET_POINT_TRANSPARENCY)    return resetPointTransparency(command);
        else if(names == RESET_LINE_TRANSPARENCY)     return resetLineTransparency(command);
        else if(names == RESET_TRIANGLE_TRANSPARENCY) return resetTriangleTransparency(command);
        else if(names == RESET_QUAD_TRANSPARENCY)     return resetQuadTransparency(command);
        else if(names == RESET_POLYLINE_TRANSPARENCY) return resetPolylineTransparency(command);
        else if(names == RESET_POINT_SIZE)     return resetPointSize(command);
        else if(names == RESET_LINE_WIDTH)     return resetLineWidth(command);
        else if(names == RESET_POLYLINE_WIDTH) return resetPolylineWidth(command);
        else if(names == RESET_PICKRADIUS) return resetPickradius(command);
        else if(names == RIBBON)         return ribbon(command);
        else if(names == ROTATE_X)       return rotate(command, AXIS_X);
        else if(names == ROTATE_Y)       return rotate(command, AXIS_Y);
        else if(names == ROTATE_Z)       return rotate(command, AXIS_Z);
        else if(names == SAVE_PDB)       return savePDB(command);
        else if(names == SAVE_SCRIPT)    return saveScript(command);
        else if(names == SAVE_PNG)       return savePng(command);
        else if(names == SAVE_JPEG)      return saveJpeg(command);
        else if(names == SCRIPT)         return script(command);
        else if(names == SELECT)         return select(command);
        else if(names == SELECTVERTEX)   return selectvertex(command);
        else if(names == SET_ADJUSTVIEW_ON)          return setAdjustviewOn(command);
        else if(names == SET_ADJUSTVIEW_OFF)         return setAdjustviewOff(command);
        else if(names == SET_AMBIENT)                return setAmbient(command);
        else if(names == SET_BACKGROUND)             return setBackground(command);
        else if(names == SET_BONDMODE_AND)           return setBondmodeAnd(command);
        else if(names == SET_BONDMODE_OR)            return setBondmodeOr(command);
        else if(names == SET_CARTOON)                return setCartoon(command);
        else if(names == SET_CARTOON_LOOP_TUBE_ON)   return setCartoonLoopTubeOn(command);
        else if(names == SET_CARTOON_LOOP_TUBE_OFF)  return setCartoonLoopTubeOff(command);
        else if(names == SET_CARTOON_ROUND_ON)       return setCartoonRoundOn(command);
        else if(names == SET_CARTOON_ROUND_OFF)      return setCartoonRoundOff(command);
        else if(names == SET_CENTER)                 return setCenter(command);
        else if(names == SET_DIFFUSE1)               return setDiffuse1(command);
        else if(names == SET_DIFFUSE2)               return setDiffuse2(command);
        else if(names == SET_DIFFUSE1_DIRECTION)     return setDiffuse1Direction(command);
        else if(names == SET_DIFFUSE2_DIRECTION)     return setDiffuse2Direction(command);
        else if(names == SET_DRAWLEVEL)              return setDrawlevel(command);
        else if(names == SET_EFSITE_URL)             return setEfsiteUrl(command);
        else if(names == SET_EXT_SITE_URL)           return setExtSiteUrl(command);
        else if(names == SET_HBOND_BACKBONE)         return setHBondBackbone(command);
        else if(names == SET_HBOND_SIDECHAIN)        return setHBondSidechain(command);
        else if(names == SET_HETERO_ON)              return setHeteroOn(command);
        else if(names == SET_HETERO_OFF)             return setHeteroOff(command);
        else if(names == SET_HYDROGEN_ON)            return setHydrogenOn(command);
        else if(names == SET_HYDROGEN_OFF)           return setHydrogenOff(command);
        else if(names == SET_IMAGESIZE)              return setImagesize(command);
        else if(names == SET_LOADCENTER_ON)          return setLoadcenterOn(command);
        else if(names == SET_LOADCENTER_OFF)         return setLoadcenterOff(command);
        else if(names == SET_PICK_OFF)               return setPickOff(command);
        else if(names == SET_PICK_IDENT)             return setPickIdent(command);
        else if(names == SET_PICK_COORD)             return setPickCoord(command);
        else if(names == SET_PICK_DISTANCE)          return setPickDistance(command);
        else if(names == SET_PICK_CENTER)            return setPickCenter(command);
        else if(names == SET_PICK_SELECT)            return setPickSelect(command);
        else if(names == SET_PICKRADIUS)             return setPickradius(command);
        else if(names == SET_PDBML_NOATOM_URL)       return setPdbmlNoatomUrl(command);
        else if(names == SET_PDBML_EXTATOM_URL)      return setPdbmlExtatomUrl(command);
        else if(names == SET_PDBML_PLUS_URL)         return setPdbmlPlusUrl(command);
        else if(names == SET_PROJECTION_PERSPECTIVE) return setProjectionPerspective(command);
        else if(names == SET_PROJECTION_PARALLEL)    return setProjectionParallel(command);
        else if(names == SET_RIBBONBACK)             return setRibbonback(command);
        else if(names == SET_SPECPOWER)              return setSpecpower(command);
        else if(names == SET_SPECULAR)               return setSpecular(command);
        else if(names == SET_SSBOND_BACKBONE)        return setSSBondBackbone(command);
        else if(names == SET_SSBOND_SIDECHAIN)       return setSSBondSidechain(command);
        else if(names == SET_STEREO)                 return setStereo(command);
        else if(names == SET_TRANSPARENCY)           return setTransparency(command);
        else if(names == SET_POINT_TRANSPARENCY)     return setPointTransparency(command);
        else if(names == SET_LINE_TRANSPARENCY)      return setLineTransparency(command);
        else if(names == SET_TRIANGLE_TRANSPARENCY)  return setTriangleTransparency(command);
        else if(names == SET_QUAD_TRANSPARENCY)      return setQuadTransparency(command);
        else if(names == SET_POLYLINE_TRANSPARENCY)  return setPolylineTransparency(command);
        else if(names == SET_POINT_SIZE)             return setPointSize(command);
        else if(names == SET_LINE_WIDTH)             return setLineWidth(command);
        else if(names == SET_POLYLINE_WIDTH)         return setPolylineWidth(command);
        else if(names == SET_VIEWPOINT)              return setViewpoint(command);
        else if(names == SHOW_EFSITE_URL)  return showEfsiteUrl(command);
        else if(names == SHOW_EXT_SITE_URL) return showExtSiteUrl(command);
        else if(names == SHOW_GODATA)      return showGOData(command);
        else if(names == SHOW_IMAGESIZE)   return showImagesize(command);
        else if(names == SHOW_INFORMATION) return showInformation(command);
        else if(names == SHOW_PDBML_URL)   return showPdbmlUrl(command);
        else if(names == SHOW_SITE)        return showSite(command);
        else if(names == SHOW_TRANSFORM)   return showTransform(command);
        else if(names == SHOW_VIEWPOINT)   return showViewpoint(command);
        else if(names == SHOW_XPS3)        return showXps3(command);
        else if(names == SLAB)             return slab(command);
        else if(names == SPACEFILL)        return spacefill(command);
        else if(names == SSBOND)           return ssbond(command);
        else if(names == STEREO)           return stereo(command);
        else if(names == STRUCTURE)        return structure(command);
        else if(names == TRACE)            return trace(command);
        else if(names == TRANSLATE_X)      return translate(command, AXIS_X);
        else if(names == TRANSLATE_Y)      return translate(command, AXIS_Y);
        else if(names == TRANSLATE_Z)      return translate(command, AXIS_Z);
        else if(names == WIREFRAME)        return wireframe(command);
        else if(names == WRITE)            return write(command);
        else if(names == ZAP)              return zap(command);
        else if(names == ZOOM)             return zoom(command);
        
        return null;
    }
    
    private static Usage[] help(Command command)
    {
        return new Usage[]{
            new Usage("<command>", "Displays the usage of the command.")
        };
    }

    private static Usage[] addBackbone(Command command)
    {
        return new Usage[]{
            new Usage("{<residue_name> {<atom_names>}}", "Adds backbone atom names to predefined ones for the specified residue."
                + " The <atom_names> is a comma-delimited list of atom names."
                + " Omitting the <atom_names> means to reset the residue to the initial setting."
                + " When no arguments are given, the current settings are shown.")
        };
    }

    private static Usage[] animForward(Command command)
    {
        return new Usage[]{
            new Usage("{<value>}", "Starts animation forward."
                + " If the <value> is given, just move frames forward by the specified amount.")
        };
    }

    private static Usage[] animBackward(Command command)
    {
        return new Usage[]{
            new Usage("{<value>}", "Starts animation backward."
                + " If the <value> is given, just move frames backward by the specified amount.")
        };
    }

    private static Usage[] animStop(Command command)
    {
        return new Usage[]{
            new Usage("", "Stops animation.")
        };
    }

    private static Usage[] animframe(Command command)
    {
        return new Usage[]{
            new Usage("<frame> {<file_ID>}", "Sets the frame of all animation files for the specified value."
                + " When <file_ID> is given, only the specified file is processed.")
        };
    }

    private static Usage[] animselect(Command command)
    {
        return new Usage[]{
            new Usage("{-a/-r} <file_IDs>", "Selects the specified files and makes the others not selected."
                + " More than one file IDs can be specified by putting commas as the delimiter."
                + " When the option -a or -r is specified, only the selection status of the specified files are modified,"
                + " selected or not selected, respectively, and the others remain unchanged.")
        };
    }

    private static Usage[] animmodeOnce(Command command)
    {
        return new Usage[]{
            new Usage("", "Sets the behavior of animation for 'once'." +
                " When the frame reaches the last one, animation is stopped.")
        };
    }

    private static Usage[] animmodeLoop(Command command)
    {
        return new Usage[]{
            new Usage("", "Sets the behavior of animation for 'loop'." +
                " When the frame reaches the last one, animation is reset to the first frame and continues playing.")
        };
    }

    private static Usage[] animmodeSwing(Command command)
    {
        return new Usage[]{
            new Usage("", "Sets the behavior of animation for 'swing'." +
                " When the frame reaches the last one, the direction of animation is reversed.")
        };
    }

    private static Usage[] animrange(Command command)
    {
        return new Usage[]{
            new Usage("<init_frame>-<term_frame> {<file_ID>}", "Sets the range of all animation files."
                + " When <file_ID> is given, only the specified file is processed.")
        };
    }

    private static Usage[] animspeed(Command command)
    {
        return new Usage[]{
            new Usage("<speed>", "Sets the animation speed."
                + " The argument should be an integer value from " + AnimationController.MIN_SPEED
                + " to " + AnimationController.MAX_SPEED +".")
        };
    }

    private static Usage[] animstep(Command command)
    {
        return new Usage[]{
            new Usage("<step> {<file_ID>}", "Sets the step of all animation files for the specified value."
                + " When <file_ID> is given, only the specified file is processed.")
        };
    }

    private static Usage[] backbone(Command command)
    {
        return new Usage[]{
            new Usage("{on/true}", "Turns on the selected backbone bonds."),
            new Usage("off/false", "Turns off the selected backbone bonds."),
            new Usage("<radius>", "Turns on the selected backbone bonds with the specified raidus (angstrom or Rasmol unit)."
                + " The maximum parameter value is " + ViewerController.MAX_BOND_RADIUS + ".")
        };
    }

    private static Usage[] background(Command command)
    {
        return new Usage[]{
            new Usage("<color>", "Changes the background color."
                + " The color may be given as RGB values [r,g,b], or predefined color names.")
        };
    }

    private static Usage[] ballAndStick(Command command)
    {
        return new Usage[]{
            new Usage("{on/true}", "Turns on the ball and stick image of the selected atoms with ball radius 0.5 and stick radius 0.2 in angstrom."),
            new Usage("off/false", "Turns off the ball and stick image of the selected atoms."),
            new Usage("<ball_radius> <stick_radius>", "Turns on the ball and stick image of the selected atoms with the specified ball radius and stick radius (angstrom or Rasmol unit)."
                + " The maximum parameter value is " + ViewerController.MAX_BALL_RADIUS + " and " + ViewerController.MAX_BOND_RADIUS + ", respectively.")
        };
    }

    private static Usage[] cartoon(Command command)
    {
        return new Usage[]{
            new Usage("{on/true}", "Turns on the thick ribbons for the selected residues."
                + " When a chain does not have enough atoms to draw the ribbon model, a backbone will be shown instead."),
            new Usage("off/false", "Turns off the thick ribbons for the selected residues."),
            new Usage("<half_width>", "Turns on the thick ribbons for the selected residues with the specified half width (angstrom or Rasmol unit)."
                + " The maximum parameter value is " + ViewerController.MAX_RIBBON_WIDTH + ".")
        };
    }

    private static Usage[] center(Command command)
    {
        return new Usage[]{
            new Usage("{-r/-s} {<atom_expression>}", 
                "Sets the center of rotation and the center of the screen to the center of a group of atoms specified by the atom expression."
                + " When the option -r or -s is specified, only the center of rotation or the center of the screen is modified, respectively."),
            new Usage("{-r} [x, y, z]", "Moves the center of rotation and the center of the screen from the current position by the specified amount."
                + " When the option -r is specified, only the center of rotation is modified."),
            new Usage("{-r} {x, y, z}", "Sets the center of rotation and the center of the screen to the specified coordinates."
                + " When the option -r is specified, only the center of rotation is modified."),
            new Usage("-s [x, y]", "Moves the center of the screen from the current position by the specified amount."),
            new Usage("-s {x, y}", "Sets the center of the screen to the specified coordinates.")
        };
    }

    private static Usage[] color(Command command)
    {
        return new Usage[]{
            new Usage("{atoms} <color>", "Sets the color of the selected atoms."
                + " The color may be given as RGB values [r,g,b], predefined color names, or predefined color schemes;"
                + " amino, chain, charge, cpk, group, shapely, structure, temperature and dssp."),
            new Usage("bonds/backbone/ribbons/hbonds/ssbonds/ribbonback <color>", "Sets the color of the specified object."
                + " The color may be given as RGB values [r,g,b] or predefined color names."
                + " For hydrogen bonds, color scheme 'type' can be specified."
                + " For ribbons and ribbonback, color scheme 'dssp' can be specified."),
            new Usage("bonds/backbone/ribbons/hbonds/ssbonds/ribbonback none", "Resets the color of the specified object.")
        };
    }

    private static Usage[] colorvertex(Command command)
    {
        return new Usage[]{
            new Usage("<color>", "Sets the color of the selected vertices."
                + " The color may be given as RGB values [r,g,b] or predefined color names."),
            new Usage("none", "Resets the color of the selected vertices.")
        };
    }

    private static Usage[] cpk(Command command)
    {
        return new Usage[]{
            new Usage("", "A synonym of the spacefill command.")
        };
    }

    private static Usage[] define(Command command)
    {
        return new Usage[]{
            new Usage("<name> <atom_expression>", "Associates an arbitrary set of atoms with a unique name.")
        };
    }

    private static Usage[] display(Command command)
    {
        return new Usage[]{
            new Usage("all", "Displays the image of all files."),
            new Usage("none", "Turns off the image of all files."),
            new Usage("{-a/-r} <file_IDs>", "Displays the image of the specified files and turns off the others."
                + " More than one file IDs can be specified by putting commas as the delimiter."
                + " When the option -a or -r is specified, turns the image of the specified files on or off, respectively,"
                + " and the others remain unchanged.")
        };
    }

    private static Usage[] displayatom(Command command)
    {
        return new Usage[]{
            new Usage("{on/true}", "Displays the selected atoms."),
            new Usage("off/false", "Turns off the selected atoms."),
        };
    }

    private static Usage[] displayvertex(Command command)
    {
        return new Usage[]{
            new Usage("{on/true}", "Displays the selected vertices."),
            new Usage("off/false", "Turns off the selected vertices."),
        };
    }

    private static Usage[] echo(Command command)
    {
        return new Usage[]{
            new Usage("<string>", "Echoes the specified message back to the message area.")
        };
    }

    private static Usage[] exit(Command command)
    {
        return new Usage[]{
            new Usage("", "Terminates the application.")
        };
    }

    private static Usage[] fit(Command command)
    {
        return new Usage[]{
            new Usage("<file1_ID> <file2_ID>", "Sets the transform matrix of file1 identical to that of file2.")
        };
    }

    private static Usage[] fselect(Command command)
    {
        return new Usage[]{
            new Usage("all", "Selects all files."),
            new Usage("none", "Selects no files."),
            new Usage("{-a/-r} <file_IDs>", "Selects the specified files and makes the others not selected."
                + " More than one file IDs can be specified by putting commas as the delimiter."
                + " When the option -a or -r is specified, only the selection status of the specified files are modified,"
                + " selected or not selected, respectively, and the others remain unchanged.")
        };
    }

    private static Usage[] hbond(Command command)
    {
        return new Usage[]{
            new Usage("{on/true}", "Turns on the selected hydrogen bonds."),
            new Usage("off/false", "Turns off the selected hydrogen bonds."),
            new Usage("<radius>", "Turns on the selected hydrogen bonds with the specified raidus (angstrom or Rasmol unit)."
                + " The maximum parameter value is " + ViewerController.MAX_BOND_RADIUS + ".")
        };
    }

    private static Usage[] loadEfsite(Command command)
    {
        return new Usage[]{
            new Usage("<efsite_ID>", "Retrieves the PDB file and efvet file from eF-site database.")
        };        
    }

    private static Usage[] loadPDBml(Command command)
    {
        return new Usage[]{
            new Usage("<filename> {fit <file_ID>}", "Opens a PDBML file. URL can be used to open a remote file."
                + " On loading, the transform matrix can be set identical to that of the specified file."
            )
        };
    }

    private static Usage[] loadPDB(Command command)
    {
        return new Usage[]{
            new Usage("<filename> {fit <file_ID>}", "Opens a PDB file. URL can be used to open a remote file."
                + " On loading, the transform matrix can be set identical to that of the specified file."
            )
        };
    }

    private static Usage[] loadPolygon(Command command)
    {
        return new Usage[]{
            new Usage("<filename> {fit <file_ID>}", "Opens a polygon file. URL can be used to open a remote file."
                + " On loading, the transform matrix can be set identical to that of the specified file."
            )
        };
    }

    private static Usage[] loadPolygonCgo(Command command)
    {
        return new Usage[]{
            new Usage("<filename> {fit <file_ID>}", "Opens a polygon CGO file distributed at eF-site system. URL can be used to open a remote file."
                + " On loading, the transform matrix can be set identical to that of the specified file."
            )
        };
    }

    private static Usage[] loadAnimation(Command command)
    {
        return new Usage[]{
            new Usage("<filename> {fit <file_ID>}", "Opens an animation file. URL can be used to open a remote file."
                + " On loading, the transform matrix can be set identical to that of the specified file."
            )
        };
    }

    private static Usage[] loadFtp(Command command)
    {
        return new Usage[]{
            new Usage("<PDB_code> {fit <file_ID>}", "Retrieves a PDBML file from the PDBj FTP site and opens it."
                + " On loading, the transform matrix can be set identical to that of the specified file."
            )
        };
    }

    private static Usage[] pause(Command command)
    {
        return new Usage[]{
            new Usage("", "Stops the execution of a script file until any key is pressed to restart.")
        };
    }

    private static Usage[] pdbjDescribe(Command command)
    {
        return new Usage[]{
            new Usage("<file_id> {<name>}", "Shows the document for the jV_command in PDBMLplus specified by file ID and name."
                    + " When the name is not specified, all available names are listed.")
        };
    }

    private static Usage[] pdbjExecute(Command command)
    {
        return new Usage[]{
            new Usage("<file_id> <name>", "Executes the jV_command in PDBMLplus specified by file ID and name.")
        };
    }

    private static Usage[] quit(Command command)
    {
        return new Usage[]{
            new Usage("", "A synonym of the exit command.")
        };
    }

    private static Usage[] refresh(Command command)
    {
        return new Usage[]{
            new Usage("", "Redraws all images.")
        };
    }

    private static Usage[] reset(Command command)
    {
        return new Usage[]{
            new Usage("", "Restores the original viewing transformation of all images, the center of rotation, and the view point.")
        };
    }

    private static Usage[] resetCartoon(Command command)
    {
        return new Usage[]{
            new Usage("", "Restores the thickness of the cartoon representation.")
        };
    }

    private static Usage[] resetTransparency(Command command)
    {
        return new Usage[]{
            new Usage("", "Restores the transparency of polygon images.")
        };
    }

    private static Usage[] resetPointTransparency(Command command)
    {
        return new Usage[]{
            new Usage("", "Restores the transparency of points in polygon images.")
        };
    }

    private static Usage[] resetLineTransparency(Command command)
    {
        return new Usage[]{
            new Usage("", "Restores the transparency of lines in polygon images.")
        };
    }

    private static Usage[] resetTriangleTransparency(Command command)
    {
        return new Usage[]{
            new Usage("", "Restores the transparency of triangles in polygon images.")
        };
    }

    private static Usage[] resetQuadTransparency(Command command)
    {
        return new Usage[]{
            new Usage("", "Restores the transparency of quads in polygon images.")
        };
    }

    private static Usage[] resetPolylineTransparency(Command command)
    {
        return new Usage[]{
            new Usage("", "Restores the transparency of polylines in polygon images.")
        };
    }

    private static Usage[] resetPointSize(Command command)
    {
        return new Usage[]{
            new Usage("", "Restores the size of points in polygon images.")
        };
    }

    private static Usage[] resetLineWidth(Command command)
    {
        return new Usage[]{
            new Usage("", "Restores the width of lines in polygon images.")
        };
    }

    private static Usage[] resetPolylineWidth(Command command)
    {
        return new Usage[]{
            new Usage("", "Restores the width of polylines in polygon images.")
        };
    }

    private static Usage[] resetPickradius(Command command)
    {
        return new Usage[]{
            new Usage("", "Restores the mouse-pickable region of each atom.")
        };
    }

    private static Usage[] ribbon(Command command)
    {
        return new Usage[]{
            new Usage("{on/true}", "Turns on the ribbon surfaces for the selected residues."
                + " When a chain does not have enough atoms to draw the ribbon model, a backbone will be shown instead."),
            new Usage("off/false", "Turns off the ribbon surfaces for the selected residues."),
            new Usage("<half_width>", "Turns on the ribbon surfaces for the selected residues with the specified half width (angstrom or Rasmol unit)."
                + " The maximum parameter value is " + ViewerController.MAX_RIBBON_WIDTH + ".")
        };
    }

    private static Usage[] rotate(Command command, int axis)
    {
        String s = Character.toString( (char)('w' + axis) );
        return new Usage[]{
            new Usage("<angle>", "Rotates images about the " + s + " axis by the specified angle in degrees.")
        };
    }

    private static Usage[] savePDB(Command command)
    {
        return new Usage[]{
            new Usage("<filename>", "Saves the currently selected set of atoms in a PDB format file.")
        };
    }

    private static Usage[] saveScript(Command command)
    {
        return new Usage[]{
            new Usage("<filename>", "Creates a script file that reproduces the currently displayed image.")
        };
    }

    private static Usage[] savePng(Command command)
    {
        return new Usage[]{
            new Usage("<filename>", "Creates a PNG image file of the currently displayed image.")
        };
    }

    private static Usage[] saveJpeg(Command command)
    {
        return new Usage[]{
            new Usage("<filename> {<quality>}", "Creates a JPEG image file of the currently displayed image."
                + " The compression quality can be specified, 0 < quality <= 1, where 'quality = 1' means no compression.")
        };
    }

    private static Usage[] script(Command command)
    {
        return new Usage[]{
            new Usage("<filename>", "Opens and executes the specified script file."
                + " URL can be used to open a remote file.")
        };
    }

    private static Usage[] select(Command command)
    {
        return new Usage[]{
            new Usage("", "Selects all atoms."
                + " Whether hetero atoms and hydrogens are selected or not depends on the internal parameters, hetero and hydrogen, respectively."),
            new Usage("all", "Selects all atoms including hetero atoms and hydrogens."),
            new Usage("none", "Selects no atoms."),
            new Usage("<atom_expression>", "Selects a group of atoms specified by the atom expression.")
        };
    }

    private static Usage[] selectvertex(Command command)
    {
        return new Usage[]{
            new Usage("{all}", "Selects all vertices."),
            new Usage("none", "Selects no vertices."),
            new Usage("<vertex_expression>", "Selects a group of vertices specified by the vertex expression.")
        };
    }

    private static Usage[] setAdjustviewOn(Command command)
    {
        return new Usage[]{
            new Usage("", "The view point is automatically adjusted when a new file is loaded.")
        };
    }

    private static Usage[] setAdjustviewOff(Command command)
    {
        return new Usage[]{
            new Usage("", "The view point is kept unchanged when a new file is loaded.")
        };
    }

    private static Usage[] setAmbient(Command command)
    {
        return new Usage[]{
            new Usage("{<value>}", "Sets the amount of ambient light."
                    + " The value must be between 0 and 100."
                    + " When the parameter is not specified, it is restored to the default value 33.")
        };
    }

    private static Usage[] setBackground(Command command)
    {
        return new Usage[]{
            new Usage("", "A synonym of the background command.")
        };
    }

    private static Usage[] setBondmodeAnd(Command command)
    {
        return new Usage[]{
            new Usage("", "Specifies how to select an individual bonds."
                + " A bond is selected when both atoms connected by the bond are selected.")
        };
    }

    private static Usage[] setBondmodeOr(Command command)
    {
        return new Usage[]{
            new Usage("", "Specifies how to select an individual bonds."
                + " A bond is selected when either of the connected atoms is selected.")
        };
    }

    private static Usage[] setCartoon(Command command)
    {
        return new Usage[]{
            new Usage("{<value>}", "Specifies the thickness of the cartoon representation (angstrom or Rasmol unit)."
                + " The maximum parameter value is " + ViewerController.MAX_CARTOON_HEIGHT + "."
                + " When the parameter is not specified, it is restored to the default value.")
        };
    }

    private static Usage[] setCartoonLoopTubeOn(Command command)
    {
        return new Usage[]{
            new Usage("", "The loop region is drawn as tube in the cartoon representation.")
        };
    }

    private static Usage[] setCartoonLoopTubeOff(Command command)
    {
        return new Usage[]{
            new Usage("", "The loop region is drawn as square pillar in the cartoon representation.")
        };
    }

    private static Usage[] setCartoonRoundOn(Command command)
    {
        return new Usage[]{
            new Usage("", "Square pillar with round edge is drawn in the cartoon representation (except beta strands).")
        };
    }

    private static Usage[] setCartoonRoundOff(Command command)
    {
        return new Usage[]{
            new Usage("", "Square pillar is drawn in the cartoon representation.")
        };
    }

    private static Usage[] setCenter(Command command)
    {
        return new Usage[]{
            new Usage("<atom_expression>", "Sets the default center of the selected files to the center of the specified atoms."),
            new Usage("[x, y, z]", "Sets the default center of the selected files to the specified coordinates.")
        };
    }

    private static Usage[] setDiffuse1(Command command)
    {
        return new Usage[]{
            new Usage("{<value>}", "Sets the amount of the first diffuse light."
                + " The value must be between 0 and 100."
                + " When the parameter is not specified, it is restored to the default value 50.")
        };
    }

    private static Usage[] setDiffuse2(Command command)
    {
        return new Usage[]{
            new Usage("{<value>}", "Sets the amount of the second diffuse light."
                + " The value must be between 0 and 100."
                + " When the parameter is not specified, it is restored to the default value 50.")
        };
    }

    private static Usage[] setDiffuse1Direction(Command command)
    {
        return new Usage[]{
            new Usage("{[x, y, z]}", "Sets the direction of the first diffuse light."
                + " When the parameter is not specified, it is restored to the default value [-1, -1, -1].")
        };
    }

    private static Usage[] setDiffuse2Direction(Command command)
    {
        return new Usage[]{
            new Usage("{[x, y, z]}", "Sets the direction of the second diffuse light."
                + " When the parameter is not specified, it is restored to the default value [1, -1, -1].")
        };
    }

    private static Usage[] setDrawlevel(Command command)
    {
        return new Usage[]{
            new Usage("<value>", "Specifies precision of the rendering of spheres and cylinders."
                + " The value may be given as an integer (minimum " + ViewerController.MIN_DRAWLEVEL + ")"
                + " that stands for the number of straight line segments to represent an arc of 180 degrees.")
        };
    }

    private static Usage[] setEfsiteUrl(Command command)
    {
        return new Usage[]{
            new Usage("<url>", "Sets the URL for eF-site.")
        };
    }

    private static Usage[] setExtSiteUrl(Command command)
    {
        return new Usage[]{
            new Usage("<url>", "Sets the URL for an external database site.")
        };
    }

    private static Usage[] setHBondBackbone(Command command)
    {
        return new Usage[]{
            new Usage("", "Hydrogen bonds are displayed between backbones.")
        };
    }

    private static Usage[] setHBondSidechain(Command command)
    {
        return new Usage[]{
            new Usage("", "Hydrogen bonds are displayed between sidechains.")
        };
    }

    private static Usage[] setHeteroOn(Command command)
    {
        return new Usage[]{
            new Usage("", "Sets the default behavior of the select command such that hetero atoms are selected.")
        };
    }

    private static Usage[] setHeteroOff(Command command)
    {
        return new Usage[]{
            new Usage("", "Sets the default behavior of the select command such that hetero atoms are not selected.")
        };
    }

    private static Usage[] setHydrogenOn(Command command)
    {
        return new Usage[]{
            new Usage("", "Sets the default behavior of the select command such that hydrogens are selected.")
        };
    }

    private static Usage[] setHydrogenOff(Command command)
    {
        return new Usage[]{
            new Usage("", "Sets the default behavior of the select command such that hydrogens are not selected.")
        };
    }

    private static Usage[] setImagesize(Command command)
    {
        return new Usage[]{
            new Usage("<width> <height>", "Sets the size of the 3D-rendering panel in pixels."
                + " The size will be set within the screen size.")
        };
    }

    private static Usage[] setLoadcenterOn(Command command)
    {
        return new Usage[]{
            new Usage("", "When a file is opened, sets the default center of that file to the center of all files that have already opened.")
        };
    }

    private static Usage[] setLoadcenterOff(Command command)
    {
        return new Usage[]{
            new Usage("", "When a file is opened, sets the default center of that file according to its own coordiantes.")
        };
    }

    private static Usage[] setPdbmlNoatomUrl(Command command)
    {
        return new Usage[]{
            new Usage("<url>", "Sets the URL for PDBML noatom files.")
        };
    }

    private static Usage[] setPdbmlExtatomUrl(Command command)
    {
        return new Usage[]{
            new Usage("<url>", "Sets the URL for PDBML extatom files.")
        };
    }

    private static Usage[] setPdbmlPlusUrl(Command command)
    {
        return new Usage[]{
            new Usage("<url>", "Sets the URL for PDBMLplus files.")
        };        
    }

    private static Usage[] setPickOff(Command command)
    {
        return new Usage[]{
            new Usage("", "Turns off the mouse picking.")
        };
    }

    private static Usage[] setPickIdent(Command command)
    {
        return new Usage[]{
            new Usage("", "Sets the mouse picking behavior to show atom identification.")
        };
    }

    private static Usage[] setPickCoord(Command command)
    {
        return new Usage[]{
            new Usage("", "Sets the mouse picking behavior to show atom coordinates with identification.")
        };
    }

    private static Usage[] setPickDistance(Command command)
    {
        return new Usage[]{
            new Usage("", "Sets the mouse picking behavior to show the distance between atoms successively picked.")
        };
    }

    private static Usage[] setPickCenter(Command command)
    {
        return new Usage[]{
            new Usage("", "Sets the mouse picking behavior to specify the center of rotation and center of the screen.")
        };
    }

    private static Usage[] setPickSelect(Command command)
    {
        return new Usage[]{
            new Usage("", "Sets the mouse picking behavior to select the file that contains the atom picked.")
        };
    }

    private static Usage[] setPickradius(Command command)
    {
        return new Usage[]{
            new Usage("<value>", "Sets the mouse-pickable region of each atom to be the sphere centered to each atom with the specified radius (angstrom or Rasmol unit).")
        };
    }

    private static Usage[] setProjectionPerspective(Command command)
    {
        return new Usage[]{
            new Usage("", "Sets the projection mode for a perspective projection.")
        };
    }

    private static Usage[] setProjectionParallel(Command command)
    {
        return new Usage[]{
            new Usage("{<size>}", "Sets the projection mode for a parallel projection."
                + " The size of image (fit to the height of the screen) can be specified (angstrom or Rasmol unit).")
        };
    }

    private static Usage[] setRibbonback(Command command)
    {
        return new Usage[]{
            new Usage("<color>", "Sets the color of the back of ribbon models."
                + " The color may be given as RGB values [r,g,b] or predefined color names."),
                new Usage("none", "Resets the color of the back of ribbon models.")
        };
    }

    private static Usage[] setSpecpower(Command command)
    {
        return new Usage[]{
            new Usage("<value>", "Sets the shininess of solid objects."
                + " The value between 0 and 100 specifies a material reflection coefficient with 0 being diffuse surfaces and 100 being shiny surfaces."
            )
        };
    }

    private static Usage[] setSpecular(Command command)
    {
        return new Usage[]{
            new Usage("on/true", "Enables the display of specular highlights on solid objects."),
            new Usage("off/false", "Disables the display of specular highlights on solid objects."),
            new Usage("<value>", "Enables the display of specular highlights on solid objects."
                + " The value between 0 and 100 specifies the specular color in gray scale with 0 and 100 being black and white, respectively."
                + " The default value is " + (100*ViewerController.DEFAULT_SPECULAR_RATIO) + "."
            )
        };
    }

    private static Usage[] setSSBondBackbone(Command command)
    {
        return new Usage[]{
            new Usage("", "Disulfide bonds are displayed between backbones.")
        };
    }

    private static Usage[] setSSBondSidechain(Command command)
    {
        return new Usage[]{
            new Usage("", "Disulfide bonds are displayed between sidechains.")
        };
    }

    private static Usage[] setStereo(Command command)
    {
        return new Usage[]{
            new Usage("", "A synonym of the stereo command.")
        };
    }

    private static Usage[] setTransparency(Command command)
    {
        return new Usage[]{
            new Usage("<value>", "Sets the transparency of polygon images.")
        };
    }

    private static Usage[] setPointTransparency(Command command)
    {
        return new Usage[]{
            new Usage("<value>", "Sets the transparency of points in polygon images.")
        };
    }

    private static Usage[] setLineTransparency(Command command)
    {
        return new Usage[]{
            new Usage("<value>", "Sets the transparency of lines in polygon images.")
        };
    }

    private static Usage[] setTriangleTransparency(Command command)
    {
        return new Usage[]{
            new Usage("<value>", "Sets the transparency of triangles in polygon images.")
        };
    }

    private static Usage[] setQuadTransparency(Command command)
    {
        return new Usage[]{
            new Usage("<value>", "Sets the transparency of quads in polygon images.")
        };
    }

    private static Usage[] setPolylineTransparency(Command command)
    {
        return new Usage[]{
            new Usage("<value>", "Sets the transparency of polylines in polygon images.")
        };
    }

    private static Usage[] setPointSize(Command command)
    {
        return new Usage[]{
            new Usage("<value>", "Sets the size of points in polygon images. The <value> should be larger than 0.")
        };
    }

    private static Usage[] setLineWidth(Command command)
    {
        return new Usage[]{
            new Usage("<value>", "Sets the width of lines in polygon images. The <value> should be larger than 0.")
        };
    }

    private static Usage[] setPolylineWidth(Command command)
    {
        return new Usage[]{
            new Usage("<value>", "Sets the width of polylines in polygon images. The <value> should be larger than 0.")
        };
    }

    private static Usage[] setViewpoint(Command command)
    {
        return new Usage[]{
            new Usage("{x, y, z}", "Sets the viewpoint to the specified coordinates.")
        };
    }

    private static Usage[] showEfsiteUrl(Command command)
    {
        return new Usage[]{
            new Usage("", "Displays the URL for eF-site.")
        };
    }

    private static Usage[] showExtSiteUrl(Command command)
    {
        return new Usage[]{
            new Usage("", "Displays the URL for external database sites.")
        };        
    }

    private static Usage[] showPdbmlUrl(Command command)
    {
        return new Usage[]{
            new Usage("", "Displays the URL for PDBML files.")
        };        
    }

    private static Usage[] showGOData(Command command)
    {
        return new Usage[]{
            new Usage("", "Displays gene ontology data of molecules.")
        };
    }

    private static Usage[] showImagesize(Command command)
    {
        return new Usage[]{
            new Usage("", "Displays the size of the 3D-rendering panel.")
        };
    }

    private static Usage[] showInformation(Command command)
    {
        return new Usage[]{
            new Usage("", "Displays a detail discription of molecules.")
        };
    }

    private static Usage[] showSite(Command command)
    {
        return new Usage[]{
            new Usage("{<prefix>:<db>:<category>}", 
                    "Displays site information in an external database.")
        };
    }

    private static Usage[] showTransform(Command command)
    {
        return new Usage[]{
            new Usage("", "Displays the transform matrix of molecules.")
        };
    }

    private static Usage[] showViewpoint(Command command)
    {
        return new Usage[]{
            new Usage("", "Displays the current viewpoint.")
        };
    }

    private static Usage[] showXps3(Command command)
    {
        return new Usage[]{
            new Usage("", "Displays keywords available in PDBj expression.")
        };
    }

    private static Usage[] slab(Command command)
    {
        return new Usage[]{
            new Usage("{on/true}", "Enables the z-clipping plane of molecules and polygons."),
            new Usage("off/false", "Disables the z-clipping plane of molecules and polygons."),
            new Usage("<ratio>", "Sets the position of the z-clipping plane of molecules and polygons."
                + " The parameter may be given as a number from 0 to 100."
                + " The values 0 and 100 represent that image as a whole is completely invisible and visible, respectively."),
            new Usage("-v <value>", "Sets the position of the z-clipping plane of molecules and polygons by specifying the z coordinate value.")
        };
    }

    private static Usage[] spacefill(Command command)
    {
        return new Usage[]{
            new Usage("{on/true}", "Turns on the ball image of the selected atoms."),
            new Usage("off/false", "Turns off the ball image of the selected atoms."),
            new Usage("<radius>", "Turns on the ball image of the selected atoms with the specified radius (angstrom or Rasmol unit)."
                + " The maximum parameter value is " + ViewerController.MAX_BALL_RADIUS + "."),
            new Usage("temperature", "Turns on the ball image of the selected atoms using the temperature factor as radius.")
        };
    }

    private static Usage[] ssbond(Command command)
    {
        return new Usage[]{
            new Usage("{on/true}", "Turns on the selected disulfide bonds."),
            new Usage("off/false", "Turns off the selected disulfide bonds."),
            new Usage("<radius>", "Turns on the selected disulfide bonds with the specified raidus (angstrom or Rasmol unit)."
                + " The maximum parameter value is " + ViewerController.MAX_BOND_RADIUS + ".")
        };
    }

    private static Usage[] stereo(Command command)
    {
        return new Usage[]{
            new Usage("{redblue/redcyan/redgreen} <angle>", "Enables stereo display with the specified separation angle."
                + " Positive and negative values represent wall-eyed and cross-eyed viewing, respectively."
                + " When 'redblue', 'redcyan' or 'redgreen' is passed as the first argument, anaglyph 3D is rendered with red-blue, red-cyan or red-green color pair, respectively."),
            new Usage("{on/true/redblue/redcyan/redgreen}", "Enables side-by-side stereo viewing (for argument 'on' or 'true')"
                + " or anaglyph 3D rendering (for argument 'redblue', 'redcyan' or 'redgreen') with a previously specified separation angle,"
                + " where program's initial value is 6 degrees."
                + " The command without arguments cycles six states;"
                + " wall-eyed stereo, cross-eyed stereo, red-blue anaglyph, red-cyan anaglyph, red-green anaglyph and stereo-off."),
            new Usage("off/false", "Disables stereo display.")
        };
    }

    private static Usage[] structure(Command command)
    {
        return new Usage[]{
            new Usage("", "Estimates the secondary structure using Kabsch and Sander's DSSP algorithm.")
        };
    }

    private static Usage[] trace(Command command)
    {
        return new Usage[]{
            new Usage("{on/true}", "Turns on a tube representation for the selected residues."
                + " When a chain does not have enough atoms to draw the tube model, a backbone will be shown instead."),
            new Usage("off/false", "Turns off a tube representation for the selected residues."),
            new Usage("<radius>", "Turns on a tube representation for the selected residues with the specified radius (angstrom or Rasmol unit)."
                + " The maximum parameter value is " + ViewerController.MAX_BOND_RADIUS + ".")
        };
    }

    private static Usage[] translate(Command command, int axis)
    {
        String s = Character.toString( (char)('w' + axis) );
        return new Usage[]{
            new Usage("<value>", "Moves images along the " + s + " axis by the specified amount (angstrom).")
        };
    }

    private static Usage[] wireframe(Command command)
    {
        return new Usage[]{
            new Usage("{on/true}", "Turns on the selected bonds."),
            new Usage("off/false", "Turns off the selected bonds."),
            new Usage("<radius>", "Turns on the selected bonds with the specified raidus (angstrom or Rasmol unit)."
                + " The maximum parameter value is " + ViewerController.MAX_BOND_RADIUS + ".")
        };
    }

    private static Usage[] write(Command command)
    {
        return new Usage[]{
            new Usage("", "A synonym of the save command.")
        };
    }

    private static Usage[] zap(Command command)
    {
        return new Usage[]{
            new Usage("{<file_IDs>}", "Closes the specified files."
                + " More than one file IDs can be specified by putting commas as the delimiter."
                + " When the paraneter is absent, all files are closed.")
        };
    }

    private static Usage[] zoom(Command command)
    {
        return new Usage[]{
            new Usage("{<value>}", "Sets the magnification of the image as a whole."
                + " The value stands for the magnification as a percentage of the current scale."
                + " The minimum parameter value is " + (ViewerController.MIN_ZOOM_RATIO*100)+ ".")
        };
    }
}    
