/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.commands;

import java.awt.*;
import java.util.*;
import org.pdbj.viewer.utils.*;
import org.pdbj.viewer.controller.*;

/**
 * Represents GUI controller.
 */
public interface GuiController
{
    /**
     * Error message for a command not supported.
     */
    String COMMAND_NOT_SUPPORTED = "Command Not Supported.";

    /**
     * Returns whether or not the script mode.
     */
    boolean isScriptMode();

    /**
     * Loads PDB file.
     */
    void loadPDBFile(String filePath, FileStatus copy);

    /**
     * Loads PDBML file.
     */
    void loadPDBmlFile(String filePath, FileStatus copy);

    /**
     * Loads polygon file.
     */
    void loadPolygonFile(String filePath, FileStatus copy);

    /**
     * Loads polygon CGO file.
     */
    void loadPolygonCgoFile(String filePath, FileStatus copy);

    /**
     * Loads script file.
     */
    void loadScriptFile(String filePath);

    /**
     * Loads animation file.
     */
    void loadAnimationFile(String filePath, FileStatus copy);

    /**
     * Loads PDBML file by FTP.
     */
    void loadPDBmlFileFtp(String pdbCode, FileStatus copy);

    /**
     * Loads eF-site data files.
     */
    void loadEfsite(String efsiteId);

    /**
     * Saves pdb file.
     */
    void savePDBFile(String filePath);

    /**
     * Saves script file.
     */
    void saveScriptFile(String filePath);

    /**
     * Saves PNG file.
     */
    void savePngFile(String filePath, float ratio);

    /**
     * Saves JPEG file.
     */
    void saveJpegFile(String filePath, float ratio, float quality);

    /**
     * Pause execution of script.
     */
    void pauseScript();

    /**
     * Sets up the stereo mode.
     */
    void setupStereo();

    /**
     * Terminates the application.
     */
    void exit();

    /**
     * Returns the FTP message listener.
     */
    MessageListener getFtpMessageListener();

    /**
     * Returns whether or not the standalone application.
     */
    boolean isStandalone();

    /**
     * Loads function file by FTP.
     */
    void loadFunctionFtp(FileStatus file);

    /**
     * Returns the site URL map.
     */
    HashMap getSiteUrlMap();

    /**
     * Loads the site list.
     */
    void loadSiteList(FileStatus file, String key);

    /**
     * Returns the size of the 3D-rendering panel.
     */
    Dimension getImageSize();

    /**
     * Requests the size of the 3D-rendering panel and 
     * returns the size actually set.
     */
    Dimension setImageSize(Dimension d);

    /**
     * PDBj execute.
     */
    void pdbjExecute(int fileId, String name);

    /**
     * Initialize stereo.
     */
    void initializeStereo();

    /**
     * Returns whether NEWT is used.
     */
    boolean isNewt();
}
