/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.commands;

import org.pdbj.viewer.manipulators.*;

/**
 * Primitive expression parser.
 */
class PrimitiveExprParser
{
    public static SelectExpr parse(String expression)
    {
        if(expression == null || expression.length() == 0) return null;

        PrimitiveExpr expr = new PrimitiveExpr();

        try{
            int index, last;

            // File ID
            index = expression.indexOf('@');
            if(index != -1){
                String fileId = expression.substring(index+1);
                if(!fileId.equals("*")) expr.setFileId(Integer.parseInt(fileId));
                expression = expression.substring(0, index);
            }
            // Model ID
            index = expression.indexOf('/');
            if(index != -1){
                String modelId = expression.substring(index+1);
                if(!modelId.equals("*")) expr.setModelId(Integer.parseInt(modelId));
                expression = expression.substring(0, index);
            }
            // AltLoc
            index = expression.indexOf(';');
            if(index != -1){
                String altLoc = expression.substring(index+1);
                if(altLoc.equals("")) return null;
                if(!altLoc.equals("*")) expr.setAltLoc(altLoc);
                expression = expression.substring(0, index);
            }
            // Atom Name
            index = expression.indexOf('.');
            if(index != -1){
                String atomName = expression.substring(index+1);
                if(atomName.equals("")) return null;
                if(!atomName.equals("*")) expr.setAtomName(atomName);
                expression = expression.substring(0, index);
            }
            // Chain ID
            index = expression.indexOf(':');
            if(index != -1){
                String chainId = expression.substring(index+1);
                if(isEmptyChainId(chainId)) return null;
                if(!chainId.equals("*")) expr.setChainId(chainId);
                expression = expression.substring(0, index);
            }
            if(expression.length() == 0) return null;

            index = 0;
            last = expression.length();

            // Residue Name
            String resName = null;
            if(expression.charAt(index) == '['){
                index = expression.indexOf(']');
                if(index == -1) return null;
                resName = expression.substring(1, index);
                index++;
            }
            else if(expression.charAt(index) == '*'){
                resName = "*";
                index++;
            }
            else{
                while( index != last && 
                       !isNumeric(expression.charAt(index)) ) index++;
                resName = expression.substring(0, index);
            }
            if(resName.length() == 0 || resName.length() > 3) return null;
            if(!resName.equals("*")) expr.setResidueName(resName);

            // Residue ID
            if(index != last){
                int init = index;
                if(expression.charAt(index) == '*'){
                    index++;
                }
                else{
                    while( index != last && 
                           isNumeric(expression.charAt(index)) ) index++;
                    if(index != init){
                        expr.setResidueId(
                            Integer.parseInt(expression.substring(init, index))
                        );
                    }
                }
            }

            // Chain ID
            if(index != last){
                String chainId = expression.substring(index);
                if(isEmptyChainId(chainId)) return null;
                if(!chainId.equals("*")) expr.setChainId(chainId);
            }
        }
        catch(NumberFormatException e){
            return null;
        }

        return expr;
    }

    private static boolean isNumeric(char ch)
    {
        return (ch >= '0' && ch <= '9') || ch == '-';
    }

    private static boolean isEmptyChainId(String chainId)
    {
        return chainId.equals("") || chainId.equals("a_") || chainId.equals("l_");
    }
}
