/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.commands;

import java.util.ArrayList;

/**
 * Splits string.
 */
public class StringSplitter
{
    private String[] _delimiters;

    /**
     * Splits string with the specified delimiters.
     */
    public String[] split(String expr, String[] delimiters)
    {
        _delimiters = delimiters;

        ArrayList list = this.separate(expr);
        return this.toArray(list);
    }

    /**
     * Splits string with the specified delimiters and trims the tokens.
     */
    public String[] splitTrim(String expr, String[] delimiters)
    {
        _delimiters = delimiters;

        ArrayList list = this.separate(expr);

        ArrayList list2 = new ArrayList();
        for(int i=0; i<list.size(); i++)
        {
            String s = (String)list.get(i);
            String token = s.trim();
            if( !token.equals("") ) list2.add(token);
        }
        return this.toArray(list2);
    }

    //--------------------------------------------------------------------
    // Tokenize
    //--------------------------------------------------------------------
    private ArrayList separate(String expr)
    {
        ArrayList currTokens = this.divide(expr);

        if(currTokens.size() == 1){
            return currTokens;
        }
        else{
            ArrayList tokens = new ArrayList();
            for(int i=0; i<currTokens.size(); i++)
            {
                String token = (String)currTokens.get(i);
                tokens.addAll( this.separate(token) );
            }
            return tokens;
        }
    }

    private ArrayList divide(String expr)
    {
        ArrayList tokens = new ArrayList();
        boolean find = false;
        for(int i=0; i<_delimiters.length; i++)
        {
            String delimiter = _delimiters[i];
            if(find) break;
            int index = expr.indexOf(delimiter);
            if(index != -1){
                int index2 = index + delimiter.length();
                if(index != 0){
                    tokens.add( expr.substring(0, index) );
                }
                tokens.add(delimiter);
                if(index2 < expr.length()){
                    tokens.add( expr.substring(index2) );
                }
                find = true;
            }
        }
        if(!find) tokens.add(expr);

        return tokens;
    }

    //--------------------------------------------------------------------
    // Utility
    //--------------------------------------------------------------------
    private String[] toArray(ArrayList list)
    {
        return (String[])list.toArray( new String[0] );
    }
}
