/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.commands;

import java.util.*;
import org.pdbj.viewer.tables.*;
import org.pdbj.viewer.manipulators.*;

/**
 * User defined atom set.
 */
public class UserAtomSet
{
    private HashMap _atomSetMap;

    /**
     * Constructor.
     */
    public UserAtomSet()
    {
        _atomSetMap = new HashMap();
    }

    /**
     * Adds atom set.
     */
    public boolean add(String name, String expr)
    {
        if( testName(name) ){
            _atomSetMap.put(name, expr);
            return true;
        }
        return false;
    }

    /**
     * Returns an iterator for names.
     */
    public Iterator iteratorName() {
        return _atomSetMap.keySet().iterator();
    }

    /**
     * Returns the atom expression for the specified name.
     */
    public String valueOf(String name)
    {
        return (String)_atomSetMap.get(name);
    }

    /**
     * Removes all atom sets.
     */
    public void clear()
    {
        _atomSetMap.clear();
    }

    /**
     * Tests whether the atom set name is available.
     */
    public static boolean testName(String name)
    {
        if(name == null) return false;

        // valid character?
        for(int i=0; i<name.length(); i++){
            char ch = name.charAt(i);
            if( !(ch >= 'a' && ch <= 'z') && !(ch >= 'A' && ch <= 'Z')
                && !(ch >= '0' && ch <= '9') && ch != '_')
            {
                return false;
            }
        }

        // number?
        if( isNumberToken(name) ) return false;

        // element name?
        if( ElementTable.isElementName(name) ) return false;

        // color name?
        if( ColorTable.isColorName(name) ) return false;

        // predefined set name?
        int index = PredefinedSetExpr.getIndex(name);
        if(index != -1) return false;

        return true;
    }

    private static boolean isNumberToken(String token)
    {
        try{
            Double.parseDouble(token);
        }
        catch(NumberFormatException e){
            return false;
        }
        return true;
    }
}
