/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.controller;

import org.pdbj.viewer.molecules.*;
import org.pdbj.viewer.polygons.*;

/**
 * Class that represents file status.
 */
public class FileStatus
{
    public static final int PDBML   = 0;
    public static final int PDB     = 1;
    public static final int POLYGON = 2;

    private MoleculeFile _moleculeFile;
    private PolygonFile  _polygonFile;

    private int _type;

    /**
     * Returns the file type.
     */
    public int getType()
    {
        return _type;
    }

    /**
     * Returns the file ID.
     */
    public int getId()
    {
        return (_type == POLYGON) ?
            _polygonFile.getFileId() : _moleculeFile.getFileId();
    }

    /**
     * Returns the file path.
     */
    public String getPath()
    {
        return (_type == POLYGON) ?
            _polygonFile.getFilePath() : _moleculeFile.getFilePath();
    }

    /**
     * Returns whether the file is selected.
     */
    public boolean isSelected()
    {
        return (_type == POLYGON) ?
            _polygonFile.isSelected() : _moleculeFile.isSelected();
    }

    /**
     * Returns whether the file is displayed.
     */
    public boolean isDisplayed()
    {
        return (_type == POLYGON) ?
            _polygonFile.isDisplayed() : _moleculeFile.isDisplayed();
    }

    /**
     * Returns whether any component is selected.
     */
    public boolean isComponentSelected() {
        int cnt = (_type == POLYGON) ? 
                _polygonFile.getSelectVertexCount() : _moleculeFile.getSelectAtomCount();
        return cnt > 0;
    }

    /**
     * Returns the molecule file.
     */
    public MoleculeFile getMoleculeFile()
    {
        return _moleculeFile;
    }

    /**
     * Returns the polygon file.
     */
    public PolygonFile getPolygonFile()
    {
        return _polygonFile;
    }

    /**
     * Constructor.
     */
    public FileStatus(MoleculeFile moleculeFile)
    {
        _moleculeFile = moleculeFile;
        _type = moleculeFile.isPDBml() ? PDBML : PDB;
    }

    /**
     * Constructor.
     */
    public FileStatus(PolygonFile polygonFile)
    {
        _polygonFile = polygonFile;
        _type = POLYGON;
    }
}
