/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.controller;

import org.pdbj.viewer.utils.*;

/**
 * View parameters.
 */
public class ViewParameters
{
    public static final float SLABVALUE_UNDEFINED = Float.NEGATIVE_INFINITY;

    private Vector3f _defaultCameraPosition;
    private Vector3f _defaultCenter;
    private Vector3f _currentCenter;
    private float    _defaultRadius;
    private float    _currentRadius;

    private Vector3f _rotationCenter;

    private boolean _slab;
    private float   _slabValue;
    
    private boolean _loadCenter;
    private boolean _adjustView;

    /**
     * Returns the default camera position.
     */
    public Vector3f getDefaultCameraPosition()
    {
        return _defaultCameraPosition;
    }

    /**
     * Returns the default center.
     */
    public Vector3f getDefaultCenter()
    {
        return _defaultCenter;
    }
    
    /**
     * Sets the default radius.
     */
    public void setDefaultRadius(float defaultRadius)
    {
        _defaultRadius = defaultRadius;
    }

    /**
     * Returns the default radius.
     */
    public float getDefaultRadius()
    {
        return _defaultRadius;
    }

    /**
     * Returns the current center.
     */
    public Vector3f getCurrentCenter()
    {
        return _currentCenter;
    }
    
    /**
     * Sets the current radius.
     */
    public void setCurrentRadius(float currentRadius)
    {
        _currentRadius = currentRadius;
    }

    /**
     * Returns the current radius.
     */
    public float getCurrentRadius()
    {
        return _currentRadius;
    }

    /**
     * Returns the rotation center.
     */
    public Vector3f getRotationCenter()
    {
        return _rotationCenter;
    }
    
    /**
     * Sets whether the slab mode.
     */
    public void setSlab(boolean slab)
    {
        _slab = slab;
    }

    /**
     * Returns whether the slab mode.
     */
    public boolean isSlab()
    {
        return _slab;
    }

    /**
     * Sets the z coordinate of the slab plane.
     */
    public void setSlabValue(float slabValue)
    {
        _slabValue = slabValue;
    }

    /**
     * Returns the z coordinate of the slab plane.
     */
    public float getSlabValue()
    {
        return _slabValue;
    }

    /**
     * Returns whether to load to center.
     */
    public boolean isLoadCenter()
    {
        return _loadCenter;
    }

    /**
     * Sets whether to load to center.
     */
    public void setLoadCenter(boolean enable)
    {
        _loadCenter = enable;
    }

    /**
     * Returns whether to adjust view.
     */
    public boolean isAdjustView()
    {
        return _adjustView;
    }

    /**
     * Sets whether to adjust view.
     */
    public void setAdjustView(boolean enable)
    {
        _adjustView = enable;
    }

    /**
     * Constructor.
     */
    public ViewParameters()
    {
        _defaultCameraPosition = new Vector3f();
        _defaultCenter         = new Vector3f();
        _currentCenter         = new Vector3f();
        _rotationCenter        = new Vector3f();

        _slabValue = SLABVALUE_UNDEFINED;
        
        _adjustView = true;
    }
}
