/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.exceptions;

import java.io.*;
import java.net.*;
import java.security.*;
import javax.xml.parsers.*;
import org.xml.sax.*;

/**
 * Handles exceptinos.
 */
public class ExceptionUtil
{
    /**
     * Returns the stack trace.
     */
    public static String getStackTrace(Throwable e)
    {
        StringBuffer sb = new StringBuffer();
        
        sb.append(e.toString() + "\n");
        StackTraceElement[] elements = e.getStackTrace();
        for(int i=0; i<elements.length; i++){
            sb.append("    at " + elements[i].toString() + "\n");
        }
        
        return sb.toString();
    }

    /**
     * Handles SAX exceptinos.
     */
    public static RecoverableException handleSAXException(SAXException e)
    {
        StringBuffer sb = new StringBuffer();

        sb.append( ErrorMessages.INVALID_XML + "\n" );
        sb.append( e.getMessage() + "\n" );

        return new RecoverableException( sb.toString() );
    }

    /**
     * Handles XML parser exceptinos.
     */
    public static RecoverableException handleParserConfigurationException(
        ParserConfigurationException e)
    {
        //e.printStackTrace();
        
        StringBuffer sb = new StringBuffer();

        sb.append("XML Parser Configuration Error.\n");
        sb.append("\n");
        sb.append( ExceptionUtil.getStackTrace(e) );

        return new RecoverableException( sb.toString() );
    }

    /**
     * Handles UnknownHost exceptinos.
     */
    public static RecoverableException handleUnknownHostException(
        UnknownHostException e)
    {
        return new RecoverableException( "Unknown Host : " + e.getMessage() );
    }

    /**
     * Handles IO exceptinos.
     */
    public static RecoverableException handleIOException(IOException e)
    {
        //e.printStackTrace();

        StringBuffer sb = new StringBuffer();

        sb.append(ErrorMessages.IO_ERROR + "\n");
        sb.append("\n");
        sb.append( e.getMessage() );
        //sb.append( ExceptionUtil.getStackTrace(e) );

        return new RecoverableException( sb.toString() );
    }

    /**
     * Returns whether the exception is due to a bug in JDK 1.4.1.
     */
    public static boolean isPropertyPermission(AccessControlException e)
    {
        String message = e.getMessage();
        return ( message.indexOf("java.util.PropertyPermission") != -1);
    }
    
    public static RecoverableException handlePropertyPermission()
    {
        StringBuffer sb = new StringBuffer();

        sb.append("Java XML Parser error.\n");
        sb.append("\n");
        sb.append("This problem is related to the XML-parser in Java of the version from\n");
        sb.append("1.4.1_03 to 1.4.1_06. The problem is fixed in Java 1.4.2 or later, and\n");
        sb.append("it does not exist in Java 1.4.1_02. In other words, jV does not work\n");
        sb.append("with JRE from 1.4.1_03 to 1.4.1_06. Please use JRE 1.4.1_02 or JRE\n");
        sb.append("1.4.2.\n");

        return new RecoverableException( sb.toString() );
    }

    /**
     * Handles out of memory errors.
     */
    public static FatalException handleOutOfMemoryError(OutOfMemoryError e)
    {
        e.printStackTrace();

        StringBuffer sb = new StringBuffer();
        sb.append(ErrorMessages.OUT_OF_MEMORY);

        return new FatalException( sb.toString() );
    }

    /**
     * Handles unexpected exceptinos.
     */
    public static FatalException handleThrowable(Throwable t)
    {
        t.printStackTrace();

        StringBuffer sb = new StringBuffer();
        
        sb.append("Fatal error has occurred.\n");
        sb.append("\n");
        sb.append("Please let us know how this error message appeared. Details of\n");
        sb.append("the error will be appeared on the console window. Along with the\n");
        sb.append("error messages, information of your computational environment\n");
        sb.append("will be needed for us to fix our problems. Error reports to\n");
        sb.append("pdbjviewer@protein.osaka-u.ac.jp will be appreciated.\n");
        sb.append("\n");
        sb.append("Thanks");

        return new FatalException( sb.toString() );
    }
}
