/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.gui;

import org.pdbj.viewer.exceptions.*;
import org.pdbj.viewer.controller.*;
import org.pdbj.viewer.mouse.*;
import org.pdbj.viewer.commands.*;

/**
 * Represents a GUI wrapper.
 */
public interface GuiWrapper extends GuiController
{
    /**
     * Returns a viewer controller.
     */
    ViewerController getViewerController();

    /**
     * Returns a mouse behavior.
     */
    MouseBehavior getMouseBehavior();

    /**
     * Loads a local file.
     */
    void loadLocalFile(FileType fileType);

    /**
     * Loads a remote file.
     */
    void loadRemoteFile(FileType fileType);

    /**
     * Loads a remote file.
     */
    void loadRemoteFile(UrlDialog urlDialog);

    /**
     * Loads files specified by PDB ID.
     */
    void loadByPDBID();

    /**
     * Loads files specified by eF-site ID.
     */
    void loadByEFsiteID();

    /**
     * Loads a file registered in the history.
     */
    void loadHistory(FileType fileType, FileLocator locator);

    /**
     * Appends a file history.
     */
    void addFileHistory(FileType type, FileLocator locator);

    /**
     * Saves a file.
     */
    void saveFile(FileType fileType);

    /**
     * Shows information of files.
     */
    void showInformation();

    /**
     * Shows an animation frame.
     */
    void showAnimationFrame();

    /**
     * Shows an about dialog.
     */
    void showAboutDialog();

    /**
     * Opens the manual.
     */
    void openManual();

    /**
     * Rotates stereo mode.
     */
    void rotateStereo();

    /**
     * Handles a recoverable exception.
     */
    void handleRecoverableException(RecoverableException e);

    /**
     * Handles a fatal exception.
     */
    void handleFatalException(FatalException e);

    /**
     * Starts an execution of a command.
     */
    void startCommand(String command, CommandType type);

    /**
     * Starts an execution of a command.
     */
    void startCommand(CommandTokenizer tokenizer, CommandType type);

    /**
     * Ends an execution of a command.
     */
    void endCommand();

    /**
     * Returns whether menu is active.
     */
    boolean menuActive();

    /**
     * Called when a key is typed to start script.
     */
    void commandKeyTyped();
    
    /**
     * Called when focus is moved.
     */
    void focusMoved();
}
