/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * Custom input dialog.
 */
public class InputDialog extends JDialog implements ActionListener
{
    private static final long serialVersionUID = 1L;

    private JLabel _label;
    private JTextField _textField;
    private JButton _buttonOK;
    private JButton _buttonCancel;
    
    private String _value;

    /**
     * Constructor.
     */
    public InputDialog(Frame owner, String title, String label, int textWidth)
    {
        super(owner, title, true);
        this.createComponent(owner, label, textWidth);
        this.setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
    }

    /**
     * Shows dialog.
     */
    public String show(String text)
    {
        _textField.setText(text);
        this.setVisible(true);
        return _value;
    }

    //--------------------------------------------------------------------
    // Create component
    //--------------------------------------------------------------------
    private void createComponent(Frame owner, String label, int textWidth)
    {
        int min = 240;
        int margin = 20;
        int width = textWidth + 2*margin;
        if(width < min) width = min;
        
        Point ownerLocation = owner.getLocation();
        Dimension ownerSize = owner.getSize();

        Dimension size = new Dimension(width+8, 160);        
        this.setSize(size);
        this.setResizable(false);
        this.setLocation(
            ownerLocation.x + (ownerSize.width - size.width)/2, 
            ownerLocation.y + (ownerSize.height - size.height)/2
        );

        Font font = new Font("SansSerif", Font.PLAIN, 12);
        
        Container container = getContentPane();
        container.setLayout(null);
        
        _label = new JLabel(label);
        _label.setSize(width - 2*margin,20);
        _label.setLocation(margin, 20);
        _label.setFont(font);
        
        _textField = new JTextField();
        _textField.setSize(textWidth, 20);
        _textField.setLocation( (width - textWidth)/2, 50);
        _textField.setFont(font);
        _textField.addKeyListener(
            new KeyAdapter(){
                public void keyTyped(KeyEvent e){
                    handle_keyTyped(e);
                }
            }
        );

        _buttonOK = new JButton("OK");
        _buttonOK.setSize(80, 20);
        _buttonOK.setLocation(width - margin - 170, 90);
        _buttonOK.setFont(font);
        _buttonOK.addActionListener(this);

        _buttonCancel = new JButton("Cancel");
        _buttonCancel.setSize(80, 20);
        _buttonCancel.setLocation(width - margin - 80, 90);
        _buttonCancel.setFont(font);
        _buttonCancel.addActionListener(this);

        container.add(_label);
        container.add(_textField);
        container.add(_buttonOK);
        container.add(_buttonCancel);
    }
    
    private void handle_keyTyped(KeyEvent e)
    {
        if(e.getKeyChar() == KeyEvent.VK_ENTER)
        {
            e.consume();
            _value = _textField.getText().trim();
            this.setVisible(false);
        }
    }

    //--------------------------------------------------------------------
    // Implements ActionListener
    //--------------------------------------------------------------------
    /**
     * Called when a button action is performed.
     */
    public void actionPerformed(ActionEvent e)
    {
        if(e.getSource() == _buttonOK)
        {
            _value = _textField.getText().trim();
            this.setVisible(false);
        }
        else if(e.getSource() == _buttonCancel)
        {
            this.setVisible(false);
        }
    }
}
