/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.gui;

import org.pdbj.viewer.molecules.*;
import org.pdbj.viewer.polygons.*;

/**
 * Reader frame task.
 */
class ReaderFrameTask implements Runnable
{
    static final int LOAD_MOLECULE = 0;
    static final int LOAD_POLYGON = 1;
    static final int RECOVERABLE_ERROR = 2;
    static final int FATAL_ERROR = 3;
    
    private ReaderContext _context;
    private int _status;

    ReaderFrameTask(ReaderContext context)
    {
        _context = context;
    }
    
    void setStatus(int status)
    {
        _status = status;
    }
    
    int getStatus()
    {
        return _status;
    }

    public void run()
    {
        if (_context.efsiteData != null) {
            if (_context.efsiteData.isFinished()) {
                if (_context.efsiteData.getMoleculeFile() != null) {
                    processMoleculeFile(_context.efsiteData.getMoleculeFile());
                }
                if (_context.efsiteData.getPolygonFile() != null) {
                    processPolygonFile(_context.efsiteData.getPolygonFile());
                }
            }
            
        } else {
            if(_status == LOAD_MOLECULE)
            {
                processMoleculeFile(_context.moleculeFile);
            }
            else if(_status == LOAD_POLYGON)
            {
                processPolygonFile(_context.polygonFile);
            }
        }

        if(_status == RECOVERABLE_ERROR)
        {
            _context.guiWrapper.handleRecoverableException(_context.recoverableException);
        }
        else if(_status == FATAL_ERROR)
        {
            _context.guiWrapper.handleFatalException(_context.fatalException);
        }

        if (_context.endCommand) {
            if (_context.efsiteData == null || _context.efsiteData.isFinished()) {
                _context.guiWrapper.endCommand();
            }
        }
    }

    private void processMoleculeFile(MoleculeFile moleculeFile) {
        int id = _context.controller.loadMoleculeFile(moleculeFile, _context.image, _context.copy);
        if (_context.toHistory && id != -1) {
            _context.guiWrapper.addFileHistory(_context.fileType, _context.locator);
        }
    }

    private void processPolygonFile(PolygonFile polygonFile) {
        int id = _context.controller.loadPolygonFile(polygonFile, _context.copy);
        if(_context.toHistory && id != -1){
            _context.guiWrapper.addFileHistory(_context.fileType, _context.locator);
        }
    }
}
