/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.gui;

import java.io.*;
import java.net.*;
import java.util.*;

/**
 * Url configuration.
 */
public class UrlConfig
{
    public static final String TYPE_TEXT = "text";
    public static final String TYPE_ATOM_ID = "atom ID";
    public static final String TYPE_ATOM = "atom";
    public static final String TYPE_RESIDUE = "residue";
    public static final String TYPE_ORIG_COORD = "orig_coords";
    public static final String TYPE_CURR_COORD = "curr_coords";

    private String  _url;
    private boolean _attachParam;
    private String  _delimiter;

    private ArrayList _names;
    private ArrayList _values;
    private ArrayList _types;

    /**
     * Constructor.
     */
    public UrlConfig()
    {
        _url = "";
        _attachParam = true;
        _delimiter = ",";

        _names  = new ArrayList();
        _values = new ArrayList();
        _types  = new ArrayList();
    }

    /**
     * Sets the URL.
     */
    public void setUrl(String url)
    {
        _url = url;
    }

    /**
     * Returns the URL.
     */
    public String getUrl()
    {
        return _url;
    }

    /**
     * Sets whether parameters are attached.
     */
    public void setAttachParameter(boolean enable)
    {
        _attachParam = enable;
    }

    /**
     * Returns whether parameters are attached.
     */
    public boolean isAttachParameter()
    {
        return _attachParam;
    }

    /**
     * Sets the coordinate delimiter.
     */
    public void setDelimiter(String delimiter)
    {
        _delimiter = delimiter;
    }

    /**
     * Returns the coordinate delimiter.
     */
    public String getDelimiter()
    {
        return _delimiter;
    }

    /**
     * Appends a parameter.
     */
    public void addParameter(String name, String value, String type)
    {
        if(name == null || name.equals("")) return;

        _names.add(name);
        _values.add(value);
        _types.add(type);
    }

    /**
     * Clears all parameters.
     */
    public void clearParameters()
    {
        _names.clear();
        _values.clear();
        _types.clear();
    }

    /**
     * Returns the number of parameters.
     */
    public int numParameters()
    {
        return _names.size();
    }

    /**
     * Returns the name of the parameter.
     */
    public String getName(int index)
    {
        return (String)_names.get(index);
    }

    /**
     * Returns the value of the parameter.
     */
    public String getValue(int index)
    {
        return (String)_values.get(index);
    }

    /**
     * Returns the type of the parameter.
     */
    public String getType(int index)
    {
        return (String)_types.get(index);
    }

    /**
     * Returns an encoded string expression of parameters.
     */
    public String encodeParameters(String encode) throws UnsupportedEncodingException
    {
        StringBuffer buffer = new StringBuffer();
        boolean first = true;
        for(int i=0; i<_names.size(); i++)
        {
            String name = this.getName(i);
            String value = this.getValue(i);
            if( value == null || value.equals("") ) continue;
            
            if(!first) buffer.append("&");
            String nameEncode  = URLEncoder.encode(name, encode);
            String valueEncode = URLEncoder.encode(value, encode);
            buffer.append(nameEncode + "=" + valueEncode);
            first = false;
        }

        return buffer.toString();
    }
}
