/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.gui;

import java.awt.*;

/**
 * GUI layout.
 */
public abstract class ViewerLayout
{
    /**
     * Preferred file status panel width.
     */
    public static final int TOOL_WIDTH = 195;
    /**
     * Preferred command area height.
     */
    public static final int COMMAND_HEIGHT = 140;

    private Canvas _canvasL;
    private Canvas _canvasR;

    private FileStatusPanel _fileStatusPanel;
    private ViewerStatusPanel _viewerStatusPanel;
    private CommandArea     _commandArea;

    private boolean _stereo;

    /**
     * Sets the left canvas.
     */
    public void setCanvasL(Canvas canvas)
    {
        _canvasL = canvas;
    }

    /**
     * Returns the left canvas.
     */
    public Canvas getCanvasL()
    {
        return _canvasL;
    }
    
    /**
     * Sets the right canvas.
     */
    public void setCanvasR(Canvas canvas)
    {
        _canvasR = canvas;
    }

    /**
     * Returns the right canvas.
     */
    public Canvas getCanvasR()
    {
        return _canvasR;
    }
    
    /**
     * Sets the file status panel.
     */
    public void setFileStatusPanel(FileStatusPanel fileStatusPanel)
    {
        _fileStatusPanel = fileStatusPanel;
    }

    /**
     * Returns the file status panel.
     */
    public FileStatusPanel getFileStatusPanel()
    {
        return _fileStatusPanel;
    }

    /**
     * Sets the viewer status panel.
     */
    public void setViewerStatusPanel(ViewerStatusPanel viewerStatusPanel)
    {
        _viewerStatusPanel = viewerStatusPanel;
    }

    /**
     * Returns the viewer status panel.
     */
    public ViewerStatusPanel getViewerStatusPanel()
    {
        return _viewerStatusPanel;
    }

    /**
     * Sets the command area.
     */
    public void setCommandArea(CommandArea commandArea)
    {
        _commandArea = commandArea;
    }

    /**
     * Returns the command area.
     */
    public CommandArea getCommandArea()
    {
        return _commandArea;
    }

    /**
     * Sets whether the stereo mode.
     */
    public void setStereo(boolean stereo)
    {
        _stereo = stereo;
    }

    /**
     * Returns whether the stereo mode.
     */
    public boolean isStereo()
    {
        return _stereo;
    }

    /**
     * Returns the size of the 3D-rendering panel.
     */
    public Dimension getImageSize() {
        Dimension d = _canvasL.getSize();
        if (_stereo) {
            d.setSize(2 * d.width, d.height);
        }
        return d;
    }

    /**
     * Creates the components.
     */
    public abstract void create(Container container);

    /**
     * Initializes the components.
     */
    public abstract void initialize(Container container);

    /**
     * Initialize stereo.
     */
    public abstract void initializeStereo();
}

