/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.manipulators;

import org.pdbj.viewer.molecules.*;
import org.pdbj.viewer.images.*;

/**
* Class that represents comparison operators expressions for atoms.
*/
public class AtomComparisonExpr extends ComparisonExpr
{
    public static final int INDEX_ELEMNO      = 0;
    public static final int INDEX_ATOMNO      = 1;
    public static final int INDEX_RESNO       = 2;
    public static final int INDEX_RADIUS      = 3;
    public static final int INDEX_TEMPERATURE = 4;
    public static final int INDEX_MODEL       = 5;
    public static final int INDEX_FILE        = 6;
    
    private static String[] _itemNames
        = {
            "ELEMNO",
            "ATOMNO",
            "RESNO",
            "RADIUS",
            "TEMPERATURE",
            "MODEL",
            "FILE"
        };

    private int _index;

    /**
    * Returnd the number of comparable items.
    */
    public static int counts()
    {
        return _itemNames.length;
    }

    /**
    * Returns the index of the comparable item speciied by name.
    */
    public static int getIndex(String itemName)
    {
        String name = itemName.toUpperCase();
        for(int i=0; i<_itemNames.length; i++){
            if( name.equals(_itemNames[i]) ) return i;
        }
        return -1;
    }

    /**
    * Returns the name of the speciied comparable item.
    */
    public static String getName(int index)
    {
        return _itemNames[index];
    }

    /**
    * Sets the index of comparable items.
    */
    public void setIndex(int index)
    {
        _index = index;
    }

    /**
    * Returns the index of comparable items.
    */
    public int getIndex()
    {
        return _index;
    }

    /**
    * Constructor.
    */
    public AtomComparisonExpr(int index, int operatorType, float value)
    {
        super(operatorType, value);
        _index = index;
    }

    /**
    * Tests whether the specified atom matches the expression.
    */
    public boolean match(AtomPath atomPath)
    {
        Molecule molecule = atomPath.getMolecule();
        Residue residue   = atomPath.getResidue();
        Atom atom         = atomPath.getAtom();

        switch(_index)
        {
            case INDEX_ELEMNO:
                return compare( atom.getAtomicNo() );

            case INDEX_ATOMNO:
                return compare( atom.getId() );

            case INDEX_RESNO:
                return compare( residue.getId() );

            case INDEX_RADIUS:
                if(atom.getImage().getModel() == AtomImage.MODEL_SPACEFILL){
                    return compare( atom.getImage().getRadius() );
                }
                else{
                    return false;
                }

            case INDEX_TEMPERATURE:
                return compare( atom.getTempFactor() );

            case INDEX_MODEL:
                return compare( molecule.getModelId() );

            case INDEX_FILE:
                return compare( molecule.getFile().getFileId() );

            default:
                return false;
        }
    }
}

