/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.manipulators;

import java.util.ArrayList;
import org.pdbj.viewer.utils.*;
import org.pdbj.viewer.molecules.*;

/**
* Class that represents within expressions.
*/
public class AtomWithinExpr extends DistanceExpr
{
    private float _distance;
    private float _distanceSquared;

    private Vector4f _v1 = new Vector4f();
    
    /**
    * Sets the distance.
    */
    public void setDistance(float distance)
    {
        _distance = distance; 
        _distanceSquared = distance*distance; 
    }

    /**
    * Returns the distance.
    */
    public float getDistance()
    {
        return _distance;
    }

    /**
    * Constructor.
    */
    public AtomWithinExpr(SelectExpr atomExpr, float distance)
    {
        super.setAtomExpr(atomExpr);
        this.setDistance(distance);
    }
    
    /**
    * Tests whether the specified atom matches the expression.
    */
    public boolean match(AtomPath atomPath)
    {
        Atom atom = atomPath.getAtom();
        _v1.x = atom.getX();
        _v1.y = atom.getY();
        _v1.z = atom.getZ();
        _v1.w = 1;
        _v1.transform( atomPath.getMolecule().getImage().getTransform() );

        ArrayList list = super.getCoordinates();
        for(int i=0; i<list.size(); i++)
        {
            Vector4f curr = (Vector4f)list.get(i);
            
            float dx = curr.x - _v1.x;
            float dist = dx*dx;
            if(dist > _distanceSquared) continue;            

            float dy = curr.y - _v1.y;
            dist += dy*dy;
            if(dist > _distanceSquared) continue;            

            float dz = curr.z - _v1.z;
            dist += dz*dz;
            if(dist <= _distanceSquared){
                return true;
            }            
        }

        return false;
    }
}

