/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.manipulators;

import java.util.*;

/**
 * Backbone atom set.
 */
public class BackboneAtomSet {

    private Map _residues;

    /**
     * Constructor.
     */
    public BackboneAtomSet() {
        _residues = new LinkedHashMap();
    }

    /**
     * Sets backbone atoms.
     */
    public void setBackboneAtoms(String residueName, String[] atomNames) {
        _residues.put(residueName, new LinkedHashSet(Arrays.asList(atomNames)));
    }

    /**
     * Clears backbone atoms.
     */
    public void clearBackboneAtoms(String residueName) {
        _residues.remove(residueName);
    }

    /**
     * Returns whether the passed atom is backbone atom for the specified residue.
     */
    public boolean isBackboneAtom(String residueName, String atomName) {
        Set atoms = (Set) _residues.get(residueName);
        return atoms != null && atoms.contains(atomName);
    }

    /**
     * Returns whether the backbone atoms are defined for the specified residue.
     */
    public boolean isDefined(String residueName) {
        return _residues.get(residueName) != null;
    }

    /**
     * Returns the defined residues. 
     */
    public List getDefinedResidueNames() {
        return new ArrayList(_residues.keySet());
    }

    /**
     * Returns the backbone atoms. 
     */
    public List getBackboneAtoms(String residueName) {
        Set atoms = (Set) _residues.get(residueName);        
        return atoms != null ? new ArrayList(atoms) : null;
    }

    /**
     * Returns the backbone atoms formatted. 
     */
    public String getBackboneAtomsFormatted(String residueName) {
        List atoms = getBackboneAtoms(residueName);
        if (atoms != null) {
            Iterator it = atoms.iterator();
            StringBuffer sb = new StringBuffer();
            sb.append(it.next());
            while (it.hasNext()) {
                sb.append(",").append(it.next());
            }
            return sb.toString();
        } else {
            return null;
        }
    }
}
