/*
 * Modified at March 2014.
 * RIKEN, Japan
 */

/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.manipulators;

import java.awt.Color;

/**
* Expression of colors.
*/
public class ColorExpr
{
    public static final int TARGET_ATOM         = 0;
    public static final int TARGET_BOND         = 1;
    public static final int TARGET_BACKBONE     = 2;
    public static final int TARGET_HBOND        = 3;
    public static final int TARGET_SSBOND       = 4;
    public static final int TARGET_RESIDUE      = 5;
    public static final int TARGET_RESIDUE_BACK = 6;

    public static final int SCHEME_RGB         = 0;
    public static final int SCHEME_AMINO       = 1;
    public static final int SCHEME_CHAIN       = 2;
    public static final int SCHEME_CHARGE      = 3;
    public static final int SCHEME_CPK         = 4;
    public static final int SCHEME_GROUP       = 5;
    public static final int SCHEME_SHAPELY     = 6;
    public static final int SCHEME_STRUCTURE   = 7;
    public static final int SCHEME_TEMPERATURE = 8;
    public static final int SCHEME_TYPE        = 9;
    public static final int SCHEME_DEFAULT     = 10;
    public static final int SCHEME_DSSP        = 11;

    private int   _target;
    private int   _scheme;
    private Color _color;

    /**
    * Sets the target to be colored.
    */
    public void setTarget(int target)
    {
        _target = target;
    }

    /**
    * Returns the target to be colored.
    */
    public int getTarget()
    {
        return _target;
    }

    /**
    * Sets the color scheme.
    */
    public void setScheme(int scheme)
    {
        _scheme = scheme;
    }

    /**
    * Returns the color scheme.
    */
    public int getScheme()
    {
        return _scheme;
    }

    /**
    * Sets the color for RGB-value scheme.
    */
    public void setColor(Color color)
    {
        _color = color;
    }

    /**
    * Returns the color for RGB-value scheme.
    */
    public Color getColor()
    {
        return _color;
    }
}
