/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.manipulators;

/**
 * Class that represents comparison operators expressions.
 */
public abstract class ComparisonExpr extends SelectExpr
{
    public static final int OP_EQUAL         = 0;
    public static final int OP_NOT_EQUAL     = 1;
    public static final int OP_LARGER        = 2;
    public static final int OP_LARGER_EQUAL  = 3;
    public static final int OP_SMALLER       = 4;
    public static final int OP_SMALLER_EQUAL = 5;

    private int   _operatorType;
    private float _value;

    /**
    * Sets the operator type.
    */
    public void setOperatorType(int operatorType)
    {
        _operatorType = operatorType;
    }

    /**
    * Returns the operator type.
    */
    public int getOperatorType()
    {
        return _operatorType;
    }

    /**
    * Sets the value to be compared.
    */
    public void setValue(float value)
    {
        _value = value;
    }

    /**
    * Returns the value to be compared.
    */
    public float getValue()
    {
        return _value;
    }

    /**
    * Constructor.
    */
    public ComparisonExpr(int operatorType, float value)
    {
        _operatorType = operatorType;
        _value        = value;
    }

    /**
    * Compares.
    */
    public boolean compare(float currValue)
    {
        switch(_operatorType)
        {
            case OP_EQUAL:
                return (currValue == _value);

            case OP_NOT_EQUAL:
                return (currValue != _value);

            case OP_LARGER:
                return (currValue > _value);

            case OP_LARGER_EQUAL:
                return (currValue >= _value);

            case OP_SMALLER:
                return (currValue < _value);

            case OP_SMALLER_EQUAL:
                return (currValue <= _value);

            default:
                return false;
        }
    }
}
