/*
 * Modified at March 2014.
 * RIKEN, Japan
 */

/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.manipulators;

import java.util.ArrayList;
import org.pdbj.viewer.utils.*;
import org.pdbj.viewer.molecules.*;

/**
 * Class that represents expressions by distance.
 */
public abstract class DistanceExpr extends SelectExpr
{
    private SelectExpr _atomExpr;
    private ArrayList _coordinates;

    /**
    * Constructor.
    */
    public DistanceExpr()
    {
        _coordinates = new ArrayList();
    }
    
    /**
    * Sets the atoms from which distance is measured.
    */
    public void setAtomExpr(SelectExpr expr)
    {
        _atomExpr = expr;
    }

    /**
    * Returns the atoms from which distance is measured.
    */
    public SelectExpr getAtomExpr()
    {
        return _atomExpr;
    }

    /**
    * Initialize.
    */
    public void setup(MoleculeFile[] moleculeFiles)
    {
        if(_atomExpr != null){
            _atomExpr.setup(moleculeFiles);
            this.setupCoordinates(moleculeFiles);
        }
    }

    /**
    * Returns the collection of coordinates.
    */
    public ArrayList getCoordinates()
    {
        return _coordinates;
    }

    //----------------------------------------------------------------------
    // Coordinates
    //----------------------------------------------------------------------
    private void setupCoordinates(MoleculeFile[] moleculeFiles)
    {
        AtomPath atomPath = new AtomPath();

        for(int i=0; i<moleculeFiles.length; i++)
        {
            MoleculeFile file = moleculeFiles[i];
            atomPath.setMoleculeFile(file);

            //for(int m=0; m<file.numMolecules(); m++)
            //{
                //Molecule molecule = file.getMolecule(m);
                Molecule molecule = file.getMolecule(file.getCurrentFrame());
                atomPath.setMolecule(molecule);

                for(int ch=0; ch<molecule.numChains(); ch++)
                {
                    Chain chain = molecule.getChain(ch);
                    atomPath.setChain(chain);

                    for(int re=0; re<chain.numResidues(); re++)
                    {
                        Residue residue = chain.getResidue(re);
                        atomPath.setResidue(residue);

                        for(int at=0; at<residue.numAtoms(); at++)
                        {
                            Atom atom = residue.getAtom(at);
                            atomPath.setAtom(atom);

                            if(_atomExpr.match(atomPath)){
                                Vector4f v = new Vector4f(
                                    atom.getX(), atom.getY(), atom.getZ(), 1
                                );
                                v.transform( molecule.getImage().getTransform() );
                                _coordinates.add(v);
                            }
                        }
                    }
                }
            //}
        }
    }
}
