/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.manipulators;

import org.pdbj.viewer.molecules.*;
import org.pdbj.viewer.polygons.*;

/**
* Class that represents logical-or expressions.
*/
public class OrExpr extends SelectExpr
{
    private SelectExpr _left;
    private SelectExpr _right;

    /**
    * Sets the left child node.
    */
    public void setLeftChild(SelectExpr left)
    {
        _left = left;
    }

    /**
    * Returns the left child node.
    */
    public SelectExpr getLeftChild()
    {
        return _left;
    }

    /**
    * Sets the right child node.
    */
    public void setRightChild(SelectExpr right)
    {
        _right = right;
    }

    /**
    * Returns the right child node.
    */
    public SelectExpr getRightChild()
    {
        return _right;
    }

    /**
    * Initialize.
    */
    public void setup(MoleculeFile[] moleculeFiles)
    {
        _left.setup(moleculeFiles);
        _right.setup(moleculeFiles);
    }

    /**
    * Tests whether the specified atom matches the expression.
    */
    public boolean match(AtomPath atomPath)
    {
        return _left.match(atomPath) || _right.match(atomPath);
    }

    /**
    * Tests whether the specified vertex matches the expression.
    */
    public boolean match(PolygonFile file, int vertexIndex)
    {
        return _left.match(file, vertexIndex) || _right.match(file, vertexIndex);
    }
}
