/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.manipulators;

import org.pdbj.viewer.molecules.*;

/**
* Class that represents residue range expressions.
*/
public class ResidueRangeExpr extends SelectExpr
{
    private int _initResidueId;
    private int _termResidueId;

    private String _chainId;

    /**
    * Sets the initial residue ID.
    */
    public void setInitResidueId(int initId)
    {
        _initResidueId = initId;
    }

    /**
    * Returns the initial residue ID.
    */
    public int getInitResidueId()
    {
        return _initResidueId;
    }

    /**
    * Sets the terminal residue ID.
    */
    public void setTermResidueId(int termId)
    {
        _termResidueId = termId;
    }

    /**
    * Returns the terminal residue ID.
    */
    public int getTermResidueId()
    {
        return _termResidueId;
    }

    /**
    * Sets the chain ID.
    */
    public void setChainId(String chainId)
    {
        _chainId = chainId;
    }

    /**
    * Returns the chain ID.
    */
    public String getChainId()
    {
        return _chainId;
    }

    /**
    * Constructor.
    */
    public ResidueRangeExpr(int initResidueId, int termResidueId)
    {
        _initResidueId = initResidueId;
        _termResidueId = termResidueId;
    }

    /**
    * Constructor.
    */
    public ResidueRangeExpr(int initResidueId, int termResidueId, String chainId)
    {
        _initResidueId = initResidueId;
        _termResidueId = termResidueId;
        _chainId = chainId;
    }

    /**
    * Tests whether the specified atom matches the expression.
    */
    public boolean match(AtomPath atomPath)
    {
        return ( atomPath.getResidue().getId() >= _initResidueId && 
                 atomPath.getResidue().getId() <= _termResidueId &&
                 this.testChain(atomPath) );
    }
    
    private boolean testChain(AtomPath atomPath)
    {
        if( _chainId == null || _chainId.equals("*") ) return true;
        
        return PrimitiveExpr.compareChain(_chainId, atomPath.getChain());
    }
}

