/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.manipulators;

import java.util.*;
import org.pdbj.viewer.molecules.*;
import org.pdbj.viewer.site.*;

/**
 * Class that represents site expressions.
 */
public class SiteExpr extends SelectExpr {
    private String _prefix;
    private String _db;
    private String _category;
    private HashMap _map;
    
    /**
     * Constructs an instance.
     */
    public SiteExpr() {
    }

    /**
     * Constructs an instance.
     */
    public SiteExpr(String prefix, String db, String category) {
        _prefix = prefix;
        _db = db;
        _category = category;
    }

    /**
     * Sets the prefix.
     */
    public void setPrefix(String prefix) {
        _prefix = prefix;
    }

    /**
     * Returns the prefix.
     */
    public String getPrefix() {
        return _prefix;
    }

    /**
     * Sets the db.
     */
    public void setDb(String db) {
        _db = db;
    }

    /**
     * Returns the db.
     */
    public String getDb() {
        return _db;
    }

    /**
     * Sets the category.
     */
    public void setCategory(String category) {
        _category = category;
    }

    /**
     * Returns the category.
     */
    public String getCategory() {
        return _category;
    }

    /**
     * Initialize.
     */
    public void setup(MoleculeFile[] moleculeFiles) {
        _map = new HashMap();
        for (int i = 0; i < moleculeFiles.length; i++) {
            MoleculeFile file = moleculeFiles[i];
            if (file.isAnimation()) {
                continue;
            }
            SiteList siteList = file.getSiteList(_prefix);
            if (siteList == null || siteList == SiteList.UNDEFINED) {
                continue;
            }
            List list = new ArrayList();
            Iterator it = siteList.iterator();
            while (it.hasNext()) {
                Site site = (Site) it.next();
                String db = site.getDb().toLowerCase();
                String category = site.getCategory().toLowerCase();
                if (!_db.equals("") && !_db.equals(db)) {
                    continue;
                }
                if (!_category.equals("") && !_category.equals(category)) {
                    continue;
                }
                list.add(site);
            }
            _map.put(file, list);
        }
    }

    /**
     * Tests whether the specified atom matches the expression.
     */
    public boolean match(AtomPath atomPath) {
        List list = (List) _map.get(atomPath.getMolecule().getFile());
        if (list != null) {
            Iterator it1 = list.iterator();
            while (it1.hasNext()) {
                Site site = (Site) it1.next();
                Iterator it2 = site.iterator();
                while (it2.hasNext()) {
                    Region region = (Region) it2.next();
                    String chainId = atomPath.getChain().getId();
                    if (region.getChainId().equals(chainId)) {
                        int seq = atomPath.getResidue().getId();
                        int init = region.getInitSeqId();
                        int term = region.getTermSeqId();
                        if (seq >= init && seq <= term) {
                            return true;
                        }
                    }
                }
            }
        }
        return false;
    }
}
