/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.manipulators;

import org.pdbj.viewer.polygons.*;

/**
 * Class that represents comparison operators expressions for vertices.
 */
public class VertexComparisonExpr extends ComparisonExpr
{
    public static final int INDEX_FILE = 0;
    public static final int INDEX_ID   = 1;

    private static String[] _itemNames = { "FILE", "ID" };

    private int    _index;
    private String _name;

    /**
    * Returns the number of comparable items.
    */
    public static int counts()
    {
        return _itemNames.length;
    }

    /**
    * Returns the index of the comparable item specified by name.
    */
    public static int getIndex(String itemName)
    {
        String name = itemName.toUpperCase();
        for(int i=0; i<_itemNames.length; i++){
            if( name.equals(_itemNames[i]) ) return i;
        }
        return -1;
    }

    /**
    * Returns the name of the specified comparable item.
    */
    public static String getName(int index)
    {
        return _itemNames[index];
    }

    /**
    * Sets the index of comparable items.
    */
    public void setIndex(int index)
    {
        _index = index;
    }

    /**
    * Returns the index of comparable items.
    */
    public int getIndex()
    {
        return _index;
    }

    /**
    * Constructor.
    */
    public VertexComparisonExpr(int index, int operatorType, float value)
    {
        super(operatorType, value);
        _index = index;
    }

    /**
    * Constructor.
    */
    public VertexComparisonExpr(String name, int operatorType, float value)
    {
        super(operatorType, value);
        _name = name;
        _index = -1;
    }

    /**
    * Tests whether the specified vertex matches the expression.
    */
    public boolean match(PolygonFile file, int vertexIndex)
    {
        Vertices vertices = file.getVertices();
        if(_index == -1){
            int dataIndex = file.getUserDataIndex(_name);
            if(dataIndex != -1){
                float value = vertices.getUserData(vertexIndex, dataIndex);
                if(value != Float.NEGATIVE_INFINITY) return compare(value);
            }
        }
        else{
            switch(_index)
            {
                case INDEX_FILE:
                    return compare( file.getFileId() );

                case INDEX_ID:
                    return compare( vertices.getId(vertexIndex) );
            }
        }
        return false;
    }
}
