/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.manipulators;

import java.util.*;
import org.pdbj.viewer.molecules.*;
import org.pdbj.viewer.plus.*;

/**
 * Class that represents xPSSS expressions.
 */
public class XpsssExpr extends SelectExpr
{
    private String _type;
    private HashMap _hashMap;

    /**
    * Sets the type.
    */
    public void setType(String type)
    {
        _type = type;
    }

    /**
    * Returns the type.
    */
    public String getType()
    {
        return _type;
    }

    /**
    * Constructor.
    */
    public XpsssExpr(String type)
    {
        _type = type;
    }

    /**
    * Initialize.
    */
    public void setup(MoleculeFile[] moleculeFiles)
    {
        _hashMap = new HashMap();
        for(int i=0; i<moleculeFiles.length; i++)
        {
            MoleculeFile file = moleculeFiles[i];
            if( file.isAnimation() ) continue;

            Function function = file.getFunction();
            if(function == null || function == Function.UNDEFINED) continue;
            
            ArrayList list = new ArrayList();
            for(int j=0; j<function.numStructSites(); j++)
            {
                StructSite site = function.getStructSite(j);
                
                String infoType = site.getInfoType();
                String infoSubType = site.getInfoSubType();
                
                if( testType(infoType) || testType(infoSubType) )
                {
                    for(int k=0; k<site.numStructSiteGens(); k++)
                    {
                        list.add( site.getStructSiteGen(k) );
                    }
                }
            }
            _hashMap.put(file, list);
        }
    }

    private boolean testType(String type)
    {
        if(type != null && !type.equals(""))
        {
            if( type.equalsIgnoreCase(_type) )
            {
                return true;
            }
        }
        
        return false;
    }
    
    /**
    * Tests whether the specified atom matches the expression.
    */
    public boolean match(AtomPath atomPath)
    {
        ArrayList list = (ArrayList)_hashMap.get( atomPath.getMolecule().getFile() );
        if(list != null){
            for(int i=0; i<list.size(); i++){
                StructSiteGen siteGen = (StructSiteGen)list.get(i);
                if( siteGen.getAuthAsymId().equals(atomPath.getChain().getId()) ){
                    int init = siteGen.getInitSeqId();
                    int term = siteGen.getTermSeqId();
                    int seq = atomPath.getResidue().getId();
                    if(seq >= init && seq <= term) return true;
                }
            }
        }
        return false;
    }

}
