/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.moleculebuilders;

/**
* Represents atom records in PDB or PDBML files.
*/
public class AtomRecord
{
    public static final String NO_MODEL_ID = "NO_MODEL_ID";

    private String _id;
    private String _mdlId;
    private String _labelAsymId;
    private String _authAsymId;
    private String _seqId;
    private String _altId;
    private String _compId;
    private String _typeSymbol;
    private String _atomId;
    private String _cartnX;
    private String _cartnY;
    private String _cartnZ;
    private String _occupancy;
    private String _bFactor;
    private char   _insCode;

    /**
    * Sets the atom ID.
    */
    public void setId(String id)
    {
        _id = id;
    }

    /**
    * Returns the atom ID.
    */
    public String getId()
    {
        return _id;
    }

    /**
    * Sets the model ID.
    */
    public void setMdlId(String mdlId)
    {
        _mdlId = mdlId;
    }

    /**
    * Returns the model ID.
    */
    public String getMdlId()
    {
        return _mdlId;
    }

    /**
     * Sets the label chain ID.
     */
    public void setLabelAsymId(String labelAsymId) {
        _labelAsymId = labelAsymId;
    }

    /**
     * Returns the label chain ID.
     */
    public String getLabelAsymId() {
        return _labelAsymId;
    }

    /**
    * Sets the auth chain ID.
    */
    public void setAuthAsymId(String authAsymId)
    {
        _authAsymId = authAsymId;
    }

    /**
    * Returns the auth chain ID.
    */
    public String getAuthAsymId()
    {
        return _authAsymId;
    }

    /**
    * Sets the residue ID.
    */
    public void setSeqId(String seqId)
    {
        _seqId = seqId;
    }

    /**
    * Returns the residue ID.
    */
    public String getSeqId()
    {
        return _seqId;
    }

    /**
    * Sets the altLoc.
    */
    public void setAltId(String altId)
    {
        _altId = altId;
    }

    /**
    * Returns the altLoc.
    */
    public String getAltId()
    {
        return _altId;
    }

    /**
    * Sets the residue name.
    */
    public void setCompId(String compId)
    {
        _compId = compId;
    }

    /**
    * Returns the residue name.
    */
    public String getCompId()
    {
        return _compId;
    }

    /**
    * Sets the element symbol.
    */
    public void setTypeSymbol(String typeSymbol)
    {
        _typeSymbol = typeSymbol;
    }

    /**
    * Returns the element symbol.
    */
    public String getTypeSymbol()
    {
        return _typeSymbol;
    }

    /**
    * Sets the atom name.
    */
    public void setAtomId(String atomId)
    {
        _atomId = atomId;
    }

    /**
    * Returns the atom name.
    */
    public String getAtomId()
    {
        return _atomId;
    }

    /**
    * Sets the coordinate x.
    */
    public void setCartnX(String cartnX)
    {
        _cartnX = cartnX;
    }

    /**
    * Returns the coordinate x.
    */
    public String getCartnX()
    {
        return _cartnX;
    }

    /**
    * Sets the coordinate y.
    */
    public void setCartnY(String cartnY)
    {
        _cartnY = cartnY;
    }

    /**
    * Returns the coordinate y.
    */
    public String getCartnY()
    {
        return _cartnY;
    }

    /**
    * Sets the coordinate z.
    */
    public void setCartnZ(String cartnZ)
    {
        _cartnZ = cartnZ;
    }

    /**
    * Returns the coordinate z.
    */
    public String getCartnZ()
    {
        return _cartnZ;
    }

    /**
    * Sets the occupancy.
    */
    public void setOccupancy(String occupancy)
    {
        _occupancy = occupancy;
    }

    /**
    * Returns the occupancy.
    */
    public String getOccupancy()
    {
        return _occupancy;
    }

    /**
    * Sets the temperature factor.
    */
    public void setBFactor(String bFactor)
    {
        _bFactor = bFactor;
    }

    /**
    * Returns the temperature factor.
    */
    public String getBFactor()
    {
        return _bFactor;
    }

    /**
    * Sets the insCode.
    */
    public void setInsCode(char insCode)
    {
        _insCode = insCode;
    }

    /**
    * Returns the insCode.
    */
    public char getInsCode()
    {
        return _insCode;
    }

    /**
     * Clears.
     */
    public void clear()
    {
        _id          = "";
        _mdlId       = "";
        _labelAsymId = "";
        _authAsymId  = "";
        _seqId       = "";
        _altId       = "";
        _compId      = "";
        _typeSymbol  = "";
        _atomId      = "";
        _cartnX      = "";
        _cartnY      = "";
        _cartnZ      = "";
        _occupancy   = "";
        _bFactor     = "";
        _insCode     = ' ';
    }

    /**
     * Constructor.
     */
    public AtomRecord()
    {
        this.clear();
    }
}
