/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.molecules;

/**
 * Class that holds object path from MoleculeFile to Atom.
 */
public class AtomPath
{
    private MoleculeFile _moleculeFile;
    private Molecule     _molecule;
    private Chain        _chain;
    private Residue      _residue;
    private Atom         _atom;

    /**
     * Sets the MoleculeFile object.
     */
    public void setMoleculeFile(MoleculeFile moleculeFile)
    {
        _moleculeFile = moleculeFile;
    }

    /**
     * Returns the MoleculeFile object.
     */
    public MoleculeFile getMoleculeFile()
    {
        return _moleculeFile;
    }

    /**
     * Sets the Molecule object.
     */
    public void setMolecule(Molecule molecule)
    {
        _molecule = molecule;
    }

    /**
     * Returns the Molecule object.
     */
    public Molecule getMolecule()
    {
        return _molecule;
    }

    /**
     * Sets the Chain object.
     */
    public void setChain(Chain chain)
    {
        _chain = chain;
    }

    /**
     * Returns the Chain object.
     */
    public Chain getChain()
    {
        return _chain;
    }

    /**
     * Sets the Residue object.
     */
    public void setResidue(Residue residue)
    {
        _residue = residue;
    }

    /**
     * Returns the Residue object.
     */
    public Residue getResidue()
    {
        return _residue;
    }

    /**
     * Sets the Atom object.
     */
    public void setAtom(Atom atom)
    {
        _atom = atom;
    }

    /**
     * Returns the Atom object.
     */
    public Atom getAtom()
    {
        return _atom;
    }

    /**
     * When the specified MoleculeFile has the specified Atom,
     * returns AtomPath object. Otherwise, returns null.
     */
    public static AtomPath find(MoleculeFile moleculeFile, Atom atom)
    {
        for(int i=0; i<moleculeFile.numMolecules(); i++)
        {
            Molecule molecule = moleculeFile.getMolecule(i);
            AtomPath atomPath = find(molecule, atom);
            if(atomPath != null) return atomPath;
        }
        return null;
    }

    /**
     * When the specified Molecule has the specified Atom,
     * returns AtomPath object. Otherwise, returns null.
     */
    public static AtomPath find(Molecule molecule, Atom atom)
    {
        for(int ch=0; ch<molecule.numChains(); ch++)
        {
        Chain chain = molecule.getChain(ch);
        for(int re=0; re<chain.numResidues(); re++)
        {
        Residue residue = chain.getResidue(re);
        for(int at=0; at<residue.numAtoms(); at++)
        {
            Atom currAtom = residue.getAtom(at);
            if(currAtom == atom){
                AtomPath atomPath = new AtomPath();
                atomPath.setMoleculeFile(molecule.getFile());
                atomPath.setMolecule(molecule);
                atomPath.setChain(chain);
                atomPath.setResidue(residue);
                atomPath.setAtom(atom);

                return atomPath;
            }
        }}}
        return null;
    }
}

