/*
 * This source code is a derived work of jV version 4.3.1 licensed as below.
 * March 2014
 * RIKEN, Japan
 */

/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.molecules;

import org.pdbj.viewer.utils.Vector3f;

public class BackboneTraj extends Bond {

    private MoleculeTraj _molecule;
    private int _chain;
    private int _idx;

    public BackboneTraj(MoleculeTraj molecule, int chain, int idx) {
        _molecule = molecule;
        _chain = chain;
        _idx = idx;
    }

    /**
     * Sets the direction vector.
     */
    public void setDirection(Vector3f v)
    {
        _molecule.getCurrFrame().getBackboneDirectionX()[_chain][_idx] = v.x;
        _molecule.getCurrFrame().getBackboneDirectionY()[_chain][_idx] = v.y;
        _molecule.getCurrFrame().getBackboneDirectionZ()[_chain][_idx] = v.z;
    }

    /**
     * Returns the direction vector.
     */
    public void getDirection(Vector3f v)
    {
        v.x = _molecule.getCurrFrame().getBackboneDirectionX()[_chain][_idx];
        v.y = _molecule.getCurrFrame().getBackboneDirectionY()[_chain][_idx];
        v.z = _molecule.getCurrFrame().getBackboneDirectionZ()[_chain][_idx];
    }

    /**
    * Sets the normal vector.
    */
    public void setNormal(Vector3f v)
    {
        _molecule.getCurrFrame().getBackboneNormalX()[_chain][_idx] = v.x;
        _molecule.getCurrFrame().getBackboneNormalY()[_chain][_idx] = v.y;
        _molecule.getCurrFrame().getBackboneNormalZ()[_chain][_idx] = v.z;
    }

    /**
    * Returns the normal vector.
    */
    public void getNormal(Vector3f v)
    {
        v.x = _molecule.getCurrFrame().getBackboneNormalX()[_chain][_idx];
        v.y = _molecule.getCurrFrame().getBackboneNormalY()[_chain][_idx];
        v.z = _molecule.getCurrFrame().getBackboneNormalZ()[_chain][_idx];
    }

    /**
    * Sets the distance.
    */
    public void setDistance(float distance)
    {
        _molecule.getCurrFrame().getBackboneDistance()[_chain][_idx] = distance;
    }

    /**
    * Returns the distance.
    */
    public float getDistance()
    {
        return _molecule.getCurrFrame().getBackboneDistance()[_chain][_idx];
    }
}
