/*
 * Modified at March 2014.
 * RIKEN, Japan
 */

/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.molecules;

import java.util.ArrayList;

/**
 * A representation of a chain.
 */
public abstract class Chain
{
    private String _id;
    private String _labelId;

    private ArrayList _residues;
    private ArrayList _backbones;

    /**
     * Constructs a Chain object.
     */
    public Chain()
    {
        _residues = new ArrayList();
        _backbones = new ArrayList();
    }

    /**
     * Sets the chain ID.
     */
    public void setId(String id)
    {
        _id = id;
    }

    /**
     * Returns the chain ID.
     */
    public String getId()
    {
        return _id;
    }

    /**
     * Sets the label chain ID.
     */
    public void setLabelId(String labelId) {
        _labelId = labelId;
    }

    /**
     * Returns the label chain ID.
     */
    public String getLabelId() {
        return _labelId;
    }

    /**
     * Returns the collection of residues.
     */
    public ArrayList getResidues()
    {
        return _residues;
    }

    /**
     * Returns the collection of backbone bonds.
     */
    public ArrayList getBackbones()
    {
        return _backbones;
    }

    /**
     * Appends a residue.
     */
    public void addResidue(Residue residue)
    {
        _residues.add(residue);
    }

    /**
     * Returns the number of residues.
     */
    public int numResidues()
    {
        return _residues.size();
    }

    /**
     * Returns the residue at the specified index.
     */
    public Residue getResidue(int index)
    {
        return (Residue)_residues.get(index);
    }

    /**
     * Appends a backbone bond.
     */
    public void addBackbone(Bond bond)
    {
        _backbones.add(bond);
    }

    /**
     * Returns the number of backbone bonds.
     */
    public int numBackbones()
    {
        return _backbones.size();
    }

    /**
     * Returns the backbone bond at the specified index.
     */
    public Bond getBackbone(int index)
    {
        return (Bond)_backbones.get(index);
    }

    /**
     * Sets whether the ribbon can be drawn.
     */
    public abstract void setRibbonDrawable(boolean ribbonDrawable);

    /**
     * Returns whether the ribbon can be drawn.
     */
    public abstract boolean isRibbonDrawable();

    public Bond appendBackbone() {
        Bond bond = createBackbone();
        _backbones.add(bond);
        return bond;
    }

    protected abstract Bond createBackbone();
}

