/*
 * This source code is a derived work of jV version 4.3.1 licensed as below.
 * March 2014
 * RIKEN, Japan
 */

/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.molecules;

public class MoleculeCommonData {

    private float _centerX;
    private float _centerY;
    private float _centerZ;
    private float _radius;
    private float _maxX;
    private float _maxY;
    private float _maxZ;
    private float _minX;
    private float _minY;
    private float _minZ;
    private int _selectAtomCount;

    /**
     * Constructor.
     */
    public MoleculeCommonData(Molecule molecule)
    {
        _centerX = molecule.getCenterX();
        _centerY = molecule.getCenterY();
        _centerZ = molecule.getCenterZ();
        _radius = molecule.getRadius();
        _maxX = molecule.getMaxX();
        _maxY = molecule.getMaxY();
        _maxZ = molecule.getMaxZ();
        _minX = molecule.getMinX();
        _minY = molecule.getMinY();
        _minZ = molecule.getMinZ();
        _selectAtomCount = molecule.getSelectAtomCount();
    }

    /**
     * Sets the x coordinate at the center of the molecule.
     */
    public void setCenterX(float centerX)
    {
        _centerX = centerX;
    }

    /**
     * Returns the x coordinate at the center of the molecule.
     */
    public float getCenterX()
    {
        return _centerX;
    }

    /**
     * Sets the y coordinate at the center of the molecule.
     */
    public void setCenterY(float centerY)
    {
        _centerY = centerY;
    }

    /**
     * Returns the y coordinate at the center of the molecule.
     */
    public float getCenterY()
    {
        return _centerY;
    }

    /**
     * Sets the z coordinate at the center of the molecule.
     */
    public void setCenterZ(float centerZ)
    {
        _centerZ = centerZ;
    }

    /**
     * Returns the z coordinate at the center of the molecule.
     */
    public float getCenterZ()
    {
        return _centerZ;
    }

    /**
     * Sets the radius of the molecule.
     */
    public void setRadius(float radius)
    {
        _radius = radius;
    }

    /**
     * Returns the radius of the molecule.
     */
    public float getRadius()
    {
        return _radius;
    }

    /**
     * Sets the minimum value of the x coordinate.
     */
    public void setMinX(float minX)
    {
        _minX = minX;
    }

    /**
     * Returns the minimum value of the x coordinate.
     */
    public float getMinX()
    {
        return _minX;
    }

    /**
     * Sets the minimum value of the y coordinate.
     */
    public void setMinY(float minY)
    {
        _minY = minY;
    }

    /**
     * Returns the minimum value of the y coordinate.
     */
    public float getMinY()
    {
        return _minY;
    }

    /**
     * Sets the minimum value of the z coordinate.
     */
    public void setMinZ(float minZ)
    {
        _minZ = minZ;
    }

    /**
     * Returns the minimum value of the z coordinate.
     */
    public float getMinZ()
    {
        return _minZ;
    }

    /**
     * Sets the maximum value of the x coordinate.
     */
    public void setMaxX(float maxX)
    {
        _maxX = maxX;
    }

    /**
     * Returns the maximum value of the x coordinate.
     */
    public float getMaxX()
    {
        return _maxX;
    }

    /**
     * Sets the maximum value of the y coordinate.
     */
    public void setMaxY(float maxY)
    {
        _maxY = maxY;
    }

    /**
     * Returns the maximum value of the y coordinate.
     */
    public float getMaxY()
    {
        return _maxY;
    }

    /**
     * Sets the maximum value of the z coordinate.
     */
    public void setMaxZ(float maxZ)
    {
        _maxZ = maxZ;
    }

    /**
     * Returns the maximum value of the z coordinate.
     */
    public float getMaxZ()
    {
        return _maxZ;
    }

    /**
     * Sets the number of atoms selected.
     */
    public void setSelectAtomCount(int selectAtomCount)
    {
        _selectAtomCount = selectAtomCount;
    }

    /**
     * Returns the number of atoms selected.
     */
    public int getSelectAtomCount()
    {
        return _selectAtomCount;
    }
}
