/*
 * This source code is a derived work of jV version 4.3.1 licensed as below.
 * March 2014
 * RIKEN, Japan
 */

/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.molecules;

import java.util.ArrayList;

public class MoleculeImpl extends Molecule {

    private float _centerX;
    private float _centerY;
    private float _centerZ;
    private float _radius;
    private float _maxX;
    private float _maxY;
    private float _maxZ;
    private float _minX;
    private float _minY;
    private float _minZ;
    private boolean _builtHBond;
    private boolean _builtSSBond;
    private boolean _ribbonChecked;
    private int _structure;
    private int _helixCount;
    private int _strandCount;
    private int _turnCount;
    private int _selectAtomCount;

    private boolean _bondInitialized;
    private boolean _backboneInitialized;
    private boolean _hbondInitialized;
    private boolean _ssbondInitialized;
    private boolean _refreshResidue;

    private ArrayList _hbonds;
    private ArrayList _ssbonds;

    /**
     * Constructor.
     */
    public MoleculeImpl()
    {
        _hbonds  = new ArrayList();
        _ssbonds = new ArrayList();
    }

    public void setFrame(int frame) {
    }

    /**
     * Sets the x coordinate at the center of the molecule.
     */
    public void setCenterX(float centerX)
    {
        _centerX = centerX;
    }

    /**
     * Returns the x coordinate at the center of the molecule.
     */
    public float getCenterX()
    {
        return _centerX;
    }

    /**
     * Sets the y coordinate at the center of the molecule.
     */
    public void setCenterY(float centerY)
    {
        _centerY = centerY;
    }

    /**
     * Returns the y coordinate at the center of the molecule.
     */
    public float getCenterY()
    {
        return _centerY;
    }

    /**
     * Sets the z coordinate at the center of the molecule.
     */
    public void setCenterZ(float centerZ)
    {
        _centerZ = centerZ;
    }

    /**
     * Returns the z coordinate at the center of the molecule.
     */
    public float getCenterZ()
    {
        return _centerZ;
    }

    /**
     * Sets the radius of the molecule.
     */
    public void setRadius(float radius)
    {
        _radius = radius;
    }

    /**
     * Returns the radius of the molecule.
     */
    public float getRadius()
    {
        return _radius;
    }

    /**
     * Sets the minimum value of the x coordinate.
     */
    public void setMinX(float minX)
    {
        _minX = minX;
    }

    /**
     * Returns the minimum value of the x coordinate.
     */
    public float getMinX()
    {
        return _minX;
    }

    /**
     * Sets the minimum value of the y coordinate.
     */
    public void setMinY(float minY)
    {
        _minY = minY;
    }

    /**
     * Returns the minimum value of the y coordinate.
     */
    public float getMinY()
    {
        return _minY;
    }

    /**
     * Sets the minimum value of the z coordinate.
     */
    public void setMinZ(float minZ)
    {
        _minZ = minZ;
    }

    /**
     * Returns the minimum value of the z coordinate.
     */
    public float getMinZ()
    {
        return _minZ;
    }

    /**
     * Sets the maximum value of the x coordinate.
     */
    public void setMaxX(float maxX)
    {
        _maxX = maxX;
    }

    /**
     * Returns the maximum value of the x coordinate.
     */
    public float getMaxX()
    {
        return _maxX;
    }

    /**
     * Sets the maximum value of the y coordinate.
     */
    public void setMaxY(float maxY)
    {
        _maxY = maxY;
    }

    /**
     * Returns the maximum value of the y coordinate.
     */
    public float getMaxY()
    {
        return _maxY;
    }

    /**
     * Sets the maximum value of the z coordinate.
     */
    public void setMaxZ(float maxZ)
    {
        _maxZ = maxZ;
    }

    /**
     * Returns the maximum value of the z coordinate.
     */
    public float getMaxZ()
    {
        return _maxZ;
    }

    /**
     * Sets whether hydrogen bonds have been built.
     */
    public void setBuiltHBond(boolean builtHBond)
    {
        _builtHBond = builtHBond;
    }

    /**
     * Returns whether hydrogen bonds have been built.
     */
    public boolean builtHBond()
    {
        return _builtHBond;
    }

    /**
     * Sets whether disulfide bonds have been built.
     */
    public void setBuiltSSBond(boolean builtSSBond)
    {
        _builtSSBond = builtSSBond;
    }

    /**
     * Returns whether disulfide bonds have been built.
     */
    public boolean builtSSBond()
    {
        return _builtSSBond;
    }

    /**
     * Sets whether the ribbon model is checked for each chain.
     */
    public void setRibbonChecked(boolean ribbonChecked) {
        _ribbonChecked = ribbonChecked;
    }

    /**
     * Returns whether the ribbon model is checked for each chain.
     */
    public boolean isRibbonChecked() {
        return _ribbonChecked;
    }

    /**
     * Sets the structurre source.
     */
    public void setStructure(int structure)
    {
        _structure = structure;
    }

    /**
     * Returns the structure source.
     */
    public int getStructure()
    {
        return _structure;
    }

    /**
     * Sets the number of helices.
     */
    public void setHelixCount(int helixCount)
    {
        _helixCount = helixCount;
    }

    /**
     * Returns the number of helices.
     */
    public int getHelixCount()
    {
        return _helixCount;
    }

    /**
     * Sets the number of strands.
     */
    public void setStrandCount(int strandCount)
    {
        _strandCount = strandCount;
    }

    /**
     * Returns the number of strands.
     */
    public int getStrandCount()
    {
        return _strandCount;
    }

    /**
     * Sets the number of turns.
     */
    public void setTurnCount(int turnCount)
    {
        _turnCount = turnCount;
    }

    /**
     * Returns the number of turns.
     */
    public int getTurnCount()
    {
        return _turnCount;
    }

    /**
     * Sets the number of atoms selected.
     */
    public void setSelectAtomCount(int selectAtomCount)
    {
        _selectAtomCount = selectAtomCount;
    }

    /**
     * Returns the number of atoms selected.
     */
    public int getSelectAtomCount()
    {
        return _selectAtomCount;
    }

    /**
     * Sets whether bond images have been initialized.
     */
    public void setBondInitialized(boolean initialized)
    {
        _bondInitialized = initialized;
    }

    /**
     * Tests whether bond images have been initialized.
     */
    public boolean bondInitialized()
    {
        return _bondInitialized;
    }

    /**
     * Sets whether backbone images have been initialized.
     */
    public void setBackboneInitialized(boolean initialized)
    {
        _backboneInitialized = initialized;
    }
    
    /**
     * Tests whether backbone images have been initialized.
     */
    public boolean backboneInitialized()
    {
        return _backboneInitialized;
    }

    /**
     * Sets whether hbond images have been initialized.
     */
    public void setHBondInitialized(boolean initialized)
    {
        _hbondInitialized = initialized;
    }
    
    /**
     * Tests whether hbond images have been initialized.
     */
    public boolean hbondInitialized()
    {
        return _hbondInitialized;
    }

    /**
     * Sets whether ssbond images have been initialized.
     */
    public void setSSBondInitialized(boolean initialized)
    {
        _ssbondInitialized = initialized;
    }
    
    /**
     * Tests whether ssbond images have been initialized.
     */
    public boolean ssbondInitialized()
    {
        return _ssbondInitialized;
    }

    /**
     * Sets whether residue images should be refreshed.
     */
    public void setRefreshResidue(boolean refresh)
    {
        _refreshResidue = refresh;
    }

    /**
     * Tests whether residue images should be refreshed.
     */
    public boolean refreshResidue()
    {
        return _refreshResidue;
    }

    /**
     * Returns the collection of hydrogen bonds.
     */
    public ArrayList getHBonds()
    {
        return _hbonds;
    }

    /**
     * Appends a hydrogen bond.
     */
    public void addHBond(HBond bond)
    {
        _hbonds.add(bond);
    }

    /**
     * Returns the number of hydrogen bonds.
     */
    public int numHBonds()
    {
        return _hbonds.size();
    }

    /**
     * Returns the hydrogen bond at the specified index.
     */
    public HBond getHBond(int index)
    {
        return (HBond)_hbonds.get(index);
    }

    /**
     * Returns the collection of disulfide bonds.
     */
    public ArrayList getSSBonds()
    {
        return _ssbonds;
    }

    /**
     * Appends a disulfide bond.
     */
    public void addSSBond(SSBond bond)
    {
        _ssbonds.add(bond);
    }

    /**
     * Returns the number of disulfide bonds.
     */
    public int numSSBonds()
    {
        return _ssbonds.size();
    }

    /**
     * Returns the disulfide bond at the specified index.
     */
    public SSBond getSSBond(int index)
    {
        return (SSBond)_ssbonds.get(index);
    }

    public Bond createBond() {
        return new BondImpl();
    }
}
