/*
 * This source code is a derived work of jV version 4.3.1 licensed as below.
 * March 2014
 * RIKEN, Japan
 */

/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.molecules;

import java.util.ArrayList;
import java.util.List;

public class MoleculeTraj extends Molecule {

    private MoleculeCommonData _commonData;
    private MoleculeFrameData _currFrame;
    private List _frames;

    /**
     * Constructor.
     */
    public MoleculeTraj(Molecule molecule) {
        _commonData = new MoleculeCommonData(molecule);
        _currFrame = new MoleculeFrameData(molecule);
        _frames = new ArrayList();
        _frames.add(_currFrame);

        int[] offsets = new int[3];
        for (int ch = 0; ch < molecule.numChains(); ch++) {
            addChain(new ChainTraj(molecule.getChain(ch), this, offsets));
        }
    }

    public void addFrame() {
        _currFrame = new MoleculeFrameData(_frames.size(),
                (MoleculeFrameData) _frames.get(0));
        _frames.add(_currFrame);
    }

    public MoleculeFrameData getCurrFrame() {
        return _currFrame;
    }

    public void setFrame(int frame) {
        _currFrame = (MoleculeFrameData) _frames.get(frame);
    }

    /**
     * Sets the x coordinate at the center of the molecule.
     */
    public void setCenterX(float centerX)
    {
        _commonData.setCenterX(centerX);
    }

    /**
     * Returns the x coordinate at the center of the molecule.
     */
    public float getCenterX()
    {
        return _commonData.getCenterX();
    }

    /**
     * Sets the y coordinate at the center of the molecule.
     */
    public void setCenterY(float centerY)
    {
        _commonData.setCenterY(centerY);
    }

    /**
     * Returns the y coordinate at the center of the molecule.
     */
    public float getCenterY()
    {
        return _commonData.getCenterY();
    }

    /**
     * Sets the z coordinate at the center of the molecule.
     */
    public void setCenterZ(float centerZ)
    {
        _commonData.setCenterZ(centerZ);
    }

    /**
     * Returns the z coordinate at the center of the molecule.
     */
    public float getCenterZ()
    {
        return _commonData.getCenterZ();
    }

    /**
     * Sets the radius of the molecule.
     */
    public void setRadius(float radius)
    {
        _commonData.setRadius(radius);
    }

    /**
     * Returns the radius of the molecule.
     */
    public float getRadius()
    {
        return _commonData.getRadius();
    }

    /**
     * Sets the minimum value of the x coordinate.
     */
    public void setMinX(float minX)
    {
        _commonData.setMinX(minX);
    }

    /**
     * Returns the minimum value of the x coordinate.
     */
    public float getMinX()
    {
        return _commonData.getMinX();
    }

    /**
     * Sets the minimum value of the y coordinate.
     */
    public void setMinY(float minY)
    {
        _commonData.setMinY(minY);
    }

    /**
     * Returns the minimum value of the y coordinate.
     */
    public float getMinY()
    {
        return _commonData.getMinY();
    }

    /**
     * Sets the minimum value of the z coordinate.
     */
    public void setMinZ(float minZ)
    {
        _commonData.setMinZ(minZ);
    }

    /**
     * Returns the minimum value of the z coordinate.
     */
    public float getMinZ()
    {
        return _commonData.getMinZ();
    }

    /**
     * Sets the maximum value of the x coordinate.
     */
    public void setMaxX(float maxX)
    {
        _commonData.setMaxX(maxX);
    }

    /**
     * Returns the maximum value of the x coordinate.
     */
    public float getMaxX()
    {
        return _commonData.getMaxX();
    }

    /**
     * Sets the maximum value of the y coordinate.
     */
    public void setMaxY(float maxY)
    {
        _commonData.setMaxY(maxY);
    }

    /**
     * Returns the maximum value of the y coordinate.
     */
    public float getMaxY()
    {
        return _commonData.getMaxY();
    }

    /**
     * Sets the maximum value of the z coordinate.
     */
    public void setMaxZ(float maxZ)
    {
        _commonData.setMaxZ(maxZ);
    }

    /**
     * Returns the maximum value of the z coordinate.
     */
    public float getMaxZ()
    {
        return _commonData.getMaxZ();
    }

    /**
     * Sets the number of atoms selected.
     */
    public void setSelectAtomCount(int selectAtomCount)
    {
        _commonData.setSelectAtomCount(selectAtomCount);
    }

    /**
     * Returns the number of atoms selected.
     */
    public int getSelectAtomCount()
    {
        return _commonData.getSelectAtomCount();
    }
    /**
     * Sets whether bonds have been built.
     */
    public void setBuiltBond(boolean builtBond)
    {
        super.setBuiltBond(builtBond);
        if (builtBond) {
            // assume that current frame is the first frame
            _currFrame.setupBond(this);
        }
    }

    /**
     * Sets whether backbones have been built.
     */
    public void setBuiltBackbone(boolean builtBackbone)
    {
        super.setBuiltBackbone(builtBackbone);
        if (builtBackbone) {
            // assume that current frame is the first frame
            _currFrame.setupBackbone(this);
        }
    }

    /**
     * Sets whether hydrogen bonds have been built.
     */
    public void setBuiltHBond(boolean builtHBond)
    {
        _currFrame.setBuiltHBond(builtHBond);
    }

    /**
     * Returns whether hydrogen bonds have been built.
     */
    public boolean builtHBond()
    {
        return _currFrame.builtHBond();
    }

    /**
     * Sets whether disulfide bonds have been built.
     */
    public void setBuiltSSBond(boolean builtSSBond)
    {
        _currFrame.setBuiltSSBond(builtSSBond);
    }

    /**
     * Returns whether disulfide bonds have been built.
     */
    public boolean builtSSBond()
    {
        return _currFrame.builtSSBond();
    }

    /**
     * Sets whether the ribbon model is checked for each chain.
     */
    public void setRibbonChecked(boolean ribbonChecked)
    {
        _currFrame.setRibbonChecked(ribbonChecked);
    }

    /**
     * Returns whether the ribbon model is checked for each chain.
     */
    public boolean isRibbonChecked()
    {
        return _currFrame.isRibbonChecked();
    }

    /**
     * Sets the structurre source.
     */
    public void setStructure(int structure)
    {
        _currFrame.setStructureSource(structure);
    }

    /**
     * Returns the structure source.
     */
    public int getStructure()
    {
        return _currFrame.getStructureSource();
    }

    /**
     * Sets the number of helices.
     */
    public void setHelixCount(int helixCount)
    {
        _currFrame.setHelixCount(helixCount);
    }

    /**
     * Returns the number of helices.
     */
    public int getHelixCount()
    {
        return _currFrame.getHelixCount();
    }

    /**
     * Sets the number of strands.
     */
    public void setStrandCount(int strandCount)
    {
        _currFrame.setStrandCount(strandCount);
    }

    /**
     * Returns the number of strands.
     */
    public int getStrandCount()
    {
        return _currFrame.getStrandCount();
    }

    /**
     * Sets the number of turns.
     */
    public void setTurnCount(int turnCount)
    {
        _currFrame.setTurnCount(turnCount);
    }

    /**
     * Returns the number of turns.
     */
    public int getTurnCount()
    {
        return _currFrame.getTurnCount();
    }

    /**
     * Sets whether bond images have been initialized.
     */
    public void setBondInitialized(boolean initialized)
    {
        _currFrame.setBondInitialized(initialized);
    }

    /**
     * Tests whether bond images have been initialized.
     */
    public boolean bondInitialized()
    {
        return _currFrame.bondInitialized();
    }

    /**
     * Sets whether backbone images have been initialized.
     */
    public void setBackboneInitialized(boolean initialized)
    {
        _currFrame.setBackboneInitialized(initialized);
    }
    
    /**
     * Tests whether backbone images have been initialized.
     */
    public boolean backboneInitialized()
    {
        return _currFrame.backboneInitialized();
    }

    /**
     * Sets whether hbond images have been initialized.
     */
    public void setHBondInitialized(boolean initialized)
    {
        _currFrame.setHBondInitialized(initialized);
    }
    
    /**
     * Tests whether hbond images have been initialized.
     */
    public boolean hbondInitialized()
    {
        return _currFrame.hbondInitialized();
    }

    /**
     * Sets whether ssbond images have been initialized.
     */
    public void setSSBondInitialized(boolean initialized)
    {
        _currFrame.setSSBondInitialized(initialized);
    }
    
    /**
     * Tests whether ssbond images have been initialized.
     */
    public boolean ssbondInitialized()
    {
        return _currFrame.ssbondInitialized();
    }

    /**
     * Sets whether residue images should be refreshed.
     */
    public void setRefreshResidue(boolean refresh)
    {
        _currFrame.setRefreshResidue(refresh);
    }

    /**
     * Tests whether residue images should be refreshed.
     */
    public boolean refreshResidue()
    {
        return _currFrame.refreshResidue();
    }

    /**
     * Returns the collection of hydrogen bonds.
     */
    public ArrayList getHBonds()
    {
        return _currFrame.getHBonds();
    }

    /**
     * Appends a hydrogen bond.
     */
    public void addHBond(HBond bond)
    {
        _currFrame.addHBond(bond);
    }

    /**
     * Returns the number of hydrogen bonds.
     */
    public int numHBonds()
    {
        return _currFrame.numHBonds();
    }

    /**
     * Returns the hydrogen bond at the specified index.
     */
    public HBond getHBond(int index)
    {
        return _currFrame.getHBond(index);
    }

    /**
     * Returns the collection of disulfide bonds.
     */
    public ArrayList getSSBonds()
    {
        return _currFrame.getSSBonds();
    }

    /**
     * Appends a disulfide bond.
     */
    public void addSSBond(SSBond bond)
    {
        _currFrame.addSSBond(bond);
    }

    /**
     * Returns the number of disulfide bonds.
     */
    public int numSSBonds()
    {
        return _currFrame.numSSBonds();
    }

    /**
     * Returns the disulfide bond at the specified index.
     */
    public SSBond getSSBond(int index)
    {
        return _currFrame.getSSBond(index);
    }

    public void setTime(float time) {
        _currFrame.setTime(time);
    }

    public float getTime() {
        return _currFrame.getTime();
    }

    public Bond createBond() {
        return new BondTraj(this, numBonds());
    }
}
