/*
 * This source code is a derived work of jV version 4.3.1 licensed as below.
 * March 2014
 * RIKEN, Japan
 */

/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.molecules;

public class ResidueTraj extends Residue {

    private MoleculeTraj _molecule;
    private int _idx;

    /**
     * Constructor.
     */
    public ResidueTraj(Residue residue, MoleculeTraj molecule, int[] offsets) {
        _molecule = molecule;
        _idx = offsets[1];
        setId(residue.getId());
        setInsCode(residue.getInsCode());
        setIndex(residue.getIndex());
        setParentIndex(residue.getParentIndex());
        setName(residue.getName());
        setChainBreak(residue.isChainBreak());
        setChemCompType(residue.getChemCompType());
        setHBondIndex(-1);
        setModel(residue.getModel());
        setColorIndex(residue.getColorIndex());
        setWidth(residue.getWidth());
        setColorIndexGromacs(-1);

        for (int at = 0; at < residue.numAtoms(); at++) {
            addAtom(new AtomTraj(residue.getAtom(at), molecule, offsets));
        }
        offsets[1]++;
    }

    public void clear() {
        super.clear();
        setWidth(0);
    }

    /**
     * Sets the secondary structure.
     */
    public void setStructure(int structure)
    {
        _molecule.getCurrFrame().getStructure()[_idx] = structure;
    }

    /**
     * Returns the secondary structure.
     */
    public int getStructure()
    {
        return _molecule.getCurrFrame().getStructure()[_idx];
    }

    /**
     * Sets the secondary structure in Gromacs.
     */
    public void setStructureGromacs(int structureGromacs) {
        _molecule.getCurrFrame().getStructureGromacs()[_idx] = structureGromacs;
    }

    /**
     * Returns the secondary structure in Gromacs.
     */
    public int getStructureGromacs() {
        return _molecule.getCurrFrame().getStructureGromacs()[_idx];
    }

    /**
     * Sets the color index for Gromacs.
     */
    public void setColorIndexGromacs(int colorIndexGromacs) {
        _molecule.getCurrFrame().getColorIndexGromacs()[_idx] = colorIndexGromacs;
    }

    /**
     * Returns the color index for Gromacs.
     */
    public int getColorIndexGromacs() {
        return _molecule.getCurrFrame().getColorIndexGromacs()[_idx];
    }

    /**
     * Sets the index in the list of hydrogen bonds.
     */
    public void setHBondIndex(int hbondIndex)
    {
        _molecule.getCurrFrame().getHBondIndex()[_idx] = hbondIndex;
    }

    /**
     * Returns the index in the list of hydrogen bonds.
     */
    public int getHBondIndex()
    {
        return _molecule.getCurrFrame().getHBondIndex()[_idx];
    }

    /**
     * Sets the rendering model.
     */
    public void setModel(int model)
    {
        _molecule.getCurrFrame().getResidueModel()[_idx] = model;
        if (model == MODEL_NONE) {
            clear();
        }
    }

    /**
     * Returns the rendering model.
     */
    public int getModel()
    {
        return _molecule.getCurrFrame().getResidueModel()[_idx];
    }

    /**
     * Sets the color index in ColorManager object.
     */
    public void setColorIndex(int colorIndex)
    {
        _molecule.getCurrFrame().getResidueColorIndex()[_idx] = colorIndex;
    }

    /**
     * Returns the color index in ColorManager object.
     */
    public int getColorIndex()
    {
        return _molecule.getCurrFrame().getResidueColorIndex()[_idx];
    }

    /**
     * Sets the width of the image.
     */
    public void setWidth(float width)
    {
        _molecule.getCurrFrame().getResidueWidth()[_idx] = width;
    }

    /**
     * Returns the width of the image.
     */
    public float getWidth()
    {
        return _molecule.getCurrFrame().getResidueWidth()[_idx];
    }

    /**
     * Sets the list index.
     */
    public void setListIndex(int listIndex)
    {
        _molecule.getCurrFrame().getListIndex()[_idx] = listIndex;
    }

    /**
     * Returns the list index.
     */
    public int getListIndex()
    {
        return _molecule.getCurrFrame().getListIndex()[_idx];
    }

    /**
     * Sets the back list index.
     */
    public void setBackListIndex(int backListIndex)
    {
        _molecule.getCurrFrame().getBackListIndex()[_idx] = backListIndex;
    }

    /**
     * Returns the back list index.
     */
    public int getBackListIndex()
    {
        return _molecule.getCurrFrame().getBackListIndex()[_idx];
    }
}
