/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.mouse;

import org.pdbj.viewer.utils.*;
import org.pdbj.viewer.images.*;
import org.pdbj.viewer.molecules.*;

/**
 * Atom tester.
 */
class AtomTester
{
    static final float DEFAULT_RADIUS = 0.2f;

    Atom nearestAtom;
    Molecule nearestMolecule;
    Molecule currMolecule;
    Matrix4f transform;

    float clipZ;
    float pickRadius;

    private float _nearestZ;
    private Vector4f _vector1 = new Vector4f();

    AtomTester()
    {
        _nearestZ = Float.NEGATIVE_INFINITY;
    }

    void test(Atom atom)
    {
        if(atom.getImage().getModel() == AtomImage.MODEL_SPACEFILL){
            this.test(atom, atom.getImage().getRadius());
        }
    }

    void test(Bond bond)
    {
        if(bond.getImage().getModel() == BondImage.MODEL_WIREFRAME){
            float r = this.pickRadius;
            if(r == 0){
                r = bond.getImage().getRadius();
                if(r == 0) r = DEFAULT_RADIUS;
            }
            this.test(bond.getSrcAtom(), r);
            this.test(bond.getDstAtom(), r);
        }
    }

    void test(Residue residue)
    {
        if( residue.getImage().getModel() == ResidueImage.MODEL_RIBBON ||
            residue.getImage().getModel() == ResidueImage.MODEL_CARTOON ||
            residue.getImage().getModel() == ResidueImage.MODEL_CARTOON_TUBE ||
            residue.getImage().getModel() == ResidueImage.MODEL_TRACE )
        {
            Atom atomCA = residue.isProtein() ?
                residue.getProteinCA() : residue.getNucleotideP();
            float r = this.pickRadius;
            if(r == 0){
                r = residue.getImage().getWidth();
            }
            this.test(atomCA, r);
        }
    }

    private void test(Atom atom, float radius)
    {
        float rs = radius*radius;

        _vector1.set( atom.getX(), atom.getY(), atom.getZ(), 1 );
        _vector1.transform(transform);

        float ds = _vector1.x * _vector1.x;
        if(ds > rs) return;
        ds += _vector1.y * _vector1.y;
        if(ds > rs) return;

        float dz = (float)Math.sqrt(rs - ds);
        if(_vector1.z - dz > clipZ) return;

        float currZ = _vector1.z + dz;
        if(currZ > clipZ) currZ = clipZ;
        
        // this depends on the order of clip plane rendering
        if(currZ >= _nearestZ){
            nearestAtom = atom;
            nearestMolecule = currMolecule;
            _nearestZ = currZ;
        }
    }
}
