/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.mouse;

import java.text.*;
import org.pdbj.viewer.utils.*;
import org.pdbj.viewer.molecules.*;

/**
 * Class that holds a picking result.
 */
public class PickResult
{
    private int    _fileId;
    private int    _modelId;
    private String _chainId;
    private String _labelAsymId;
    private int    _residueId;
    private int    _atomId;
    private char   _insCode;
    private String _altLoc;
    private String _residueName;
    private String _atomName;
    private float  _x;
    private float  _y;
    private float  _z;
    private float  _origX;
    private float  _origY;
    private float  _origZ;
    
    /**
     * Sets the file ID.
     */
    public void setFileId(int fileId)
    {
        _fileId = fileId;
    }

    /**
     * Returns the file ID.
     */
    public int getFileId()
    {
        return _fileId;
    }

    /**
     * Sets the model ID.
     */
    public void setModelId(int modelId)
    {
        _modelId = modelId;
    }

    /**
     * Returns the model ID.
     */
    public int getModelId()
    {
        return _modelId;
    }

    /**
     * Sets the chain ID (auth_asym_id).
     */
    public void setChainId(String chainId)
    {
        _chainId = chainId;
    }

    /**
     * Returns the chain ID (auth_asym_id).
     */
    public String getChainId()
    {
        return _chainId;
    }

    /**
     * Sets the label_asym_id.
     */
    public void setLabelAsymId(String labelAsymId)
    {
        _labelAsymId = labelAsymId;
    }

    /**
     * Returns the label_asym_id.
     */
    public String getLabelAsymId()
    {
        return _labelAsymId;
    }

    /**
     * Sets the residue ID.
     */
    public void setResidueId(int residueId)
    {
        _residueId = residueId;
    }

    /**
     * Returns the residue ID.
     */
    public int getResidueId()
    {
        return _residueId;
    }

    /**
     * Sets the atom ID.
     */
    public void setAtomId(int atomId)
    {
        _atomId = atomId;
    }

    /**
     * Returns the atom ID.
     */
    public int getAtomId()
    {
        return _atomId;
    }

    /**
     * Sets the insertion code.
     */
    public void setInsCode(char insCode)
    {
        _insCode = insCode;
    }

    /**
     * Returns the insertion code.
     */
    public char getInsCode()
    {
        return _insCode;
    }

    /**
     * Sets the alternate location.
     */
    public void setAltLoc(String altLoc)
    {
        _altLoc = altLoc;
    }

    /**
     * Returns the alternate location.
     */
    public String getAltLoc()
    {
        return _altLoc;
    }

    /**
     * Sets the residue name.
     */
    public void setResidueName(String residueName)
    {
        _residueName = residueName;
    }

    /**
     * Returns the residue name.
     */
    public String getResidueName()
    {
        return _residueName;
    }

    /**
     * Sets the atom name.
     */
    public void setAtomName(String atomName)
    {
        _atomName = atomName;
    }

    /**
     * Returns the atom name.
     */
    public String getAtomName()
    {
        return _atomName;
    }

    /**
     * Sets the x coordinate.
     */
    public void setX(float x)
    {
        _x = x;
    }

    /**
     * Returns the x coordinate.
     */
    public float getX()
    {
        return _x;
    }

    /**
     * Sets the y coordinate.
     */
    public void setY(float y)
    {
        _y = y;
    }

    /**
     * Returns the y coordinate.
     */
    public float getY()
    {
        return _y;
    }

    /**
     * Sets the z coordinate.
     */
    public void setZ(float z)
    {
        _z = z;
    }

    /**
     * Returns the z coordinate.
     */
    public float getZ()
    {
        return _z;
    }

    /**
     * Sets the original x coordinate.
     */
    public void setOrigX(float x)
    {
        _origX = x;
    }

    /**
     * Returns the original x coordinate.
     */
    public float getOrigX()
    {
        return _origX;
    }

    /**
     * Sets the original y coordinate.
     */
    public void setOrigY(float y)
    {
        _origY = y;
    }

    /**
     * Returns the original y coordinate.
     */
    public float getOrigY()
    {
        return _origY;
    }

    /**
     * Sets the original z coordinate.
     */
    public void setOrigZ(float z)
    {
        _origZ = z;
    }

    /**
     * Returns the original z coordinate.
     */
    public float getOrigZ()
    {
        return _origZ;
    }

    /**
     * Returns a string expression of the model ID.
     */
    public String toStringModelId()
    {
        return (_modelId == Molecule.NO_MODEL_ID) ? "" : "" + _modelId;
    }

    /**
     * Returns a string expression of the coordinates.
     */
    public String[] toStringCoordinates(int fractionDigits)
    {
        NumberFormat format = NumberFormat.getNumberInstance();
        format.setMaximumFractionDigits(fractionDigits);
        format.setMinimumFractionDigits(fractionDigits);
        format.setGroupingUsed(false);

        String[] coord = new String[3];
        coord[0] = format.format(_x);
        coord[1] = format.format(_y);
        coord[2] = format.format(_z);

        return coord;
    }

    /**
     * Returns a string expression of the original coordinates.
     */
    public String[] toStringOrigCoordinates(int fractionDigits)
    {
        NumberFormat format = NumberFormat.getNumberInstance();
        format.setMaximumFractionDigits(fractionDigits);
        format.setMinimumFractionDigits(fractionDigits);
        format.setGroupingUsed(false);

        String[] coord = new String[3];
        coord[0] = format.format(_origX);
        coord[1] = format.format(_origY);
        coord[2] = format.format(_origZ);

        return coord;
    }

    /**
     * Sets the result.
     */
    public void setResult(AtomPath atomPath, Vector4f currCoords, Vector4f origCoords)
    {
        _fileId  = atomPath.getMoleculeFile().getFileId();
        _modelId = atomPath.getMolecule().getModelId();
        _chainId = atomPath.getChain().getId();
        _labelAsymId = atomPath.getChain().getLabelId();

        Residue residue = atomPath.getResidue();
        _residueId   = residue.getId();
        _insCode     = residue.getInsCode();
        _residueName = residue.getName();

        Atom atom = atomPath.getAtom();
        _atomId   = atom.getId();
        _altLoc   = atom.getAltLoc();
        _atomName = atom.getName();

        _x = currCoords.x;
        _y = currCoords.y;
        _z = currCoords.z;
        _origX = origCoords.x;
        _origY = origCoords.y;
        _origZ = origCoords.z;
    }

    /**
     * Clears.
     */
    public void clear()
    {
        _fileId  = 0;
        _modelId = 0;
        _chainId = "";
        _labelAsymId = "";

        _residueId   = 0;
        _insCode     = 0;
        _residueName = "";

        _atomId   = 0;
        _altLoc   = "";
        _atomName = "";

        _x = 0;
        _y = 0;
        _z = 0;
        _origX = 0;
        _origY = 0;
        _origZ = 0;
    }

    /**
     * Constructor.
     */
    public PickResult()
    {
        this.clear();
    }
}
