/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.plus;

import java.util.*;

/**
 * Class that represents molecule functions.
 */
public class Function
{
    public static final Function UNDEFINED = new Function();
    
    private ArrayList _structSites;
    private ArrayList _goRefs;
    private LinkedHashMap _jvCommands;

    /**
     * Constructor.
     */
    public Function()
    {
        _structSites = new ArrayList();
        _goRefs = new ArrayList();
        _jvCommands = new LinkedHashMap();
    }

    /**
     * Appends a struct site.
     */
    public void addStructSite(StructSite structSite)
    {
        _structSites.add(structSite);
    }

    /**
     * Returns the number of struct sites.
     */
    public int numStructSites()
    {
        return _structSites.size();
    }

    /**
     * Returns the specified struct site.
     */
    public StructSite getStructSite(int index)
    {
        return (StructSite)_structSites.get(index);
    }

    /**
     * Appends a GO_ref.
     */
    public void addGORef(GORef goRef)
    {
        _goRefs.add(goRef);
    }

    /**
     * Returns the number of GO_refs.
     */
    public int numGORefs()
    {
        return _goRefs.size();
    }

    /**
     * Returns the GO_ref specified by index.
     */
    public GORef getGORef(int index)
    {
        return (GORef)_goRefs.get(index);
    }

    /**
     * Appends a jV command.
     */
    public void addJvCommand(JvCommand jvCommand) {
        _jvCommands.put(jvCommand.getName(), jvCommand);
    }

    /**
     * Returns the jV command.
     */
    public JvCommand getJvCommand(String name) {
        return (JvCommand) _jvCommands.get(name);
    }

    /**
     * Returns an iterator for jV commands.
     */
    public Iterator iteratorJvCommands() {
        return _jvCommands.values().iterator();
    }

    /**
     * Reset commands.
     */
    public void resetCommands() {
        for (Iterator it = iteratorJvCommands(); it.hasNext();) {
            JvCommand jvCommand = (JvCommand) it.next();
            jvCommand.reset();
        }
    }
}
