/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.plus;

/**
 * Class that represents struct_site_gen elements in the function file.
 */
public class StructSiteGen
{
    private String _siteId;
    private String _authAsymId;
    private String _begAuthSeqId;
    private String _endAuthSeqId;
    
    private int  _initSeqId;
    private int  _termSeqId;
    private char _initInsCode;
    private char _termInsCode;

    /**
     * Sets the site ID.
     */
    public void setSiteId(String siteId)
    {
        _siteId = siteId;
    }

    /**
     * Returns the site ID.
     */
    public String getSiteId()
    {
        return _siteId;
    }

    /**
     * Sets the auth_asym_id.
     */
    public void setAuthAsymId(String authAsymId)
    {
        _authAsymId = authAsymId;
    }

    /**
     * Returns the auth_asym_id.
     */
    public String getAuthAsymId()
    {
        return _authAsymId;
    }

    /**
     * Sets the beg_auth_seq_id or auth_seq_id.
     */
    public void setBegAuthSeqId(String begAuthSeqId)
    {
        _begAuthSeqId = begAuthSeqId;

        this.fixSeqId(_begAuthSeqId, true);
    }

    /**
     * Returns the beg_auth_seq_id or auth_seq_id.
     */
    public String getBegAuthSeqId()
    {
        return _begAuthSeqId;
    }

    /**
     * Sets the end_auth_seq_id or auth_seq_id.
     */
    public void setEndAuthSeqId(String endAuthSeqId)
    {
        _endAuthSeqId = endAuthSeqId;

        this.fixSeqId(_endAuthSeqId, false);
    }

    /**
     * Returns the end_auth_seq_id or auth_seq_id.
     */
    public String getEndAuthSeqId()
    {
        return _endAuthSeqId;
    }

    /**
     * Returns the init seqID.
     */
    public int getInitSeqId()
    {
        return _initSeqId;
    }

    /**
     * Returns the term seqID.
     */
    public int getTermSeqId()
    {
        return _termSeqId;
    }

    /**
     * Returns the init insCode.
     */
    public char getInitInsCode()
    {
        return _initInsCode;
    }

    /**
     * Returns the term insCode.
     */
    public char getTermInsCode()
    {
        return _termInsCode;
    }
    
    //--------------------------------------------------------------------
    // Utils
    //--------------------------------------------------------------------
    private void fixSeqId(String seqId, boolean init)
    {
        int id = Integer.MIN_VALUE;
        char code = 0;

        if(seqId != null)
        {
            int len = seqId.length();
            try{
                char last = seqId.charAt(len-1);
                if(last >= '0' && last <= '9'){
                    id = Integer.parseInt(seqId);
                }
                else{
                    id = Integer.parseInt( seqId.substring(0, len-1) );
                    code = last;
                }
            }
            catch(NumberFormatException e){
            }
        }
        
        if(init){
            _initSeqId = id;
            _initInsCode = code;
        }
        else{
            _termSeqId = id;
            _termInsCode = code;
        }
    }
}
