/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.polygons;

import java.util.*;

/**
 * Vertices.
 */
public class Vertices {

    private int[] _id;
    private float[] _x;
    private float[] _y;
    private float[] _z;
    private float[] _nx;
    private float[] _ny;
    private float[] _nz;
    private int[] _color;    
    private float[][] _userData;

    /**
     * Sets the vertex ID.
     */
    public void setId(int[] id) {
        _id = id;
    }

    /**
     * Returns the vertex ID.
     */
    public int[] getId() {
        return _id;
    }

    /**
     * Returns the vertex ID.
     */
    public int getId(int vertexIndex) {
        return _id[vertexIndex];
    }

    /**
     * Sets the x-coordinate.
     */
    public void setX(float[] x) {
        _x = x;
    }

    /**
     * Returns the x-coordinate.
     */
    public float[] getX() {
        return _x;
    }

    /**
     * Returns the x-coordinate.
     */
    public float getX(int vertexIndex) {
        return _x[vertexIndex];
    }

    /**
     * Sets the y-coordinate.
     */
    public void setY(float[] y) {
        _y = y;
    }

    /**
     * Returns the y-coordinate.
     */
    public float[] getY() {
        return _y;
    }

    /**
     * Returns the y-coordinate.
     */
    public float getY(int vertexIndex) {
        return _y[vertexIndex];
    }

    /**
     * Sets the z-coordinate.
     */
    public void setZ(float[] z) {
        _z = z;
    }

    /**
     * Returns the z-coordinate.
     */
    public float[] getZ() {
        return _z;
    }

    /**
     * Returns the z-coordinate.
     */
    public float getZ(int vertexIndex) {
        return _z[vertexIndex];
    }

    /**
     * Sets the x component of the normal vector.
     */
    public void setNormalX(float[] nx) {
        _nx = nx;
    }

    /**
     * Returns the x component of the normal vector.
     */
    public float[] getNormalX() {
        return _nx;
    }

    /**
     * Returns the x component of the normal vector.
     */
    public float getNormalX(int vertexIndex) {
        return _nx[vertexIndex];
    }

    /**
     * Sets the y component of the normal vector.
     */
    public void setNormalY(float[] ny) {
        _ny = ny;
    }

    /**
     * Returns the y component of the normal vector.
     */
    public float[] getNormalY() {
        return _ny;
    }

    /**
     * Returns the y component of the normal vector.
     */
    public float getNormalY(int vertexIndex) {
        return _ny[vertexIndex];
    }

    /**
     * Sets the z component of the normal vector.
     */
    public void setNormalZ(float[] nz) {
        _nz = nz;
    }

    /**
     * Returns the z component of the normal vector.
     */
    public float[] getNormalZ() {
        return _nz;
    }

    /**
     * Returns the z component of the normal vector.
     */
    public float getNormalZ(int vertexIndex) {
        return _nz[vertexIndex];
    }

    /**
     * Sets the color.
     */
    public void setColor(int[] color) {
        _color = color;
    }

    /**
     * Returns the color.
     */
    public int[] getColor() {
        return _color;
    }

    /**
     * Returns the color.
     */
    public int getColor(int vertexIndex) {
        return _color[vertexIndex];
    }

    /**
     * Sets the user data.
     */
    public void setUserData(float[][] userData) {
        _userData = userData;
    }

    /**
     * Returns the user data.
     */
    public float[][] getUserData() {
        return _userData;
    }

    /**
     * Returns the user data.
     */
    public float[] getUserData(int vertexIndex) {
        return _userData[vertexIndex];
    }

    /**
     * Returns the user data.
     */
    public float getUserData(int vertexIndex, int dataIndex) {
        return _userData[vertexIndex][dataIndex];
    }

    /**
     * Returns the number of vertices.
     */
    public int length() {
        return _id.length;
    }

    /**
     * Sets values.
     */
    public void set(List vertices) {
        int num = vertices.size();

        _id = new int[num];
        _x = new float[num];
        _y = new float[num];
        _z = new float[num];
        _nx = new float[num];
        _ny = new float[num];
        _nz = new float[num];
        _color = new int[num];
        _userData = new float[num][];

        for (int i = 0; i < num; i++) {
            Vertex vertex = (Vertex) vertices.get(i);
            _id[i] = vertex.getId();
            _x[i] = vertex.getX();
            _y[i] = vertex.getY();
            _z[i] = vertex.getZ();
            _nx[i] = vertex.getNormalX();
            _ny[i] = vertex.getNormalY();
            _nz[i] = vertex.getNormalZ();
            _color[i] = vertex.getColor();
            _userData[i] = vertex.getUserData();
        }
    }
}
