/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.renderer;

import org.pdbj.viewer.molecules.*;

/**
 * Geometry for residue images.
 */
public class ResidueGeometry
{
    private Residue          _residue;
    private SplineGeometry[] _splines;
    private float            _prevWidth;
    private float            _nextWidth;

    /**
     * Sets the residue.
     */
    public void setResidue(Residue residue)
    {
        _residue = residue;
    }

    /**
     * Returns the residue.
     */
    public Residue getResidue()
    {
        return _residue;
    }

    /**
     * Sets spline geometries.
     */
    public void setSplines(SplineGeometry[] splines)
    {
        _splines = splines;
    }

    /**
     * Returns spline geometries.
     */
    public SplineGeometry[] getSplines()
    {
        return _splines;
    }
    
    /**
     * Sets the width of the previous residue image.
     */
    public void setPrevWidth(float prevWidth)
    {
        _prevWidth = prevWidth;
    }

    /**
     * Returns the width of the previous residue image.
     */
    public float getPrevWidth()
    {
        return _prevWidth;
    }

    /**
     * Sets the width of the next residue image.
     */
    public void setNextWidth(float nextWidth)
    {
        _nextWidth = nextWidth;
    }

    /**
     * Returns the width of the next residue image.
     */
    public float getNextWidth()
    {
        return _nextWidth;
    }
}
