/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.renderer;

import org.pdbj.viewer.utils.*;

/**
 * Geometry for spline images.
 */
public class SplineGeometry
{
    private Vector3f _splinePoint;
    private Vector3f _direction;
    private Vector3f _horizontal;
    private Vector3f _vertical;
    private float    _width;
    private float    _height;

    /**
     * Sets the spline point.
     */
    public void setSplinePoint(Vector3f splinePoint)
    {
        _splinePoint = splinePoint;
    }

    /**
     * Returns the spline point.
     */
    public Vector3f getSplinePoint()
    {
        return _splinePoint;
    }

    /**
     * Sets the direction vector.
     */
    public void setDirection(Vector3f direction)
    {
        _direction = direction;
    }

    /**
     * Returns the direction vector.
     */
    public Vector3f getDirection()
    {
        return _direction;
    }

    /**
     * Sets the horizontal vector.
     */
    public void setHorizontal(Vector3f horizontal)
    {
        _horizontal = horizontal;
        _width = -1;
    }

    /**
     * Returns the horizontal vector.
     */
    public Vector3f getHorizontal()
    {
        return _horizontal;
    }

    /**
     * Sets the vertical vector.
     */
    public void setVertical(Vector3f vertical)
    {
        _vertical = vertical;
        _height = -1;
    }

    /**
     * Returns the vertical vector.
     */
    public Vector3f getVertical()
    {
        return _vertical;
    }

    /**
     * Sets the width.
     */
    public void setWidth(float width)
    {
        if(_horizontal == null || _horizontal.lengthSquared() == 0){
            return;
        }

        _width = width;
        _horizontal.normalize();
        _horizontal.multiply(width);
    }

    /**
     * Returns the width.
     */
    public float getWidth()
    {
        if(_width == -1 && _horizontal != null){
            _width = _horizontal.length();
        }
        return _width;
    }
    
    /**
     * Sets the height.
     */
    public void setHeight(float height)
    {
        if(_vertical == null || _vertical.lengthSquared() == 0){
             return;
        }

        _height = height;
        _vertical.normalize();
        _vertical.multiply(height);
    }

    /**
     * Returns the height.
     */
    public float getHeight()
    {
        if(_height == -1 && _vertical != null){
            _height = _vertical.length();
        }
        return _height;
    }
    
    /**
     * Returns the copy of this object.
     */
    public SplineGeometry copy()
    {
        SplineGeometry copy = new SplineGeometry();

        copy.setSplinePoint( new Vector3f(_splinePoint) );
        copy.setDirection( new Vector3f(_direction) );
        copy.setHorizontal( new Vector3f(_horizontal) );
        copy.setVertical( new Vector3f(_vertical) );

        return copy;
    }

    /**
     * Constructor.
     */
    public SplineGeometry()
    {
        _width = -1;
        _height = -1;
    }
}
