/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.site;

/**
 * Region.
 */
public class Region {
    public static final String BLANK_CHAIN_ID = " ";
    
    private String _chainId;
    private String _begSeqId;
    private String _endSeqId;
    
    private int _initSeqId;
    private int _termSeqId;
    
    /**
     * Constructs an instance.
     */
    public Region() {
        _initSeqId = Integer.MAX_VALUE;
        _termSeqId = Integer.MIN_VALUE;
    }

    /**
     * Sets the chain_id.
     */
    public void setChainId(String chainId) {
        _chainId = chainId;
    }
    
    /**
     * Returns the chain_id.
     */
    public String getChainId() {
        return _chainId;
    }

    /**
     * Sets the beg_seq_id.
     */
    public void setBegSeqId(String begSeqId) {
        _begSeqId = begSeqId;
        setupInitSeqId();
    }

    /**
     * Returns the beg_seq_id.
     */
    public String getBegSeqId() {
        return _begSeqId;
    }

    /**
     * Sets the end_seq_id.
     */
    public void setEndSeqId(String endSeqId) {
        _endSeqId = endSeqId;
        setupTermSeqId();
    }

    /**
     * Returns the end_seq_id.
     */
    public String getEndSeqId() {
        return _endSeqId;
    }

    /**
     * Returns the init seq ID.
     */
    public int getInitSeqId() {
        return _initSeqId;
    }

    /**
     * Returns the term seq ID.
     */
    public int getTermSeqId() {
        return _termSeqId;
    }
    
    private void setupInitSeqId() {
        if (!_begSeqId.equals("")) {
            int lastpos = _begSeqId.length() - 1;
            char last = _begSeqId.charAt(lastpos);
            if (last >= '0' && last <= '9') {
                _initSeqId = Integer.parseInt(_begSeqId);
            } else {
                _initSeqId = Integer.parseInt(_begSeqId.substring(0, lastpos));
            }
        }
    }
    
    private void setupTermSeqId() {
        if (!_endSeqId.equals("")) {
            int lastpos = _endSeqId.length() - 1;
            char last = _endSeqId.charAt(lastpos);
            if (last >= '0' && last <= '9') {
                _termSeqId = Integer.parseInt(_endSeqId);
            } else {
                _termSeqId = Integer.parseInt(_endSeqId.substring(0, lastpos));
            }
        }
    }
}
