/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.site;

import java.util.*;

/**
 * Site.
 */
public class Site {
    private String _id;
    private String _db;
    private String _category;
    private String _description;
    private List _regions;

    /**
     * Construcs an instance.
     */
    public Site() {
        _regions = new ArrayList();
    }

    /**
     * Sets the id.
     */
    public void setId(String id) {
        _id = id;
    }

    /**
     * Returns the id.
     */
    public String getId() {
        return _id;
    }

    /**
     * Sets the db.
     */
    public void setDb(String db) {
        _db = db;
    }

    /**
     * Returns the db.
     */
    public String getDb() {
        return _db;
    }

    /**
     * Sets the category.
     */
    public void setCategory(String category) {
        _category = category;
    }

    /**
     * Returns the category.
     */
    public String getCategory() {
        return _category;
    }

    /**
     * Sets the description.
     */
    public void setDescription(String description) {
        _description = description;
    }

    /**
     * Returns the description.
     */
    public String getDescription() {
        return _description;
    }

    /**
     * Appends a region.
     */
    public void addRegion(Region region) {
        _regions.add(region);
    }

    /**
     * Returns the number of regions.
     */
    public int numRegions() {
        return _regions.size();
    }

    /**
     * Returns the region.
     */
    public Region getRegion(int index) {
        return (Region) _regions.get(index);
    }

    /**
     * Returns an iterator for regions.
     */
    public Iterator iterator() {
        return _regions.iterator();
    }
}
