/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.tables;

/**
 * Class that contains properties of atoms.
 */
public class AtomTable
{
    public static final int INDEX_OTHER       =  0;
    public static final int INDEX_N           =  1;
    public static final int INDEX_CA          =  2;
    public static final int INDEX_C           =  3;
    public static final int INDEX_O           =  4;
    public static final int INDEX_C_PRIME     =  5;
    public static final int INDEX_OT          =  6;
    public static final int INDEX_S           =  7;
    public static final int INDEX_P           =  8;
    public static final int INDEX_O1P         =  9;
    public static final int INDEX_O2P         = 10;
    public static final int INDEX_O5_ASTERISK = 11;
    public static final int INDEX_C5_ASTERISK = 12;
    public static final int INDEX_C4_ASTERISK = 13;
    public static final int INDEX_O4_ASTERISK = 14;
    public static final int INDEX_C3_ASTERISK = 15;
    public static final int INDEX_O3_ASTERISK = 16;
    public static final int INDEX_C2_ASTERISK = 17;
    public static final int INDEX_O2_ASTERISK = 18;
    public static final int INDEX_C1_ASTERISK = 19;
    public static final int INDEX_CA2         = 20;
    public static final int INDEX_SG          = 21;
    public static final int INDEX_N1          = 22;
    public static final int INDEX_N2          = 23;
    public static final int INDEX_N3          = 24;
    public static final int INDEX_N4          = 25;
    public static final int INDEX_N6          = 26;
    public static final int INDEX_O2          = 27;
    public static final int INDEX_O4          = 28;
    public static final int INDEX_O6          = 29;

    public static final int GROUP_AMINO_BACKBONE   = 0;
    public static final int GROUP_NUCLEIC_BACKBONE = 1;

    private static AtomData[] _atoms = new AtomData[]
    {
        new AtomData(""    ), // 0
        new AtomData(" N  "), // 1
        new AtomData(" CA "), // 2
        new AtomData(" C  "), // 3
        new AtomData(" O  "), // 4
        new AtomData(" C' "), // 5
        new AtomData(" OT "), // 6
        new AtomData(" S  "), // 7
        new AtomData(" P  "), // 8
        new AtomData(" O1P"), // 9
        new AtomData(" O2P"), // 10
        new AtomData(" O5*"), // 11
        new AtomData(" C5*"), // 12
        new AtomData(" C4*"), // 13
        new AtomData(" O4*"), // 14
        new AtomData(" C3*"), // 15
        new AtomData(" O3*"), // 16
        new AtomData(" C2*"), // 17
        new AtomData(" O2*"), // 18
        new AtomData(" C1*"), // 19
        new AtomData(" CA2"), // 20
        new AtomData(" SG "), // 21
        new AtomData(" N1 "), // 22
        new AtomData(" N2 "), // 23
        new AtomData(" N3 "), // 24
        new AtomData(" N4 "), // 25
        new AtomData(" N6 "), // 26
        new AtomData(" O2 "), // 27
        new AtomData(" O4 "), // 28
        new AtomData(" O6 ")  // 29
    };

    private AtomTable()
    {
    }
    
    /**
     * Returns the number of atoms registered.
     */
    public static int counts()
    {
        return _atoms.length;
    }

    /**
     * Returns the index of the specified atom name and residue index.
     */
    public static int getIndex(String atomName, int residueIndex)
    {
        String name = fixIrregularName(atomName.toUpperCase(), residueIndex);

        for(int i=0; i<_atoms.length; i++){
            if( name.equals(_atoms[i].name) ) return i;
        }
        return INDEX_OTHER;
    }

    /**
     * Returns the index of the specified atom name.
     */
    public static int getIndexVer3(String atomName) {
        String name = atomName.toUpperCase();

        for (int i = 0; i <= 8; i++) {
            if (name.equals(_atoms[i].name)) {
                return i;
            }
        }

        if (name.equals(" OP1")) {
            return INDEX_O1P;
        } else if (name.equals(" OP2")) {
            return INDEX_O2P;
        } else if (name.equals(" O5'")) {
            return INDEX_O5_ASTERISK;
        } else if (name.equals(" C5'")) {
            return INDEX_C5_ASTERISK;
        } else if (name.equals(" C4'")) {
            return INDEX_C4_ASTERISK;
        } else if (name.equals(" O4'")) {
            return INDEX_O4_ASTERISK;
        } else if (name.equals(" C3'")) {
            return INDEX_C3_ASTERISK;
        } else if (name.equals(" O3'")) {
            return INDEX_O3_ASTERISK;
        } else if (name.equals(" C2'")) {
            return INDEX_C2_ASTERISK;
        } else if (name.equals(" O2'")) {
            return INDEX_O2_ASTERISK;
        } else if (name.equals(" C1'")) {
            return INDEX_C1_ASTERISK;
        }

        for (int i = 20; i <= 29; i++) {
            if (name.equals(_atoms[i].name)) {
                return i;
            }
        }
        return INDEX_OTHER;
    }

    /**
     * Returns the name of the specified atom.
     */
    public static String getName(int index)
    {
        return _atoms[index].name;
    }

    /**
     * Returns the atomic number of the specified atom name and residue index.
     */
    public static int getAtomicNo(String atomName, int residueIndex)
    {
        return determineAtomicNo(atomName, residueIndex);
    }

    /**
     * Tests whether the specified atom belongs to the specified group.
     */
    public static boolean isInGroup(int index, int group)
    {
        switch(group)
        {
            case GROUP_AMINO_BACKBONE :
                return (index >= 1 && index <= 4);

            case GROUP_NUCLEIC_BACKBONE :
                return (index >= 8 && index <= 19);

            default :
                return false;
        }
    }

    //--------------------------------------------------------------------
    // fix irregular names
    //--------------------------------------------------------------------
    private static String fixIrregularName(String name, int residueIndex)
    {
        boolean bProtein = ResidueTable.isInGroup(
                            residueIndex, ResidueTable.GROUP_PROTEIN);
        boolean bNucleotide = ResidueTable.isInGroup(
                            residueIndex, ResidueTable.GROUP_NUCLEOTIDE);

        char[] chs = new char[4];
        for(int i=0; i<4; i++){
            chs[i] = (i < name.length()) ? name.charAt(i) : ' ';
        }

        // right-justified atom name
        if(chs[0] == ' ' && chs[1] == ' '){
            if(chs[2] == ' '){
                chs[1] = chs[3];
                chs[3] = ' ';
            }
            else{
                chs[1] = chs[2];
                chs[2] = chs[3];
                chs[3] = ' ';
            }
        }

        if( (chs[1]>='0') && (chs[1]<='9') ){ // IDATM PDB files
            chs[3] = chs[2];
            chs[2] = chs[1];
            chs[1] = chs[0];
            chs[0] = ' ';
        }
        else if(chs[1] == ' '){ // Corina PDB files
            chs[1] = chs[0];
            chs[0] = ' ';
        }

        if(bProtein && chs[0] == 'H'){
            chs[0] = ' ';
            chs[1] = 'H';
        }
        else if(bNucleotide){
            if(chs[3] == '\'') chs[3] = '*';

            if( (chs[0]==' ' && chs[1]=='O' && chs[2]=='P' && chs[3]=='1') ||
                (chs[0]=='1' && chs[1]=='O' && chs[2]=='P' && chs[3]==' ') )
            {
                chs[0] = ' '; chs[1] = 'O'; chs[2] = '1'; chs[3] = 'P';
            }

            if( (chs[0]==' ' && chs[1]=='O' && chs[2]=='P' && chs[3]=='2') ||
                (chs[0]=='2' && chs[1]=='O' && chs[2]=='P' && chs[3]==' ') )
            {
                chs[0] = ' '; chs[1] = 'O'; chs[2] = '2'; chs[3] = 'P';
            }
        }

        return new String(chs);
    }

    //--------------------------------------------------------------------
    // determine atomic number from an atom name written in PDB files
    //--------------------------------------------------------------------
    private static int determineAtomicNo(String atomName, int residueIndex)
    {
        boolean bCoenzyme = ResidueTable.isInGroup(
                            residueIndex, ResidueTable.GROUP_COENZYME);
        boolean bProtein = ResidueTable.isInGroup(
                            residueIndex, ResidueTable.GROUP_PROTEIN);

        String name = fixIrregularName(atomName.toUpperCase(), residueIndex);

        char ch1 = name.charAt(0);
        char ch2 = name.charAt(1);

        if(bCoenzyme){
            ch1 = ' ';
        }
        else if(ch1 == 'H' && bProtein){
            return 1;
        }

        switch( ch1 ){
            case(' '):  switch( ch2 ){
                            case('B'):  return(  5 );
                            case('C'):  return(  6 );
                            case('D'):  return(  1 );
                            case('F'):  return(  9 );
                            case('H'):  return(  1 );
                            case('I'):  return( 53 );
                            case('K'):  return( 19 );
                            case('L'):  return(  1 );
                            case('N'):  return(  7 );
                            case('O'):  return(  8 );
                            case('P'):  return( 15 );
                            case('S'):  return( 16 );
                            case('U'):  return( 92 );
                            case('V'):  return( 23 );
                            case('W'):  return( 74 );
                            case('Y'):  return( 39 );
                        }
                        break;

            case('A'):  switch( ch2 ){
                            case('C'):  return( 89 );
                            case('G'):  return( 47 );
                            case('L'):  return( 13 );
                            case('M'):  return( 95 );
                            case('R'):  return( 18 );
                            case('S'):  return( 33 );
                            case('T'):  return( 85 );
                            case('U'):  return( 79 );
                        }
                        break;

            case('B'):  switch( ch2 ){
                            case(' '):  return(  5 );
                            case('A'):  return( 56 );
                            case('E'):  return(  4 );
                            case('I'):  return( 83 );
                            case('K'):  return( 97 );
                            case('R'):  return( 35 );
                        }
                        break;

            case('C'):  switch( ch2 ){
                            case(' '):  return(  6 );
                            case('A'):  return( 20 );
                            case('D'):  return( 48 );
                            case('E'):  return( 58 );
                            case('F'):  return( 98 );
                            case('L'):  return( 17 );
                            case('M'):  return( 96 );
                            case('O'):  return( 27 );
                            case('R'):  return( 24 );
                            case('S'):  return( 55 );
                            case('U'):  return( 29 );
                        }
                        break;

            case('D'):  switch( ch2 ){
                            case(' '):  return(  1 );
                            case('Y'):  return( 66 );
                            case('U'):  return(  0 );
                        }
                        break;

            case('E'):  switch( ch2 ){
                            case('R'):  return( 68 );
                            case('S'):  return( 99 );
                            case('U'):  return( 63 );
                        }
                        break;

            case('F'):  switch( ch2 ){
                            case(' '):  return(   9 );
                            case('E'):  return(  26 );
                            case('M'):  return( 100 );
                            case('R'):  return(  87 );
                        }
                        break;

            case('G'):  switch( ch2 ){
                            case('A'):  return( 31 );
                            case('D'):  return( 64 );
                            case('E'):  return( 32 );
                        }
                        break;

            case('H'):  switch( ch2 ){
                            case(' '):  return(  1 );
                            case('E'):  return(  2 );
                            case('F'):  return( 72 );
                            case('G'):  return( 80 );
                            case('O'):  return( 67 );
                        }
                        break;

            case('I'):  switch( ch2 ){
                            case(' '):  return( 53 );
                            case('N'):  return( 49 );
                            case('R'):  return( 77 );
                        }
                        break;

            case('K'):  switch( ch2 ){
                            case(' '):  return( 19 );
                            case('R'):  return( 36 );
                        }
                        break;

            case('L'):  switch( ch2 ){
                            case('A'):  return(  57 );
                            case('I'):  return(   3 );
                            case('P'):  return(   0 );
                            case('R'):  return( 103 );
                            case('W'):  return( 103 );
                            case('U'):  return(  71 );
                        }
                        break;

            case('M'):  switch( ch2 ){
                            case('D'):  return( 101 );
                            case('G'):  return(  12 );
                            case('N'):  return(  25 );
                            case('O'):  return(  42 );
                        }
                        break;

            case('N'):  switch( ch2 ){
                            case(' '):  return(   7 );
                            case('A'):  return(  11 );
                            case('B'):  return(  41 );
                            case('D'):  return(  60 );
                            case('E'):  return(  10 );
                            case('I'):  return(  28 );
                            case('O'):  return( 102 );
                            case('P'):  return(  93 );
                        }
                        break;

            case('O'):  switch( ch2 ){
                            case(' '):  return(  8 );
                            case('S'):  return( 76 );
                        }
                        break;

            case('P'):  switch( ch2 )
                        {   case(' '):  return( 15 );
                            case('A'):  return( 91 );
                            case('B'):  return( 82 );
                            case('D'):  return( 46 );
                            case('M'):  return( 61 );
                            case('O'):  return( 84 );
                            case('R'):  return( 59 );
                            case('T'):  return( 78 );
                            case('U'):  return( 94 );
                        }
                        break;

            case('R'):  switch( ch2 )
                        {   case('A'):  return( 88 );
                            case('B'):  return( 37 );
                            case('E'):  return( 75 );
                            case('H'):  return( 45 );
                            case('N'):  return( 86 );
                            case('U'):  return( 44 );
                        }
                        break;

            case('S'):  switch( ch2 )
                        {   case(' '):  return( 16 );
                            case('B'):  return( 51 );
                            case('C'):  return( 21 );
                            case('E'):  return( 34 );
                            case('I'):  return( 14 );
                            case('M'):  return( 62 );
                            case('N'):  return( 50 );
                            case('R'):  return( 38 );
                        }
                        break;

            case('T'):  switch( ch2 )
                        {   case(' '):  return(  1 );
                            case('A'):  return( 73 );
                            case('B'):  return( 65 );
                            case('C'):  return( 43 );
                            case('E'):  return( 52 );
                            case('H'):  return( 90 );
                            case('I'):  return( 22 );
                            case('L'):  return( 81 );
                            case('M'):  return( 69 );
                        }
                        break;

            case('U'):  if( ch2==' ' )  return( 92 );
                        break;

            case('V'):  if( ch2==' ' )  return( 23 );
                        break;

            case('W'):  if( ch2==' ' )  return( 74 );
                        break;

            case('X'):  if( ch2=='E' )  return( 54 );
                        break;

            case('Y'):  switch( ch2 ){
                            case(' '):  return( 39 );
                            case('B'):  return( 70 );
                        }
                        break;

            case('Z'):  switch( ch2 ){
                            case('N'):  return( 30 );
                            case('R'):  return( 40 );
                        }
                        break;
        }

        // Numeric Prefix
        if( (ch1>='0') && (ch1<='9') ){
            ch1 = ch2;
        }

        // If all else fails
        switch( ch1 ){
            case('B'):  return(  5 );
            case('C'):  return(  6 );
            case('D'):  return(  1 );
            case('F'):  return(  9 );
            case('H'):  return(  1 );
            case('I'):  return( 53 );
            case('K'):  return( 19 );
            case('L'):  return(  1 );
            case('N'):  return(  7 );
            case('O'):  return(  8 );
            case('P'):  return( 15 );
            case('S'):  return( 16 );
            case('U'):  return( 92 );
            case('V'):  return( 23 );
            case('W'):  return( 74 );
            case('Y'):  return( 39 );
        }
        return 0;
    }
}

