/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.tables;

import java.awt.Color;

/**
 * Class that contains predefined colors.
 */
public class ColorTable
{
    public static final int INDEX_BLACK      =  0;
    public static final int INDEX_BLUE       =  1;
    public static final int INDEX_BLUETINT   =  2;
    public static final int INDEX_BROWN      =  3;
    public static final int INDEX_CYAN       =  4;
    public static final int INDEX_GOLD       =  5;
    public static final int INDEX_GREY       =  6;
    public static final int INDEX_GREEN      =  7;
    public static final int INDEX_GREENBLUE  =  8;
    public static final int INDEX_GREENTINT  =  9;
    public static final int INDEX_HOTPINK    = 10;
    public static final int INDEX_MAGENTA    = 11;
    public static final int INDEX_ORANGE     = 12;
    public static final int INDEX_PINK       = 13;
    public static final int INDEX_PINKTINT   = 14;
    public static final int INDEX_PURPLE     = 15;
    public static final int INDEX_RED        = 16;
    public static final int INDEX_REDORANGE  = 17;
    public static final int INDEX_SEAGREEN   = 18;
    public static final int INDEX_SKYBLUE    = 19;
    public static final int INDEX_VIOLET     = 20;
    public static final int INDEX_WHITE      = 21;
    public static final int INDEX_YELLOW     = 22;
    public static final int INDEX_YELLOWTINT = 23;

    private static ColorData[] _colors = new ColorData[]
    {
        new ColorData("BLACK"     , new Color(  0,   0,   0)),
        new ColorData("BLUE"      , new Color(  0,   0, 255)),
        new ColorData("BLUETINT"  , new Color(175, 214, 255)),
        new ColorData("BROWN"     , new Color(175, 117,  89)),
        new ColorData("CYAN"      , new Color(  0, 255, 255)),
        new ColorData("GOLD"      , new Color(255, 156,   0)),
        new ColorData("GREY"      , new Color(125, 125, 125)),
        new ColorData("GREEN"     , new Color(  0, 255,   0)),
        new ColorData("GREENBLUE" , new Color( 46, 139,  87)),
        new ColorData("GREENTINT" , new Color(152, 255, 179)),
        new ColorData("HOTPINK"   , new Color(255,   0, 101)),
        new ColorData("MAGENTA"   , new Color(255,   0, 255)),
        new ColorData("ORANGE"    , new Color(255, 165,   0)),
        new ColorData("PINK"      , new Color(255, 101, 117)),
        new ColorData("PINKTINT"  , new Color(255, 171, 187)),
        new ColorData("PURPLE"    , new Color(160,  32, 240)),
        new ColorData("RED"       , new Color(255,   0,   0)),
        new ColorData("REDORANGE" , new Color(255,  69,   0)),
        new ColorData("SEAGREEN"  , new Color(  0, 250, 109)),
        new ColorData("SKYBLUE"   , new Color( 58, 144, 255)),
        new ColorData("VIOLET"    , new Color(238, 130, 238)),
        new ColorData("WHITE"     , new Color(255, 255, 255)),
        new ColorData("YELLOW"    , new Color(255, 255,   0)),
        new ColorData("YELLOWTINT", new Color(246, 246, 117))
    };

    private ColorTable()
    {
    }

    /**
     * Returns the number of predefined colors.
     */
    public static int counts()
    {
        return _colors.length;
    }

    /**
     * Returns the index of the specified color name.
     * Returns -1 for color names not defined.
     */
    public static int getIndex(String colorName)
    {
        String name = colorName.toUpperCase();

        for(int i=0; i<_colors.length; i++){
            if( name.equals(_colors[i].name) ) return i;
        }
        return -1;
    }

    /**
     * Tests whether the specified color name is defined.
     */
    public static boolean isColorName(String colorName)
    {
        int index = getIndex(colorName);
        return (index != -1);
    }

    /**
     * Returns the color name of the specified index.
     */
    public static String getColorName(int index)
    {
        return _colors[index].name;
    }

    /**
     * Returns the Color object of the specified index.
     */
    public static Color getColor(int index)
    {
        return _colors[index].color;
    }

    /**
     * Returns the Color object of the specified color name.
     * Returns null for color names not defined.
     */
    public static Color getColor(String colorName)
    {
        int index = getIndex(colorName);
        if(index != -1){
            return _colors[index].color;
        }
        else{
            return null;
        }
    }
}

