/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.tables;

import java.awt.Color;

/**
 * Class that contains properties of elements.
 */
public class ElementTable
{
    public static final float VDW_CARBON   = 1.872f;  // 468/250
    public static final float VDW_NITROGEN = 1.5f;    // 375/250
    public static final float VDW_OXYGEN   = 1.4f;    // 350/250
    public static final float VDW_SULFUR   = 1.848f;  // 462/250

    private static ElementData[] _elements = new ElementData[]
    {
        new ElementData(""            ,   "", 180, 360, 12),
        new ElementData("HYDROGEN"    ,  "H",  80, 275,  4),
        new ElementData("HELIUM"      , "He", 400, 550,  5),
        new ElementData("LITHIUM"     , "Li", 170, 305, 14),
        new ElementData("BERYLLIUM"   , "Be",  88, 157, 12),
        new ElementData("BORON"       ,  "B", 208, 387, 13),
        new ElementData("CARBON"      ,  "C", 180, 387,  0),
        new ElementData("NITROGEN"    ,  "N", 170, 350,  1),
        new ElementData("OXYGEN"      ,  "O", 170, 337,  2),
        new ElementData("FLUORINE"    ,  "F", 160, 325,  6),
        new ElementData("NEON"        , "Ne", 280, 505, 12),
        new ElementData("SODIUM"      , "Na", 243, 550,  7),
        new ElementData("MAGNESIUM"   , "Mg", 275, 375, 15),
        new ElementData("ALUMINUM"    , "Al", 338, 375,  9),
        new ElementData("SILICON"     , "Si", 300, 550,  6),
        new ElementData("PHOSPHORUS"  ,  "P", 259, 470,  8),
        new ElementData("SULFUR"      ,  "S", 255, 452,  3),
        new ElementData("CHLORINE"    , "Cl", 250, 437, 13),
        new ElementData("ARGON"       , "Ar", 392, 692, 12),
        new ElementData("POTASSIUM"   ,  "K", 332, 597, 12),
        new ElementData("CALCIUM"     , "Ca", 248, 487,  9),
        new ElementData("SCANDIUM"    , "Sc", 360, 330, 12),
        new ElementData("TITANIUM"    , "Ti", 368, 487,  9),
        new ElementData("VANADIUM"    ,  "V", 332, 265, 12),
        new ElementData("CHROMIUM"    , "Cr", 338, 282,  9),
        new ElementData("MANGANESE"   , "Mn", 338, 297,  9),
        new ElementData("IRON"        , "Fe", 335, 487,  8),
        new ElementData("COBALT"      , "Co", 332, 282, 12),
        new ElementData("NICKEL"      , "Ni", 405, 310, 10),
        new ElementData("COPPER"      , "Cu", 380, 287, 10),
        new ElementData("ZINC"        , "Zn", 362, 287, 10),
        new ElementData("GALLIUM"     , "Ga", 305, 387, 12),
        new ElementData("GERMANIUM"   , "Ge", 292, 999, 12),
        new ElementData("ARSENIC"     , "As", 302, 207, 12),
        new ElementData("SELENIUM"    , "Se", 305, 225, 12),
        new ElementData("BROMINE"     , "Br", 302, 437, 10),
        new ElementData("KRYPTON"     , "Kr", 400, 475, 12),
        new ElementData("RUBIDIUM"    , "Rb", 368, 662, 12),
        new ElementData("STRONTIUM"   , "Sr", 280, 505, 12),
        new ElementData("YTTRIUM"     ,  "Y", 445, 402, 12),
        new ElementData("ZIRCONIUM"   , "Zr", 390, 355, 12),
        new ElementData("NIOBIUM"     , "Nb", 370, 332, 12),
        new ElementData("MOLYBDENUM"  , "Mo", 368, 437, 12),
        new ElementData("TECHNETIUM"  , "Tc", 338, 450, 12),
        new ElementData("RUTHENIUM"   , "Ru", 350, 300, 12),
        new ElementData("RHODIUM"     , "Rh", 362, 305, 12),
        new ElementData("PALLADIUM"   , "Pd", 375, 360, 12),
        new ElementData("SILVER"      , "Ag", 398, 387,  9),
        new ElementData("CADMIUM"     , "Cd", 422, 437, 12),
        new ElementData("INDIUM"      , "In", 408, 362, 12),
        new ElementData("TIN"         , "Sn", 365, 417, 12),
        new ElementData("ANTIMONY"    , "Sb", 365, 280, 12),
        new ElementData("TELLURIUM"   , "Te", 368, 315, 12),
        new ElementData("IODINE"      ,  "I", 350, 437, 11),
        new ElementData("XENON"       , "Xe", 425, 525, 12),
        new ElementData("CESIUM"      , "Cs", 418, 752, 12),
        new ElementData("BARIUM"      , "Ba", 335, 602,  8),
        new ElementData("LANTHANUM"   , "La", 468, 457, 12),
        new ElementData("CERIUM"      , "Ce", 458, 465, 12),
        new ElementData("PRASEODYMIUM", "Pr", 455, 405, 12),
        new ElementData("NEODYMIUM"   , "Nd", 452, 447, 12),
        new ElementData("PROMETHIUM"  , "Pm", 450, 440, 12),
        new ElementData("SAMARIUM"    , "Sm", 450, 435, 12),
        new ElementData("EUROPIUM"    , "Eu", 498, 490, 12),
        new ElementData("GADOLINIUM"  , "Gd", 448, 422, 12),
        new ElementData("TERBIUM"     , "Tb", 440, 415, 12),
        new ElementData("DYSPROSIUM"  , "Dy", 438, 407, 12),
        new ElementData("HOLMIUM"     , "Ho", 435, 402, 12),
        new ElementData("ERBIUM"      , "Er", 432, 397, 12),
        new ElementData("THULIUM"     , "Tm", 430, 392, 12),
        new ElementData("YTTERBIUM"   , "Yb", 485, 385, 12),
        new ElementData("LUTETIUM"    , "Lu", 430, 382, 12),
        new ElementData("HAFNIUM"     , "Hf", 392, 350, 12),
        new ElementData("TANTALUM"    , "Ta", 358, 305, 12),
        new ElementData("TUNGSTEN"    ,  "W", 342, 315, 12),
        new ElementData("RHENIUM"     , "Re", 338, 325, 12),
        new ElementData("OSMIUM"      , "Os", 342, 395, 12),
        new ElementData("IRIDIUM"     , "Ir", 330, 305, 12),
        new ElementData("PLATINUM"    , "Pt", 375, 387, 12),
        new ElementData("GOLD"        , "Au", 375, 362,  6),
        new ElementData("MERCURY"     , "Hg", 425, 495, 12),
        new ElementData("THALLIUM"    , "Tl", 388, 427, 12),
        new ElementData("LEAD"        , "Pb", 385, 540, 12),
        new ElementData("BISMUTH"     , "Bi", 385, 432, 12),
        new ElementData("POLONIUM"    , "Po", 420, 302, 12),
        new ElementData("ASTATINE"    , "At", 302, 280, 12),
        new ElementData("RADON"       , "Rn", 475, 575, 12),
        new ElementData("FRANCIUM"    , "Fr", 450, 810, 12),
        new ElementData("RADIUM"      , "Ra", 358, 642, 12),
        new ElementData("ACTINIUM"    , "Ac", 295, 530, 12),
        new ElementData("THORIUM"     , "Th", 255, 460, 12),
        new ElementData("PROTACTINIUM", "Pa", 222, 400, 12),
        new ElementData("URANIUM"     ,  "U", 242, 437, 12),
        new ElementData("NEPTUNIUM"   , "Np", 238, 427, 12),
        new ElementData("PLUTONIUM"   , "Pu", 232, 417, 12),
        new ElementData("AMERICIUM"   , "Am", 230, 415, 12),
        new ElementData("CURIUM"      , "Cm", 228, 412, 12),
        new ElementData("BERKELIUM"   , "Bk", 225, 410, 12),
        new ElementData("CALIFORNIUM" , "Cf", 222, 407, 12),
        new ElementData("EINSTEINIUM" , "Es", 220, 405, 12),
        new ElementData("FERMIUM"     , "Fm", 218, 402, 12),
        new ElementData("MENDELEVIUM" , "Md", 215, 400, 12),
        new ElementData("NOBELIUM"    , "No", 212, 397, 12),
        new ElementData("LAWRENCIUM"  , "Lr", 210, 395, 12)
    };

    private static Color[] _cpkColors = new Color[]
    {
        new Color(200, 200, 200), // Light Grey
        new Color(143, 143, 255), // Sky Blue
        new Color(240,   0,   0), // Red
        new Color(255, 200,  50), // Yellow
        new Color(255, 255, 255), // White
        new Color(255, 192, 203), // Pink
        new Color(218, 165,  32), // Golden Rod
        new Color(  0,   0, 255), // Blue
        new Color(255, 165,   0), // Orange
        new Color(128, 128, 144), // Dark Grey
        new Color(165,  42,  42), // Brown
        new Color(160,  32, 240), // Purple
        new Color(255,  20, 147), // Deep Pink
        new Color(  0, 255,   0), // Green
        new Color(178,  34,  34), // Fire Brick
        new Color( 34, 139,  34)  // Forest Green
    };

    private ElementTable()
    {
    }

    /**
     * Returns the number of elements registered.
     */
    public static int counts()
    {
        return _elements.length;
    }

    /**
     * Returns the atomic number of the specified element name.
     * Returns 0 for invalid element names.
     */
    public static int getAtomicNo(String elementName)
    {
        String name = fixIrregularName(elementName);

        for(int i=0; i<_elements.length; i++){
            if( name.equals(_elements[i].name) ) return i;
        }
        return 0;
    }

    /**
     * Returns the atomic number of the specified element symbpl.
     * Returns 0 for invalid element symbols.
     */
    public static int getAtomicNoBySymbol(String elementSymbol)
    {
        String symbol = elementSymbol.toUpperCase();

        for(int i=0; i<_elements.length; i++){
            if( symbol.equals(_elements[i].symbol.toUpperCase()) ) return i;
        }
        return 0;
    }

    /**
     * Tests whether the specified name is a valid element name.
     */
    public static boolean isElementName(String elementName)
    {
        int atomicNo = getAtomicNo(elementName);
        return (atomicNo != 0);
    }

    /**
     * Returns the name of the specified element.
     */
    public static String getName(int atomicNo)
    {
        return _elements[atomicNo].name;
    }

    /**
     * Returns the symbol of the specified element.
     */
    public static String getSymbol(int atomicNo)
    {
        return _elements[atomicNo].symbol;
    }

    /**
     * Returns the covalent radius of the specified element.
     */
    public static float getCovalentRadius(int atomicNo)
    {
        return _elements[atomicNo].covalentRadius;
    }

    /**
     * Returns the Van der Waals radius of the specified element.
     */
    public static float getVdWRadius(int atomicNo)
    {
        return _elements[atomicNo].vdwRadius;
    }

    /**
     * Returns the CPK color of the specified element.
     */
    public static Color getCPKColor(int atomicNo)
    {
        return _cpkColors[_elements[atomicNo].cpkColorIndex];
    }

    //--------------------------------------------------------------------
    // fix irregular names
    //--------------------------------------------------------------------
    private static String fixIrregularName(String elementName)
    {
        String name = elementName.toUpperCase();

        if( name.equals("ALUMINIUM") ){
            return "ALUMINUM";
        }
        else if( name.equals("CAESIUM") ){
            return "CESIUM";
        }
        else if( name.equals("SULPHUR") ){
            return "SULFUR";
        }

        return name;
    }
}
