/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.tables;

import java.awt.Color;

/**
 * Class that contains properties of residues.
 */
public class ResidueTable
{
    public static final int INDEX_OTHER  =  0;

    // Amino Acids
    public static final int INDEX_ALA    =  1;
    public static final int INDEX_GLY    =  2;
    public static final int INDEX_LEU    =  3;
    public static final int INDEX_SER    =  4;
    public static final int INDEX_VAL    =  5;
    public static final int INDEX_THR    =  6;
    public static final int INDEX_LYS    =  7;
    public static final int INDEX_ASP    =  8;
    public static final int INDEX_ILE    =  9;
    public static final int INDEX_ASN    = 10;
    public static final int INDEX_GLU    = 11;
    public static final int INDEX_PRO    = 12;
    public static final int INDEX_ARG    = 13;
    public static final int INDEX_PHE    = 14;
    public static final int INDEX_GLN    = 15;
    public static final int INDEX_TYR    = 16;
    public static final int INDEX_HIS    = 17;
    public static final int INDEX_CYS    = 18;
    public static final int INDEX_MET    = 19;
    public static final int INDEX_TRP    = 20;

    public static final int INDEX_ASX    = 21;
    public static final int INDEX_GLX    = 22;
    public static final int INDEX_PCA    = 23;
    public static final int INDEX_HYP    = 24;

    // DNA Nucleotides
    public static final int INDEX_A      = 25;
    public static final int INDEX_C      = 26;
    public static final int INDEX_G      = 27;
    public static final int INDEX_T      = 28;

    // RNA Nucleotides
    public static final int INDEX_U      = 29;
    public static final int INDEX_PLUS_U = 30;
    public static final int INDEX_I      = 31;
    public static final int INDEX_1MA    = 32;
    public static final int INDEX_5MC    = 33;
    public static final int INDEX_OMC    = 34;
    public static final int INDEX_1MG    = 35;
    public static final int INDEX_2MG    = 36;
    public static final int INDEX_M2G    = 37;
    public static final int INDEX_7MG    = 38;
    public static final int INDEX_OMG    = 39;
    public static final int INDEX_YG     = 40;
    public static final int INDEX_H2U    = 41;
    public static final int INDEX_5MU    = 42;
    public static final int INDEX_PSU    = 43;

    // Miscellaneous
    public static final int INDEX_UNK    = 44;
    public static final int INDEX_ACE    = 45;
    public static final int INDEX_FOR    = 46;
    public static final int INDEX_HOH    = 47;
    public static final int INDEX_DOD    = 48;
    public static final int INDEX_SO4    = 49;
    public static final int INDEX_PO4    = 50;
    public static final int INDEX_NAD    = 51;
    public static final int INDEX_COA    = 52;
    public static final int INDEX_NAP    = 53;
    public static final int INDEX_NDP    = 54;

    // PDB ver.3 DNA Nucleotides
    public static final int INDEX_V3_DA     = 55;
    public static final int INDEX_V3_DC     = 56;
    public static final int INDEX_V3_DG     = 57;
    public static final int INDEX_V3_DT     = 58;

    // PDB ver.3 RNA Nucleotides
    public static final int INDEX_V3_A      = 59;
    public static final int INDEX_V3_C      = 60;
    public static final int INDEX_V3_G      = 61;
    public static final int INDEX_V3_U      = 62;

    // PDB ver.3 other DNA Nucleotides
    public static final int INDEX_V3_1AP    = 63;
    public static final int INDEX_V3_2AR    = 64;
    public static final int INDEX_V3_2AT    = 65;
    public static final int INDEX_V3_2BD    = 66;
    public static final int INDEX_V3_2BT    = 67;
    public static final int INDEX_V3_2BU    = 68;
    public static final int INDEX_V3_2DA    = 69;
    public static final int INDEX_V3_2DF    = 70;
    public static final int INDEX_V3_2DM    = 71;
    public static final int INDEX_V3_2DT    = 72;
    public static final int INDEX_V3_2GT    = 73;
    public static final int INDEX_V3_2NT    = 74;
    public static final int INDEX_V3_2OT    = 75;
    public static final int INDEX_V3_2ST    = 76;
    public static final int INDEX_V3_3DA    = 77;
    public static final int INDEX_V3_3DR    = 78;
    public static final int INDEX_V3_3ME    = 79;
    public static final int INDEX_V3_4PC    = 80;
    public static final int INDEX_V3_4PD    = 81;
    public static final int INDEX_V3_4PE    = 82;
    public static final int INDEX_V3_4SC    = 83;
    public static final int INDEX_V3_5AA    = 84;
    public static final int INDEX_V3_5AT    = 85;
    public static final int INDEX_V3_5CG    = 86;
    public static final int INDEX_V3_5CM    = 87;
    public static final int INDEX_V3_5FC    = 88;
    public static final int INDEX_V3_5HT    = 89;
    public static final int INDEX_V3_5HU    = 90;
    public static final int INDEX_V3_5IU    = 91;
    public static final int INDEX_V3_5NC    = 92;
    public static final int INDEX_V3_5PC    = 93;
    public static final int INDEX_V3_64T    = 94;
    public static final int INDEX_V3_6HA    = 95;
    public static final int INDEX_V3_6HC    = 96;
    public static final int INDEX_V3_6HG    = 97;
    public static final int INDEX_V3_6HT    = 98;
    public static final int INDEX_V3_6MI    = 99;
    public static final int INDEX_V3_6OG    = 100;
    public static final int INDEX_V3_7DA    = 101;
    public static final int INDEX_V3_7GU    = 102;
    public static final int INDEX_V3_8FG    = 103;
    public static final int INDEX_V3_8MG    = 104;
    public static final int INDEX_V3_8OG    = 105;
    public static final int INDEX_V3_A1P    = 106;
    public static final int INDEX_V3_A34    = 107;
    public static final int INDEX_V3_A38    = 108;
    public static final int INDEX_V3_A3A    = 109;
    public static final int INDEX_V3_A40    = 110;
    public static final int INDEX_V3_A43    = 111;
    public static final int INDEX_V3_A47    = 112;
    public static final int INDEX_V3_ABR    = 113;
    public static final int INDEX_V3_ABS    = 114;
    public static final int INDEX_V3_ABT    = 115;
    public static final int INDEX_V3_AD2    = 116;
    public static final int INDEX_V3_AFG    = 117;
    public static final int INDEX_V3_AP7    = 118;
    public static final int INDEX_V3_APN    = 119;
    public static final int INDEX_V3_ATL    = 120;
    public static final int INDEX_V3_ATM    = 121;
    public static final int INDEX_V3_B1P    = 122;
    public static final int INDEX_V3_BGM    = 123;
    public static final int INDEX_V3_BOE    = 124;
    public static final int INDEX_V3_BRU    = 125;
    public static final int INDEX_V3_BVP    = 126;
    public static final int INDEX_V3_BZG    = 127;
    public static final int INDEX_V3_C2S    = 128;
    public static final int INDEX_V3_C34    = 129;
    public static final int INDEX_V3_C36    = 130;
    public static final int INDEX_V3_C37    = 131;
    public static final int INDEX_V3_C38    = 132;
    public static final int INDEX_V3_C42    = 133;
    public static final int INDEX_V3_C45    = 134;
    public static final int INDEX_V3_C46    = 135;
    public static final int INDEX_V3_C49    = 136;
    public static final int INDEX_V3_CB2    = 137;
    public static final int INDEX_V3_CBR    = 138;
    public static final int INDEX_V3_CFL    = 139;
    public static final int INDEX_V3_CMR    = 140;
    public static final int INDEX_V3_CP1    = 141;
    public static final int INDEX_V3_CPN    = 142;
    public static final int INDEX_V3_CSL    = 143;
    public static final int INDEX_V3_CTG    = 144;
    public static final int INDEX_V3_D4M    = 145;
    public static final int INDEX_V3_DCT    = 146;
    public static final int INDEX_V3_DDG    = 147;
    public static final int INDEX_V3_DDN    = 148;
    public static final int INDEX_V3_DDX    = 149;
    public static final int INDEX_V3_DFC    = 150;
    public static final int INDEX_V3_DFG    = 151;
    public static final int INDEX_V3_DGI    = 152;
    public static final int INDEX_V3_DGP    = 153;
    public static final int INDEX_V3_DI     = 154;
    public static final int INDEX_V3_DNR    = 155;
    public static final int INDEX_V3_DOC    = 156;
    public static final int INDEX_V3_DPB    = 157;
    public static final int INDEX_V3_DPY    = 158;
    public static final int INDEX_V3_DRM    = 159;
    public static final int INDEX_V3_DRP    = 160;
    public static final int INDEX_V3_DRT    = 161;
    public static final int INDEX_V3_DRZ    = 162;
    public static final int INDEX_V3_DU     = 163;
    public static final int INDEX_V3_DXD    = 164;
    public static final int INDEX_V3_DXN    = 165;
    public static final int INDEX_V3_E1X    = 166;
    public static final int INDEX_V3_EDA    = 167;
    public static final int INDEX_V3_EIT    = 168;
    public static final int INDEX_V3_FA2    = 169;
    public static final int INDEX_V3_FAG    = 170;
    public static final int INDEX_V3_FOX    = 171;
    public static final int INDEX_V3_G2S    = 172;
    public static final int INDEX_V3_G31    = 173;
    public static final int INDEX_V3_G33    = 174;
    public static final int INDEX_V3_G36    = 175;
    public static final int INDEX_V3_G38    = 176;
    public static final int INDEX_V3_G47    = 177;
    public static final int INDEX_V3_G49    = 178;
    public static final int INDEX_V3_GCK    = 179;
    public static final int INDEX_V3_GDR    = 180;
    public static final int INDEX_V3_GFL    = 181;
    public static final int INDEX_V3_GMS    = 182;
    public static final int INDEX_V3_GMU    = 183;
    public static final int INDEX_V3_GNE    = 184;
    public static final int INDEX_V3_GPN    = 185;
    public static final int INDEX_V3_HDP    = 186;
    public static final int INDEX_V3_HEU    = 187;
    public static final int INDEX_V3_HOB    = 188;
    public static final int INDEX_V3_HOL    = 189;
    public static final int INDEX_V3_I5C    = 190;
    public static final int INDEX_V3_IGU    = 191;
    public static final int INDEX_V3_IMC    = 192;
    public static final int INDEX_V3_IPN    = 193;
    public static final int INDEX_V3_LCA    = 194;
    public static final int INDEX_V3_LCC    = 195;
    public static final int INDEX_V3_LCG    = 196;
    public static final int INDEX_V3_LCH    = 197;
    public static final int INDEX_V3_LGP    = 198;
    public static final int INDEX_V3_LKC    = 199;
    public static final int INDEX_V3_M1G    = 200;
    public static final int INDEX_V3_MA7    = 201;
    public static final int INDEX_V3_MCY    = 202;
    public static final int INDEX_V3_MDR    = 203;
    public static final int INDEX_V3_MG1    = 204;
    public static final int INDEX_V3_MMT    = 205;
    public static final int INDEX_V3_MRG    = 206;
    public static final int INDEX_V3_MTR    = 207;
    public static final int INDEX_V3_NCX    = 208;
    public static final int INDEX_V3_NMS    = 209;
    public static final int INDEX_V3_NMT    = 210;
    public static final int INDEX_V3_NP3    = 211;
    public static final int INDEX_V3_NYM    = 212;
    public static final int INDEX_V3_O2C    = 213;
    public static final int INDEX_V3_P2T    = 214;
    public static final int INDEX_V3_P2U    = 215;
    public static final int INDEX_V3_PBT    = 216;
    public static final int INDEX_V3_PDU    = 217;
    public static final int INDEX_V3_PG7    = 218;
    public static final int INDEX_V3_PGN    = 219;
    public static final int INDEX_V3_PPW    = 220;
    public static final int INDEX_V3_PRN    = 221;
    public static final int INDEX_V3_PST    = 222;
    public static final int INDEX_V3_RMP    = 223;
    public static final int INDEX_V3_S2M    = 224;
    public static final int INDEX_V3_S6G    = 225;
    public static final int INDEX_V3_SMP    = 226;
    public static final int INDEX_V3_SPT    = 227;
    public static final int INDEX_V3_T2T    = 228;
    public static final int INDEX_V3_T32    = 229;
    public static final int INDEX_V3_T36    = 230;
    public static final int INDEX_V3_T3P    = 231;
    public static final int INDEX_V3_T48    = 232;
    public static final int INDEX_V3_T49    = 233;
    public static final int INDEX_V3_T4S    = 234;
    public static final int INDEX_V3_TA3    = 235;
    public static final int INDEX_V3_TAF    = 236;
    public static final int INDEX_V3_TC1    = 237;
    public static final int INDEX_V3_TFE    = 238;
    public static final int INDEX_V3_TFO    = 239;
    public static final int INDEX_V3_TFT    = 240;
    public static final int INDEX_V3_TGP    = 241;
    public static final int INDEX_V3_THX    = 242;
    public static final int INDEX_V3_TLC    = 243;
    public static final int INDEX_V3_TLN    = 244;
    public static final int INDEX_V3_TP1    = 245;
    public static final int INDEX_V3_TPC    = 246;
    public static final int INDEX_V3_TPN    = 247;
    public static final int INDEX_V3_TT     = 248;
    public static final int INDEX_V3_TTD    = 249;
    public static final int INDEX_V3_TTM    = 250;
    public static final int INDEX_V3_U33    = 251;
    public static final int INDEX_V3_UCL    = 252;
    public static final int INDEX_V3_UFP    = 253;
    public static final int INDEX_V3_UFR    = 254;
    public static final int INDEX_V3_UMS    = 255;
    public static final int INDEX_V3_US1    = 256;
    public static final int INDEX_V3_X      = 257;
    public static final int INDEX_V3_X4A    = 258;
    public static final int INDEX_V3_XAD    = 259;
    public static final int INDEX_V3_XAE    = 260;
    public static final int INDEX_V3_XAL    = 261;
    public static final int INDEX_V3_XCL    = 262;
    public static final int INDEX_V3_XCS    = 263;
    public static final int INDEX_V3_XCT    = 264;
    public static final int INDEX_V3_XCY    = 265;
    public static final int INDEX_V3_XGA    = 266;
    public static final int INDEX_V3_XGL    = 267;
    public static final int INDEX_V3_XGU    = 268;
    public static final int INDEX_V3_XTH    = 269;
    public static final int INDEX_V3_XTL    = 270;
    public static final int INDEX_V3_XTY    = 271;
    public static final int INDEX_V3_XUG    = 272;
    public static final int INDEX_V3_YRR    = 273;
    public static final int INDEX_V3_Z      = 274;
    public static final int INDEX_V3_ZDU    = 275;

    // PDB ver.3 other RNA Nucleotides
    public static final int INDEX_V3_125    = 276;
    public static final int INDEX_V3_126    = 277;
    public static final int INDEX_V3_127    = 278;
    public static final int INDEX_V3_128    = 279;
    public static final int INDEX_V3_12A    = 280;
    public static final int INDEX_V3_1MA    = 281;
    public static final int INDEX_V3_1MG    = 282;
    public static final int INDEX_V3_1PR    = 283;
    public static final int INDEX_V3_1SC    = 284;
    public static final int INDEX_V3_2AU    = 285;
    public static final int INDEX_V3_2EG    = 286;
    public static final int INDEX_V3_2MA    = 287;
    public static final int INDEX_V3_2MG    = 288;
    public static final int INDEX_V3_2MU    = 289;
    public static final int INDEX_V3_2PR    = 290;
    public static final int INDEX_V3_2SA    = 291;
    public static final int INDEX_V3_4AC    = 292;
    public static final int INDEX_V3_4OC    = 293;
    public static final int INDEX_V3_4SU    = 294;
    public static final int INDEX_V3_4TA    = 295;
    public static final int INDEX_V3_5BU    = 296;
    public static final int INDEX_V3_5FA    = 297;
    public static final int INDEX_V3_5FU    = 298;
    public static final int INDEX_V3_5IC    = 299;
    public static final int INDEX_V3_5MC    = 300;
    public static final int INDEX_V3_5MU    = 301;
    public static final int INDEX_V3_6IA    = 302;
    public static final int INDEX_V3_6MA    = 303;
    public static final int INDEX_V3_6MC    = 304;
    public static final int INDEX_V3_6MT    = 305;
    public static final int INDEX_V3_6MZ    = 306;
    public static final int INDEX_V3_70U    = 307;
    public static final int INDEX_V3_7MG    = 308;
    public static final int INDEX_V3_A23    = 309;
    public static final int INDEX_V3_A2L    = 310;
    public static final int INDEX_V3_A2M    = 311;
    public static final int INDEX_V3_A3P    = 312;
    public static final int INDEX_V3_A44    = 313;
    public static final int INDEX_V3_ADX    = 314;
    public static final int INDEX_V3_AET    = 315;
    public static final int INDEX_V3_AVC    = 316;
    public static final int INDEX_V3_BMP    = 317;
    public static final int INDEX_V3_BT5    = 318;
    public static final int INDEX_V3_C2L    = 319;
    public static final int INDEX_V3_C31    = 320;
    public static final int INDEX_V3_C43    = 321;
    public static final int INDEX_V3_CBV    = 322;
    public static final int INDEX_V3_CCC    = 323;
    public static final int INDEX_V3_CH     = 324;
    public static final int INDEX_V3_CM0    = 325;
    public static final int INDEX_V3_CS8    = 326;
    public static final int INDEX_V3_CSF    = 327;
    public static final int INDEX_V3_DBM    = 328;
    public static final int INDEX_V3_ENA    = 329;
    public static final int INDEX_V3_ENP    = 330;
    public static final int INDEX_V3_FA5    = 331;
    public static final int INDEX_V3_FHU    = 332;
    public static final int INDEX_V3_FMU    = 333;
    public static final int INDEX_V3_G25    = 334;
    public static final int INDEX_V3_G2L    = 335;
    public static final int INDEX_V3_G46    = 336;
    public static final int INDEX_V3_G48    = 337;
    public static final int INDEX_V3_G4P    = 338;
    public static final int INDEX_V3_G7M    = 339;
    public static final int INDEX_V3_GAO    = 340;
    public static final int INDEX_V3_GH3    = 341;
    public static final int INDEX_V3_GOM    = 342;
    public static final int INDEX_V3_H2U    = 343;
    public static final int INDEX_V3_I      = 344;
    public static final int INDEX_V3_IC     = 345;
    public static final int INDEX_V3_IG     = 346;
    public static final int INDEX_V3_IU     = 347;
    public static final int INDEX_V3_KAG    = 348;
    public static final int INDEX_V3_LC     = 349;
    public static final int INDEX_V3_LG     = 350;
    public static final int INDEX_V3_LHU    = 351;
    public static final int INDEX_V3_LMS    = 352;
    public static final int INDEX_V3_M2G    = 353;
    public static final int INDEX_V3_M5M    = 354;
    public static final int INDEX_V3_MA6    = 355;
    public static final int INDEX_V3_MAD    = 356;
    public static final int INDEX_V3_MIA    = 357;
    public static final int INDEX_V3_MNU    = 358;
    public static final int INDEX_V3_MTU    = 359;
    public static final int INDEX_V3_N      = 360;
    public static final int INDEX_V3_N6G    = 361;
    public static final int INDEX_V3_NF2    = 362;
    public static final int INDEX_V3_OAD    = 363;
    public static final int INDEX_V3_ODP    = 364;
    public static final int INDEX_V3_OMC    = 365;
    public static final int INDEX_V3_OMG    = 366;
    public static final int INDEX_V3_OMU    = 367;
    public static final int INDEX_V3_ONE    = 368;
    public static final int INDEX_V3_P1P    = 369;
    public static final int INDEX_V3_P5P    = 370;
    public static final int INDEX_V3_PGP    = 371;
    public static final int INDEX_V3_PMT    = 372;
    public static final int INDEX_V3_PPU    = 373;
    public static final int INDEX_V3_PQ1    = 374;
    public static final int INDEX_V3_PR5    = 375;
    public static final int INDEX_V3_PSU    = 376;
    public static final int INDEX_V3_PU     = 377;
    public static final int INDEX_V3_PUY    = 378;
    public static final int INDEX_V3_PYO    = 379;
    public static final int INDEX_V3_PYY    = 380;
    public static final int INDEX_V3_QUO    = 381;
    public static final int INDEX_V3_RIA    = 382;
    public static final int INDEX_V3_RTP    = 383;
    public static final int INDEX_V3_S4C    = 384;
    public static final int INDEX_V3_SMT    = 385;
    public static final int INDEX_V3_SRA    = 386;
    public static final int INDEX_V3_SSU    = 387;
    public static final int INDEX_V3_SUR    = 388;
    public static final int INDEX_V3_T23    = 389;
    public static final int INDEX_V3_T2S    = 390;
    public static final int INDEX_V3_T38    = 391;
    public static final int INDEX_V3_T39    = 392;
    public static final int INDEX_V3_T41    = 393;
    public static final int INDEX_V3_T6A    = 394;
    public static final int INDEX_V3_TAL    = 395;
    public static final int INDEX_V3_TLB    = 396;
    public static final int INDEX_V3_TPG    = 397;
    public static final int INDEX_V3_TYU    = 398;
    public static final int INDEX_V3_U2L    = 399;
    public static final int INDEX_V3_U2P    = 400;
    public static final int INDEX_V3_U31    = 401;
    public static final int INDEX_V3_U34    = 402;
    public static final int INDEX_V3_U36    = 403;
    public static final int INDEX_V3_U37    = 404;
    public static final int INDEX_V3_U8U    = 405;
    public static final int INDEX_V3_UAR    = 406;
    public static final int INDEX_V3_UD5    = 407;
    public static final int INDEX_V3_UDP    = 408;
    public static final int INDEX_V3_UMP    = 409;
    public static final int INDEX_V3_UR3    = 410;
    public static final int INDEX_V3_URD    = 411;
    public static final int INDEX_V3_XTS    = 412;
    public static final int INDEX_V3_YG     = 413;
    public static final int INDEX_V3_YYG    = 414;

    // PDB ver.3 other Proteins
    public static final int INDEX_004       = 415;
    public static final int INDEX_005       = 416;
    public static final int INDEX_006       = 417;
    public static final int INDEX_00B       = 418;
    public static final int INDEX_00C       = 419;
    public static final int INDEX_01W       = 420;
    public static final int INDEX_0A0       = 421;
    public static final int INDEX_0A1       = 422;
    public static final int INDEX_0A2       = 423;
    public static final int INDEX_0A8       = 424;
    public static final int INDEX_0A9       = 425;
    public static final int INDEX_0AB       = 426;
    public static final int INDEX_0AF       = 427;
    public static final int INDEX_0AG       = 428;
    public static final int INDEX_0AH       = 429;
    public static final int INDEX_0AK       = 430;
    public static final int INDEX_0AY       = 431;
    public static final int INDEX_0AZ       = 432;
    public static final int INDEX_0CS       = 433;
    public static final int INDEX_0D5       = 434;
    public static final int INDEX_0E2       = 435;
    public static final int INDEX_0E3       = 436;
    public static final int INDEX_0E4       = 437;
    public static final int INDEX_0EZ       = 438;
    public static final int INDEX_0G6       = 439;
    public static final int INDEX_0HG       = 440;
    public static final int INDEX_0NC       = 441;
    public static final int INDEX_0PJ       = 442;
    public static final int INDEX_0PN       = 443;
    public static final int INDEX_0YG       = 444;
    public static final int INDEX_0Z6       = 445;
    public static final int INDEX_143       = 446;
    public static final int INDEX_175       = 447;
    public static final int INDEX_193       = 448;
    public static final int INDEX_1PA       = 449;
    public static final int INDEX_1PI       = 450;
    public static final int INDEX_1TQ       = 451;
    public static final int INDEX_1TY       = 452;
    public static final int INDEX_1ZN       = 453;
    public static final int INDEX_200       = 454;
    public static final int INDEX_23F       = 455;
    public static final int INDEX_23S       = 456;
    public static final int INDEX_26B       = 457;
    public static final int INDEX_2AD       = 458;
    public static final int INDEX_2AG       = 459;
    public static final int INDEX_2AO       = 460;
    public static final int INDEX_2AS       = 461;
    public static final int INDEX_2CO       = 462;
    public static final int INDEX_2DO       = 463;
    public static final int INDEX_2FM       = 464;
    public static final int INDEX_2HF       = 465;
    public static final int INDEX_2ML       = 466;
    public static final int INDEX_2MR       = 467;
    public static final int INDEX_2MT       = 468;
    public static final int INDEX_2NC       = 469;
    public static final int INDEX_2TY       = 470;
    public static final int INDEX_2VA       = 471;
    public static final int INDEX_2Z9       = 472;
    public static final int INDEX_32S       = 473;
    public static final int INDEX_32T       = 474;
    public static final int INDEX_3AH       = 475;
    public static final int INDEX_3AR       = 476;
    public static final int INDEX_3FG       = 477;
    public static final int INDEX_3GA       = 478;
    public static final int INDEX_3MM       = 479;
    public static final int INDEX_3MY       = 480;
    public static final int INDEX_3TL       = 481;
    public static final int INDEX_3TY       = 482;
    public static final int INDEX_3XH       = 483;
    public static final int INDEX_40A       = 484;
    public static final int INDEX_40C       = 485;
    public static final int INDEX_40G       = 486;
    public static final int INDEX_40T       = 487;
    public static final int INDEX_4AF       = 488;
    public static final int INDEX_4BF       = 489;
    public static final int INDEX_4DP       = 490;
    public static final int INDEX_4F3       = 491;
    public static final int INDEX_4FB       = 492;
    public static final int INDEX_4FW       = 493;
    public static final int INDEX_4HT       = 494;
    public static final int INDEX_4IN       = 495;
    public static final int INDEX_4MM       = 496;
    public static final int INDEX_4PH       = 497;
    public static final int INDEX_5CS       = 498;
    public static final int INDEX_5OH       = 499;
    public static final int INDEX_5PG       = 500;
    public static final int INDEX_5ZA       = 501;
    public static final int INDEX_6CL       = 502;
    public static final int INDEX_6CW       = 503;
    public static final int INDEX_6HN       = 504;
    public static final int INDEX_7HA       = 505;
    public static final int INDEX_A66       = 506;
    public static final int INDEX_A70       = 507;
    public static final int INDEX_A9D       = 508;
    public static final int INDEX_AA4       = 509;
    public static final int INDEX_AA6       = 510;
    public static final int INDEX_AAR       = 511;
    public static final int INDEX_ABA       = 512;
    public static final int INDEX_ACB       = 513;
    public static final int INDEX_ACL       = 514;
    public static final int INDEX_ADD       = 515;
    public static final int INDEX_AEA       = 516;
    public static final int INDEX_AEI       = 517;
    public static final int INDEX_AFA       = 518;
    public static final int INDEX_AGD       = 519;
    public static final int INDEX_AGM       = 520;
    public static final int INDEX_AGT       = 521;
    public static final int INDEX_AHB       = 522;
    public static final int INDEX_AHH       = 523;
    public static final int INDEX_AHO       = 524;
    public static final int INDEX_AHP       = 525;
    public static final int INDEX_AHS       = 526;
    public static final int INDEX_AHT       = 527;
    public static final int INDEX_AIB       = 528;
    public static final int INDEX_AKL       = 529;
    public static final int INDEX_ALC       = 530;
    public static final int INDEX_ALG       = 531;
    public static final int INDEX_ALM       = 532;
    public static final int INDEX_ALN       = 533;
    public static final int INDEX_ALO       = 534;
    public static final int INDEX_ALS       = 535;
    public static final int INDEX_ALT       = 536;
    public static final int INDEX_ALY       = 537;
    public static final int INDEX_APE       = 538;
    public static final int INDEX_APH       = 539;
    public static final int INDEX_API       = 540;
    public static final int INDEX_APK       = 541;
    public static final int INDEX_APM       = 542;
    public static final int INDEX_APO       = 543;
    public static final int INDEX_APP       = 544;
    public static final int INDEX_AR2       = 545;
    public static final int INDEX_AR4       = 546;
    public static final int INDEX_ARF       = 547;
    public static final int INDEX_ARM       = 548;
    public static final int INDEX_ARO       = 549;
    public static final int INDEX_ARV       = 550;
    public static final int INDEX_AS2       = 551;
    public static final int INDEX_AS9       = 552;
    public static final int INDEX_ASA       = 553;
    public static final int INDEX_ASB       = 554;
    public static final int INDEX_ASK       = 555;
    public static final int INDEX_ASL       = 556;
    public static final int INDEX_ASM       = 557;
    public static final int INDEX_AVN       = 558;
    public static final int INDEX_AYA       = 559;
    public static final int INDEX_AYG       = 560;
    public static final int INDEX_AYI       = 561;
    public static final int INDEX_AYQ       = 562;
    public static final int INDEX_AZ0       = 563;
    public static final int INDEX_AZK       = 564;
    public static final int INDEX_AZS       = 565;
    public static final int INDEX_AZY       = 566;
    public static final int INDEX_B27       = 567;
    public static final int INDEX_B2A       = 568;
    public static final int INDEX_B2F       = 569;
    public static final int INDEX_B2I       = 570;
    public static final int INDEX_B2V       = 571;
    public static final int INDEX_B3A       = 572;
    public static final int INDEX_B3D       = 573;
    public static final int INDEX_B3E       = 574;
    public static final int INDEX_B3K       = 575;
    public static final int INDEX_B3L       = 576;
    public static final int INDEX_B3M       = 577;
    public static final int INDEX_B3Q       = 578;
    public static final int INDEX_B3S       = 579;
    public static final int INDEX_B3T       = 580;
    public static final int INDEX_B3U       = 581;
    public static final int INDEX_B3X       = 582;
    public static final int INDEX_B3Y       = 583;
    public static final int INDEX_BAL       = 584;
    public static final int INDEX_BB6       = 585;
    public static final int INDEX_BB7       = 586;
    public static final int INDEX_BB9       = 587;
    public static final int INDEX_BBC       = 588;
    public static final int INDEX_BCC       = 589;
    public static final int INDEX_BCS       = 590;
    public static final int INDEX_BCX       = 591;
    public static final int INDEX_BE2       = 592;
    public static final int INDEX_BFD       = 593;
    public static final int INDEX_BG1       = 594;
    public static final int INDEX_BHD       = 595;
    public static final int INDEX_BIF       = 596;
    public static final int INDEX_BIL       = 597;
    public static final int INDEX_BIU       = 598;
    public static final int INDEX_BJH       = 599;
    public static final int INDEX_BLE       = 600;
    public static final int INDEX_BLY       = 601;
    public static final int INDEX_BMT       = 602;
    public static final int INDEX_BNN       = 603;
    public static final int INDEX_BNO       = 604;
    public static final int INDEX_BOR       = 605;
    public static final int INDEX_BPE       = 606;
    public static final int INDEX_BSE       = 607;
    public static final int INDEX_BTK       = 608;
    public static final int INDEX_BTR       = 609;
    public static final int INDEX_BUC       = 610;
    public static final int INDEX_BUG       = 611;
    public static final int INDEX_C12       = 612;
    public static final int INDEX_C1T       = 613;
    public static final int INDEX_C1X       = 614;
    public static final int INDEX_C3Y       = 615;
    public static final int INDEX_C4R       = 616;
    public static final int INDEX_C5C       = 617;
    public static final int INDEX_C66       = 618;
    public static final int INDEX_C6C       = 619;
    public static final int INDEX_C99       = 620;
    public static final int INDEX_CAB       = 621;
    public static final int INDEX_CAF       = 622;
    public static final int INDEX_CAL       = 623;
    public static final int INDEX_CAS       = 624;
    public static final int INDEX_CAV       = 625;
    public static final int INDEX_CCL       = 626;
    public static final int INDEX_CCS       = 627;
    public static final int INDEX_CCY       = 628;
    public static final int INDEX_CDE       = 629;
    public static final int INDEX_CDV       = 630;
    public static final int INDEX_CFY       = 631;
    public static final int INDEX_CGA       = 632;
    public static final int INDEX_CGU       = 633;
    public static final int INDEX_CH6       = 634;
    public static final int INDEX_CH7       = 635;
    public static final int INDEX_CHF       = 636;
    public static final int INDEX_CHG       = 637;
    public static final int INDEX_CHP       = 638;
    public static final int INDEX_CHS       = 639;
    public static final int INDEX_CIR       = 640;
    public static final int INDEX_CJO       = 641;
    public static final int INDEX_CLB       = 642;
    public static final int INDEX_CLD       = 643;
    public static final int INDEX_CLE       = 644;
    public static final int INDEX_CLG       = 645;
    public static final int INDEX_CLH       = 646;
    public static final int INDEX_CLV       = 647;
    public static final int INDEX_CME       = 648;
    public static final int INDEX_CMH       = 649;
    public static final int INDEX_CML       = 650;
    public static final int INDEX_CMT       = 651;
    public static final int INDEX_CPC       = 652;
    public static final int INDEX_CPI       = 653;
    public static final int INDEX_CR0       = 654;
    public static final int INDEX_CR2       = 655;
    public static final int INDEX_CR5       = 656;
    public static final int INDEX_CR7       = 657;
    public static final int INDEX_CR8       = 658;
    public static final int INDEX_CRF       = 659;
    public static final int INDEX_CRG       = 660;
    public static final int INDEX_CRK       = 661;
    public static final int INDEX_CRO       = 662;
    public static final int INDEX_CRQ       = 663;
    public static final int INDEX_CRU       = 664;
    public static final int INDEX_CRW       = 665;
    public static final int INDEX_CRX       = 666;
    public static final int INDEX_CS1       = 667;
    public static final int INDEX_CS3       = 668;
    public static final int INDEX_CS4       = 669;
    public static final int INDEX_CSA       = 670;
    public static final int INDEX_CSB       = 671;
    public static final int INDEX_CSD       = 672;
    public static final int INDEX_CSE       = 673;
    public static final int INDEX_CSH       = 674;
    public static final int INDEX_CSI       = 675;
    public static final int INDEX_CSJ       = 676;
    public static final int INDEX_CSO       = 677;
    public static final int INDEX_CSP       = 678;
    public static final int INDEX_CSR       = 679;
    public static final int INDEX_CSS       = 680;
    public static final int INDEX_CSU       = 681;
    public static final int INDEX_CSW       = 682;
    public static final int INDEX_CSX       = 683;
    public static final int INDEX_CSY       = 684;
    public static final int INDEX_CSZ       = 685;
    public static final int INDEX_CTE       = 686;
    public static final int INDEX_CTH       = 687;
    public static final int INDEX_CUD       = 688;
    public static final int INDEX_CWR       = 689;
    public static final int INDEX_CXM       = 690;
    public static final int INDEX_CY0       = 691;
    public static final int INDEX_CY1       = 692;
    public static final int INDEX_CY3       = 693;
    public static final int INDEX_CY4       = 694;
    public static final int INDEX_CYD       = 695;
    public static final int INDEX_CYF       = 696;
    public static final int INDEX_CYG       = 697;
    public static final int INDEX_CYJ       = 698;
    public static final int INDEX_CYQ       = 699;
    public static final int INDEX_CYR       = 700;
    public static final int INDEX_CZ2       = 701;
    public static final int INDEX_CZO       = 702;
    public static final int INDEX_CZZ       = 703;
    public static final int INDEX_D11       = 704;
    public static final int INDEX_D3P       = 705;
    public static final int INDEX_D4P       = 706;
    public static final int INDEX_DA2       = 707;
    public static final int INDEX_DAB       = 708;
    public static final int INDEX_DAH       = 709;
    public static final int INDEX_DAL       = 710;
    public static final int INDEX_DAM       = 711;
    public static final int INDEX_DAR       = 712;
    public static final int INDEX_DAS       = 713;
    public static final int INDEX_DBB       = 714;
    public static final int INDEX_DBS       = 715;
    public static final int INDEX_DBU       = 716;
    public static final int INDEX_DBY       = 717;
    public static final int INDEX_DBZ       = 718;
    public static final int INDEX_DCL       = 719;
    public static final int INDEX_DCY       = 720;
    public static final int INDEX_DDE       = 721;
    public static final int INDEX_DDZ       = 722;
    public static final int INDEX_DFI       = 723;
    public static final int INDEX_DFO       = 724;
    public static final int INDEX_DGL       = 725;
    public static final int INDEX_DGN       = 726;
    public static final int INDEX_DHA       = 727;
    public static final int INDEX_DHI       = 728;
    public static final int INDEX_DHL       = 729;
    public static final int INDEX_DHP       = 730;
    public static final int INDEX_DIL       = 731;
    public static final int INDEX_DIR       = 732;
    public static final int INDEX_DIV       = 733;
    public static final int INDEX_DLE       = 734;
    public static final int INDEX_DLS       = 735;
    public static final int INDEX_DLY       = 736;
    public static final int INDEX_DM0       = 737;
    public static final int INDEX_DMH       = 738;
    public static final int INDEX_DMK       = 739;
    public static final int INDEX_DMT       = 740;
    public static final int INDEX_DNE       = 741;
    public static final int INDEX_DNG       = 742;
    public static final int INDEX_DNL       = 743;
    public static final int INDEX_DNM       = 744;
    public static final int INDEX_DNP       = 745;
    public static final int INDEX_DNS       = 746;
    public static final int INDEX_DOA       = 747;
    public static final int INDEX_DON       = 748;
    public static final int INDEX_DPL       = 749;
    public static final int INDEX_DPN       = 750;
    public static final int INDEX_DPP       = 751;
    public static final int INDEX_DPQ       = 752;
    public static final int INDEX_DPR       = 753;
    public static final int INDEX_DSE       = 754;
    public static final int INDEX_DSG       = 755;
    public static final int INDEX_DSN       = 756;
    public static final int INDEX_DTH       = 757;
    public static final int INDEX_DTR       = 758;
    public static final int INDEX_DTY       = 759;
    public static final int INDEX_DVA       = 760;
    public static final int INDEX_DYG       = 761;
    public static final int INDEX_DYS       = 762;
    public static final int INDEX_E13       = 763;
    public static final int INDEX_E14       = 764;
    public static final int INDEX_E15       = 765;
    public static final int INDEX_E16       = 766;
    public static final int INDEX_E17       = 767;
    public static final int INDEX_E19       = 768;
    public static final int INDEX_EFC       = 769;
    public static final int INDEX_EOV       = 770;
    public static final int INDEX_EP2       = 771;
    public static final int INDEX_ESB       = 772;
    public static final int INDEX_ESC       = 773;
    public static final int INDEX_ETA       = 774;
    public static final int INDEX_EXY       = 775;
    public static final int INDEX_EYS       = 776;
    public static final int INDEX_F2F       = 777;
    public static final int INDEX_FCL       = 778;
    public static final int INDEX_FFM       = 779;
    public static final int INDEX_FGA       = 780;
    public static final int INDEX_FGK       = 781;
    public static final int INDEX_FGL       = 782;
    public static final int INDEX_FGP       = 783;
    public static final int INDEX_FH7       = 784;
    public static final int INDEX_FHL       = 785;
    public static final int INDEX_FHO       = 786;
    public static final int INDEX_FLA       = 787;
    public static final int INDEX_FLE       = 788;
    public static final int INDEX_FLT       = 789;
    public static final int INDEX_FME       = 790;
    public static final int INDEX_FOE       = 791;
    public static final int INDEX_FOG       = 792;
    public static final int INDEX_FP9       = 793;
    public static final int INDEX_FPR       = 794;
    public static final int INDEX_FRD       = 795;
    public static final int INDEX_FT6       = 796;
    public static final int INDEX_FTR       = 797;
    public static final int INDEX_FTY       = 798;
    public static final int INDEX_FYI       = 799;
    public static final int INDEX_FYQ       = 800;
    public static final int INDEX_FZN       = 801;
    public static final int INDEX_G01       = 802;
    public static final int INDEX_GAU       = 803;
    public static final int INDEX_GHC       = 804;
    public static final int INDEX_GHG       = 805;
    public static final int INDEX_GHP       = 806;
    public static final int INDEX_GHW       = 807;
    public static final int INDEX_GL3       = 808;
    public static final int INDEX_GLH       = 809;
    public static final int INDEX_GLM       = 810;
    public static final int INDEX_GLQ       = 811;
    public static final int INDEX_GLZ       = 812;
    public static final int INDEX_GMA       = 813;
    public static final int INDEX_GME       = 814;
    public static final int INDEX_GND       = 815;
    public static final int INDEX_GPL       = 816;
    public static final int INDEX_GSC       = 817;
    public static final int INDEX_GSU       = 818;
    public static final int INDEX_GT9       = 819;
    public static final int INDEX_GVE       = 820;
    public static final int INDEX_GVL       = 821;
    public static final int INDEX_GYC       = 822;
    public static final int INDEX_GYS       = 823;
    public static final int INDEX_H5M       = 824;
    public static final int INDEX_HAQ       = 825;
    public static final int INDEX_HAR       = 826;
    public static final int INDEX_HBN       = 827;
    public static final int INDEX_HCS       = 828;
    public static final int INDEX_HF2       = 829;
    public static final int INDEX_HFA       = 830;
    public static final int INDEX_HGL       = 831;
    public static final int INDEX_HHK       = 832;
    public static final int INDEX_HIA       = 833;
    public static final int INDEX_HIC       = 834;
    public static final int INDEX_HIP       = 835;
    public static final int INDEX_HIQ       = 836;
    public static final int INDEX_HL2       = 837;
    public static final int INDEX_HLU       = 838;
    public static final int INDEX_HMF       = 839;
    public static final int INDEX_HMR       = 840;
    public static final int INDEX_HOX       = 841;
    public static final int INDEX_HPE       = 842;
    public static final int INDEX_HPH       = 843;
    public static final int INDEX_HPQ       = 844;
    public static final int INDEX_HQA       = 845;
    public static final int INDEX_HRG       = 846;
    public static final int INDEX_HRP       = 847;
    public static final int INDEX_HS8       = 848;
    public static final int INDEX_HS9       = 849;
    public static final int INDEX_HSE       = 850;
    public static final int INDEX_HSL       = 851;
    public static final int INDEX_HSO       = 852;
    public static final int INDEX_HTI       = 853;
    public static final int INDEX_HTR       = 854;
    public static final int INDEX_HV8       = 855;
    public static final int INDEX_HY3       = 856;
    public static final int INDEX_HZP       = 857;
    public static final int INDEX_I58       = 858;
    public static final int INDEX_IAM       = 859;
    public static final int INDEX_IEL       = 860;
    public static final int INDEX_IEY       = 861;
    public static final int INDEX_IGL       = 862;
    public static final int INDEX_IHN       = 863;
    public static final int INDEX_IIC       = 864;
    public static final int INDEX_IIL       = 865;
    public static final int INDEX_ILG       = 866;
    public static final int INDEX_ILX       = 867;
    public static final int INDEX_IML       = 868;
    public static final int INDEX_IOY       = 869;
    public static final int INDEX_IPG       = 870;
    public static final int INDEX_IT1       = 871;
    public static final int INDEX_IYR       = 872;
    public static final int INDEX_IYT       = 873;
    public static final int INDEX_K1R       = 874;
    public static final int INDEX_KBE       = 875;
    public static final int INDEX_KCX       = 876;
    public static final int INDEX_KGC       = 877;
    public static final int INDEX_KOR       = 878;
    public static final int INDEX_KPI       = 879;
    public static final int INDEX_KST       = 880;
    public static final int INDEX_KYN       = 881;
    public static final int INDEX_KYQ       = 882;
    public static final int INDEX_L2A       = 883;
    public static final int INDEX_L3A       = 884;
    public static final int INDEX_L3O       = 885;
    public static final int INDEX_LA2       = 886;
    public static final int INDEX_LAA       = 887;
    public static final int INDEX_LAL       = 888;
    public static final int INDEX_LBY       = 889;
    public static final int INDEX_LCK       = 890;
    public static final int INDEX_LDH       = 891;
    public static final int INDEX_LE1       = 892;
    public static final int INDEX_LED       = 893;
    public static final int INDEX_LEF       = 894;
    public static final int INDEX_LEH       = 895;
    public static final int INDEX_LEI       = 896;
    public static final int INDEX_LEM       = 897;
    public static final int INDEX_LEN       = 898;
    public static final int INDEX_LEP       = 899;
    public static final int INDEX_LET       = 900;
    public static final int INDEX_LHC       = 901;
    public static final int INDEX_LLP       = 902;
    public static final int INDEX_LLY       = 903;
    public static final int INDEX_LME       = 904;
    public static final int INDEX_LNT       = 905;
    public static final int INDEX_LOL       = 906;
    public static final int INDEX_LOV       = 907;
    public static final int INDEX_LP6       = 908;
    public static final int INDEX_LPD       = 909;
    public static final int INDEX_LPG       = 910;
    public static final int INDEX_LPL       = 911;
    public static final int INDEX_LPS       = 912;
    public static final int INDEX_LSO       = 913;
    public static final int INDEX_LTA       = 914;
    public static final int INDEX_LVG       = 915;
    public static final int INDEX_LVN       = 916;
    public static final int INDEX_LWY       = 917;
    public static final int INDEX_LYM       = 918;
    public static final int INDEX_LYN       = 919;
    public static final int INDEX_LYR       = 920;
    public static final int INDEX_LYX       = 921;
    public static final int INDEX_LYZ       = 922;
    public static final int INDEX_M0H       = 923;
    public static final int INDEX_M2L       = 924;
    public static final int INDEX_M3L       = 925;
    public static final int INDEX_M3R       = 926;
    public static final int INDEX_MA        = 927;
    public static final int INDEX_MAA       = 928;
    public static final int INDEX_MAI       = 929;
    public static final int INDEX_MBQ       = 930;
    public static final int INDEX_MC1       = 931;
    public static final int INDEX_MCG       = 932;
    public static final int INDEX_MCL       = 933;
    public static final int INDEX_MCS       = 934;
    public static final int INDEX_MDH       = 935;
    public static final int INDEX_MDO       = 936;
    public static final int INDEX_MEA       = 937;
    public static final int INDEX_MED       = 938;
    public static final int INDEX_MEG       = 939;
    public static final int INDEX_MEN       = 940;
    public static final int INDEX_MEQ       = 941;
    public static final int INDEX_MEU       = 942;
    public static final int INDEX_MF3       = 943;
    public static final int INDEX_MFC       = 944;
    public static final int INDEX_MGG       = 945;
    public static final int INDEX_MGN       = 946;
    public static final int INDEX_MH6       = 947;
    public static final int INDEX_MHL       = 948;
    public static final int INDEX_MHO       = 949;
    public static final int INDEX_MHS       = 950;
    public static final int INDEX_MHU       = 951;
    public static final int INDEX_MHV       = 952;
    public static final int INDEX_MHW       = 953;
    public static final int INDEX_MID       = 954;
    public static final int INDEX_MIR       = 955;
    public static final int INDEX_MIS       = 956;
    public static final int INDEX_MIT       = 957;
    public static final int INDEX_MK8       = 958;
    public static final int INDEX_ML3       = 959;
    public static final int INDEX_MLE       = 960;
    public static final int INDEX_MLL       = 961;
    public static final int INDEX_MLY       = 962;
    public static final int INDEX_MLZ       = 963;
    public static final int INDEX_MME       = 964;
    public static final int INDEX_MNL       = 965;
    public static final int INDEX_MNV       = 966;
    public static final int INDEX_MOD       = 967;
    public static final int INDEX_MP8       = 968;
    public static final int INDEX_MPH       = 969;
    public static final int INDEX_MPJ       = 970;
    public static final int INDEX_MPQ       = 971;
    public static final int INDEX_MSA       = 972;
    public static final int INDEX_MSE       = 973;
    public static final int INDEX_MSL       = 974;
    public static final int INDEX_MSO       = 975;
    public static final int INDEX_MSP       = 976;
    public static final int INDEX_MT2       = 977;
    public static final int INDEX_MTY       = 978;
    public static final int INDEX_MVA       = 979;
    public static final int INDEX_MYN       = 980;
    public static final int INDEX_N10       = 981;
    public static final int INDEX_N2C       = 982;
    public static final int INDEX_N31       = 983;
    public static final int INDEX_N7P       = 984;
    public static final int INDEX_NAL       = 985;
    public static final int INDEX_NAM       = 986;
    public static final int INDEX_NBQ       = 987;
    public static final int INDEX_NC1       = 988;
    public static final int INDEX_NCB       = 989;
    public static final int INDEX_NCY       = 990;
    public static final int INDEX_NDF       = 991;
    public static final int INDEX_NEP       = 992;
    public static final int INDEX_NFA       = 993;
    public static final int INDEX_NHL       = 994;
    public static final int INDEX_NIY       = 995;
    public static final int INDEX_NKS       = 996;
    public static final int INDEX_NLE       = 997;
    public static final int INDEX_NLN       = 998;
    public static final int INDEX_NLO       = 999;
    public static final int INDEX_NLP       = 1000;
    public static final int INDEX_NLQ       = 1001;
    public static final int INDEX_NMC       = 1002;
    public static final int INDEX_NMM       = 1003;
    public static final int INDEX_NNH       = 1004;
    public static final int INDEX_NOR       = 1005;
    public static final int INDEX_NOT       = 1006;
    public static final int INDEX_NPH       = 1007;
    public static final int INDEX_NRG       = 1008;
    public static final int INDEX_NRP       = 1009;
    public static final int INDEX_NRQ       = 1010;
    public static final int INDEX_NSK       = 1011;
    public static final int INDEX_NVA       = 1012;
    public static final int INDEX_NYB       = 1013;
    public static final int INDEX_NYC       = 1014;
    public static final int INDEX_NYG       = 1015;
    public static final int INDEX_NYS       = 1016;
    public static final int INDEX_NZH       = 1017;
    public static final int INDEX_O12       = 1018;
    public static final int INDEX_OAS       = 1019;
    public static final int INDEX_OBF       = 1020;
    public static final int INDEX_OBS       = 1021;
    public static final int INDEX_OCS       = 1022;
    public static final int INDEX_OCY       = 1023;
    public static final int INDEX_ODA       = 1024;
    public static final int INDEX_ODS       = 1025;
    public static final int INDEX_OHI       = 1026;
    public static final int INDEX_OHS       = 1027;
    public static final int INDEX_OIC       = 1028;
    public static final int INDEX_OLT       = 1029;
    public static final int INDEX_OLZ       = 1030;
    public static final int INDEX_OMT       = 1031;
    public static final int INDEX_OMY       = 1032;
    public static final int INDEX_ONL       = 1033;
    public static final int INDEX_OPR       = 1034;
    public static final int INDEX_ORN       = 1035;
    public static final int INDEX_ORQ       = 1036;
    public static final int INDEX_OSE       = 1037;
    public static final int INDEX_OTH       = 1038;
    public static final int INDEX_OTT       = 1039;
    public static final int INDEX_OTY       = 1040;
    public static final int INDEX_OXX       = 1041;
    public static final int INDEX_OZT       = 1042;
    public static final int INDEX_P1L       = 1043;
    public static final int INDEX_P2Y       = 1044;
    public static final int INDEX_PAQ       = 1045;
    public static final int INDEX_PAT       = 1046;
    public static final int INDEX_PAU       = 1047;
    public static final int INDEX_PBB       = 1048;
    public static final int INDEX_PBF       = 1049;
    public static final int INDEX_PCE       = 1050;
    public static final int INDEX_PCS       = 1051;
    public static final int INDEX_PDD       = 1052;
    public static final int INDEX_PEC       = 1053;
    public static final int INDEX_PF5       = 1054;
    public static final int INDEX_PFF       = 1055;
    public static final int INDEX_PFX       = 1056;
    public static final int INDEX_PG1       = 1057;
    public static final int INDEX_PG9       = 1058;
    public static final int INDEX_PGL       = 1059;
    public static final int INDEX_PHA       = 1060;
    public static final int INDEX_PHD       = 1061;
    public static final int INDEX_PHI       = 1062;
    public static final int INDEX_PHL       = 1063;
    public static final int INDEX_PHM       = 1064;
    public static final int INDEX_PIV       = 1065;
    public static final int INDEX_PKR       = 1066;
    public static final int INDEX_PLE       = 1067;
    public static final int INDEX_PM3       = 1068;
    public static final int INDEX_PNZ       = 1069;
    public static final int INDEX_POM       = 1070;
    public static final int INDEX_PPH       = 1071;
    public static final int INDEX_PPN       = 1072;
    public static final int INDEX_PR0       = 1073;
    public static final int INDEX_PR3       = 1074;
    public static final int INDEX_PR9       = 1075;
    public static final int INDEX_PRK       = 1076;
    public static final int INDEX_PRQ       = 1077;
    public static final int INDEX_PRR       = 1078;
    public static final int INDEX_PRS       = 1079;
    public static final int INDEX_PRV       = 1080;
    public static final int INDEX_PS0       = 1081;
    public static final int INDEX_PSA       = 1082;
    public static final int INDEX_PSH       = 1083;
    public static final int INDEX_PSI       = 1084;
    public static final int INDEX_PSS       = 1085;
    public static final int INDEX_PSW       = 1086;
    public static final int INDEX_PTA       = 1087;
    public static final int INDEX_PTH       = 1088;
    public static final int INDEX_PTM       = 1089;
    public static final int INDEX_PTR       = 1090;
    public static final int INDEX_PVH       = 1091;
    public static final int INDEX_PYA       = 1092;
    public static final int INDEX_PYX       = 1093;
    public static final int INDEX_QDS       = 1094;
    public static final int INDEX_QLG       = 1095;
    public static final int INDEX_R1A       = 1096;
    public static final int INDEX_R1B       = 1097;
    public static final int INDEX_R1F       = 1098;
    public static final int INDEX_R2P       = 1099;
    public static final int INDEX_R7A       = 1100;
    public static final int INDEX_RC7       = 1101;
    public static final int INDEX_RCY       = 1102;
    public static final int INDEX_RDF       = 1103;
    public static final int INDEX_RGI       = 1104;
    public static final int INDEX_ROC       = 1105;
    public static final int INDEX_S1H       = 1106;
    public static final int INDEX_S2C       = 1107;
    public static final int INDEX_S2D       = 1108;
    public static final int INDEX_S2P       = 1109;
    public static final int INDEX_SAC       = 1110;
    public static final int INDEX_SAH       = 1111;
    public static final int INDEX_SAR       = 1112;
    public static final int INDEX_SBD       = 1113;
    public static final int INDEX_SBL       = 1114;
    public static final int INDEX_SC2       = 1115;
    public static final int INDEX_SCH       = 1116;
    public static final int INDEX_SCS       = 1117;
    public static final int INDEX_SCY       = 1118;
    public static final int INDEX_SD2       = 1119;
    public static final int INDEX_SDP       = 1120;
    public static final int INDEX_SEB       = 1121;
    public static final int INDEX_SEC       = 1122;
    public static final int INDEX_SEE       = 1123;
    public static final int INDEX_SEL       = 1124;
    public static final int INDEX_SEM       = 1125;
    public static final int INDEX_SEN       = 1126;
    public static final int INDEX_SEP       = 1127;
    public static final int INDEX_SET       = 1128;
    public static final int INDEX_SGB       = 1129;
    public static final int INDEX_SHC       = 1130;
    public static final int INDEX_SHP       = 1131;
    public static final int INDEX_SHR       = 1132;
    public static final int INDEX_SIB       = 1133;
    public static final int INDEX_SIC       = 1134;
    public static final int INDEX_SLA       = 1135;
    public static final int INDEX_SLR       = 1136;
    public static final int INDEX_SLZ       = 1137;
    public static final int INDEX_SMC       = 1138;
    public static final int INDEX_SME       = 1139;
    public static final int INDEX_SMF       = 1140;
    public static final int INDEX_SNC       = 1141;
    public static final int INDEX_SNN       = 1142;
    public static final int INDEX_SOC       = 1143;
    public static final int INDEX_SOY       = 1144;
    public static final int INDEX_STA       = 1145;
    public static final int INDEX_SUB       = 1146;
    public static final int INDEX_SUI       = 1147;
    public static final int INDEX_SUN       = 1148;
    public static final int INDEX_SVA       = 1149;
    public static final int INDEX_SVZ       = 1150;
    public static final int INDEX_SXE       = 1151;
    public static final int INDEX_SYS       = 1152;
    public static final int INDEX_T11       = 1153;
    public static final int INDEX_T66       = 1154;
    public static final int INDEX_TA4       = 1155;
    public static final int INDEX_TAV       = 1156;
    public static final int INDEX_TBG       = 1157;
    public static final int INDEX_TBM       = 1158;
    public static final int INDEX_TCK       = 1159;
    public static final int INDEX_TCQ       = 1160;
    public static final int INDEX_TCR       = 1161;
    public static final int INDEX_TFQ       = 1162;
    public static final int INDEX_THC       = 1163;
    public static final int INDEX_THO       = 1164;
    public static final int INDEX_THZ       = 1165;
    public static final int INDEX_TIH       = 1166;
    public static final int INDEX_TIS       = 1167;
    public static final int INDEX_TMD       = 1168;
    public static final int INDEX_TNB       = 1169;
    public static final int INDEX_TNR       = 1170;
    public static final int INDEX_TNY       = 1171;
    public static final int INDEX_TOX       = 1172;
    public static final int INDEX_TPL       = 1173;
    public static final int INDEX_TPO       = 1174;
    public static final int INDEX_TPQ       = 1175;
    public static final int INDEX_TQQ       = 1176;
    public static final int INDEX_TRF       = 1177;
    public static final int INDEX_TRN       = 1178;
    public static final int INDEX_TRO       = 1179;
    public static final int INDEX_TRQ       = 1180;
    public static final int INDEX_TRW       = 1181;
    public static final int INDEX_TRX       = 1182;
    public static final int INDEX_TS9       = 1183;
    public static final int INDEX_TST       = 1184;
    public static final int INDEX_TTQ       = 1185;
    public static final int INDEX_TTS       = 1186;
    public static final int INDEX_TY2       = 1187;
    public static final int INDEX_TYB       = 1188;
    public static final int INDEX_TYI       = 1189;
    public static final int INDEX_TYN       = 1190;
    public static final int INDEX_TYO       = 1191;
    public static final int INDEX_TYQ       = 1192;
    public static final int INDEX_TYS       = 1193;
    public static final int INDEX_TYT       = 1194;
    public static final int INDEX_TYX       = 1195;
    public static final int INDEX_TYY       = 1196;
    public static final int INDEX_TZB       = 1197;
    public static final int INDEX_TZO       = 1198;
    public static final int INDEX_UAL       = 1199;
    public static final int INDEX_UB2       = 1200;
    public static final int INDEX_UDS       = 1201;
    public static final int INDEX_UM1       = 1202;
    public static final int INDEX_UM2       = 1203;
    public static final int INDEX_UMA       = 1204;
    public static final int INDEX_UN1       = 1205;
    public static final int INDEX_UN2       = 1206;
    public static final int INDEX_VAD       = 1207;
    public static final int INDEX_VAF       = 1208;
    public static final int INDEX_VB1       = 1209;
    public static final int INDEX_VDL       = 1210;
    public static final int INDEX_VLL       = 1211;
    public static final int INDEX_VLM       = 1212;
    public static final int INDEX_VME       = 1213;
    public static final int INDEX_VMS       = 1214;
    public static final int INDEX_VOL       = 1215;
    public static final int INDEX_WFP       = 1216;
    public static final int INDEX_X2W       = 1217;
    public static final int INDEX_X97       = 1218;
    public static final int INDEX_X98       = 1219;
    public static final int INDEX_X99       = 1220;
    public static final int INDEX_X9A       = 1221;
    public static final int INDEX_X9Q       = 1222;
    public static final int INDEX_XCP       = 1223;
    public static final int INDEX_XLI       = 1224;
    public static final int INDEX_XPC       = 1225;
    public static final int INDEX_XX1       = 1226;
    public static final int INDEX_XXY       = 1227;
    public static final int INDEX_XYG       = 1228;
    public static final int INDEX_Y28       = 1229;
    public static final int INDEX_YCM       = 1230;
    public static final int INDEX_YCP       = 1231;
    public static final int INDEX_YEN       = 1232;
    public static final int INDEX_YNM       = 1233;
    public static final int INDEX_YOF       = 1234;
    public static final int INDEX_Z70       = 1235;
    public static final int INDEX_ZAE       = 1236;
    public static final int INDEX_ZAL       = 1237;
    public static final int INDEX_ZFB       = 1238;
    public static final int INDEX_ZUK       = 1239;
    public static final int INDEX_ZZD       = 1240;
    public static final int INDEX_ZZJ       = 1241;
    public static final int INDEX_ZZU       = 1242;

    public static final int PROP_ACIDIC      =  0;
    public static final int PROP_ACYCLIC     =  1;
    public static final int PROP_ALIPHATIC   =  2;
    public static final int PROP_AROMATIC    =  3;
    public static final int PROP_BASIC       =  4;
    public static final int PROP_BURIED      =  5;
    public static final int PROP_CHARGED     =  6;
    public static final int PROP_CYCLIC      =  7;
    public static final int PROP_HYDROPHOBIC =  8;
    public static final int PROP_LARGE       =  9;
    public static final int PROP_MEDIUM      = 10;
    public static final int PROP_NEGATIVE    = 11;
    public static final int PROP_NEUTRAL     = 12;
    public static final int PROP_POLAR       = 13;
    public static final int PROP_POSITIVE    = 14;
    public static final int PROP_SMALL       = 15;
    public static final int PROP_SURFACE     = 16;

    public static final int GROUP_AMINO      =  0;
    public static final int GROUP_PROTEIN    =  1;
    public static final int GROUP_NUCLEOTIDE =  2;
    public static final int GROUP_DNA        =  3;
    public static final int GROUP_RNA        =  4;
    public static final int GROUP_SOLVENT    =  5;
    public static final int GROUP_WATER      =  6;
    public static final int GROUP_ION        =  7;
    public static final int GROUP_COENZYME   =  8;
    public static final int GROUP_AMINO_20   =  9;

    private static ResidueData[] _residues = new ResidueData[]
    {
        new ResidueData(""   , 12, 27), // 0
        new ResidueData("ALA",  8,  0), // 1
        new ResidueData("GLY",  6,  1), // 2
        new ResidueData("LEU",  7,  2), // 3
        new ResidueData("SER",  3,  3), // 4
        new ResidueData("VAL",  7,  4), // 5
        new ResidueData("THR",  3,  5), // 6
        new ResidueData("LYS",  2,  6), // 7
        new ResidueData("ASP",  0,  7), // 8
        new ResidueData("ILE",  7,  8), // 9
        new ResidueData("ASN",  5,  9), // 10
        new ResidueData("GLU",  0, 10), // 11
        new ResidueData("PRO", 11, 11), // 12
        new ResidueData("ARG",  2, 12), // 13
        new ResidueData("PHE",  4, 13), // 14
        new ResidueData("GLN",  5, 14), // 15
        new ResidueData("TYR",  4, 15), // 16
        new ResidueData("HIS", 10, 16), // 17
        new ResidueData("CYS",  1, 17), // 18
        new ResidueData("MET",  1, 18), // 19
        new ResidueData("TRP",  9, 19), // 20
        new ResidueData("ASX", 12, 20), // 21
        new ResidueData("GLX", 12, 20), // 22
        new ResidueData("PCA", 12, 20), // 23
        new ResidueData("HYP", 12, 20), // 24
        new ResidueData("  A", 12, 21), // 25
        new ResidueData("  C", 12, 22), // 26
        new ResidueData("  G", 12, 23), // 27
        new ResidueData("  T", 12, 24), // 28
        new ResidueData("  U", 12, 27), // 29
        new ResidueData(" +U", 12, 27), // 30
        new ResidueData("  I", 12, 27), // 31
        new ResidueData("1MA", 12, 27), // 32
        new ResidueData("5MC", 12, 27), // 33
        new ResidueData("OMC", 12, 27), // 34
        new ResidueData("1MG", 12, 27), // 35
        new ResidueData("2MG", 12, 27), // 36
        new ResidueData("M2G", 12, 27), // 37
        new ResidueData("7MG", 12, 27), // 38
        new ResidueData("OMG", 12, 27), // 39
        new ResidueData(" YG", 12, 27), // 40
        new ResidueData("H2U", 12, 27), // 41
        new ResidueData("5MU", 12, 27), // 42
        new ResidueData("PSU", 12, 27), // 43
        new ResidueData("UNK", 12, 27), // 44
        new ResidueData("ACE", 12, 27), // 45
        new ResidueData("FOR", 12, 27), // 46
        new ResidueData("HOH", 12, 27), // 47
        new ResidueData("DOD", 12, 27), // 48
        new ResidueData("SO4", 12, 27), // 49
        new ResidueData("PO4", 12, 27), // 50
        new ResidueData("NAD", 12, 27), // 51
        new ResidueData("COA", 12, 27), // 52
        new ResidueData("NAP", 12, 27), // 53
        new ResidueData("NDP", 12, 27), // 54
        new ResidueData(" DA", 12, 21), // 55
        new ResidueData(" DC", 12, 22), // 56
        new ResidueData(" DG", 12, 23), // 57
        new ResidueData(" DT", 12, 24), // 58
        new ResidueData("  A", 12, 21), // 59
        new ResidueData("  C", 12, 22), // 60
        new ResidueData("  G", 12, 23), // 61
        new ResidueData("  U", 12, 27), // 62
        new ResidueData("1AP", 12, 27), // 63
        new ResidueData("2AR", 12, 27), // 64
        new ResidueData("2AT", 12, 27), // 65
        new ResidueData("2BD", 12, 27), // 66
        new ResidueData("2BT", 12, 27), // 67
        new ResidueData("2BU", 12, 27), // 68
        new ResidueData("2DA", 12, 27), // 69
        new ResidueData("2DF", 12, 27), // 70
        new ResidueData("2DM", 12, 27), // 71
        new ResidueData("2DT", 12, 27), // 72
        new ResidueData("2GT", 12, 27), // 73
        new ResidueData("2NT", 12, 27), // 74
        new ResidueData("2OT", 12, 27), // 75
        new ResidueData("2ST", 12, 27), // 76
        new ResidueData("3DA", 12, 27), // 77
        new ResidueData("3DR", 12, 27), // 78
        new ResidueData("3ME", 12, 27), // 79
        new ResidueData("4PC", 12, 27), // 80
        new ResidueData("4PD", 12, 27), // 81
        new ResidueData("4PE", 12, 27), // 82
        new ResidueData("4SC", 12, 27), // 83
        new ResidueData("5AA", 12, 27), // 84
        new ResidueData("5AT", 12, 27), // 85
        new ResidueData("5CG", 12, 27), // 86
        new ResidueData("5CM", 12, 27), // 87
        new ResidueData("5FC", 12, 27), // 88
        new ResidueData("5HT", 12, 27), // 89
        new ResidueData("5HU", 12, 27), // 90
        new ResidueData("5IU", 12, 27), // 91
        new ResidueData("5NC", 12, 27), // 92
        new ResidueData("5PC", 12, 27), // 93
        new ResidueData("64T", 12, 27), // 94
        new ResidueData("6HA", 12, 27), // 95
        new ResidueData("6HC", 12, 27), // 96
        new ResidueData("6HG", 12, 27), // 97
        new ResidueData("6HT", 12, 27), // 98
        new ResidueData("6MI", 12, 27), // 99
        new ResidueData("6OG", 12, 27), // 100
        new ResidueData("7DA", 12, 27), // 101
        new ResidueData("7GU", 12, 27), // 102
        new ResidueData("8FG", 12, 27), // 103
        new ResidueData("8MG", 12, 27), // 104
        new ResidueData("8OG", 12, 27), // 105
        new ResidueData("A1P", 12, 27), // 106
        new ResidueData("A34", 12, 27), // 107
        new ResidueData("A38", 12, 27), // 108
        new ResidueData("A3A", 12, 27), // 109
        new ResidueData("A40", 12, 27), // 110
        new ResidueData("A43", 12, 27), // 111
        new ResidueData("A47", 12, 27), // 112
        new ResidueData("ABR", 12, 27), // 113
        new ResidueData("ABS", 12, 27), // 114
        new ResidueData("ABT", 12, 27), // 115
        new ResidueData("AD2", 12, 27), // 116
        new ResidueData("AFG", 12, 27), // 117
        new ResidueData("AP7", 12, 27), // 118
        new ResidueData("APN", 12, 27), // 119
        new ResidueData("ATL", 12, 27), // 120
        new ResidueData("ATM", 12, 27), // 121
        new ResidueData("B1P", 12, 27), // 122
        new ResidueData("BGM", 12, 27), // 123
        new ResidueData("BOE", 12, 27), // 124
        new ResidueData("BRU", 12, 27), // 125
        new ResidueData("BVP", 12, 27), // 126
        new ResidueData("BZG", 12, 27), // 127
        new ResidueData("C2S", 12, 27), // 128
        new ResidueData("C34", 12, 27), // 129
        new ResidueData("C36", 12, 27), // 130
        new ResidueData("C37", 12, 27), // 131
        new ResidueData("C38", 12, 27), // 132
        new ResidueData("C42", 12, 27), // 133
        new ResidueData("C45", 12, 27), // 134
        new ResidueData("C46", 12, 27), // 135
        new ResidueData("C49", 12, 27), // 136
        new ResidueData("CB2", 12, 27), // 137
        new ResidueData("CBR", 12, 27), // 138
        new ResidueData("CFL", 12, 27), // 139
        new ResidueData("CMR", 12, 27), // 140
        new ResidueData("CP1", 12, 27), // 141
        new ResidueData("CPN", 12, 27), // 142
        new ResidueData("CSL", 12, 27), // 143
        new ResidueData("CTG", 12, 27), // 144
        new ResidueData("D4M", 12, 27), // 145
        new ResidueData("DCT", 12, 27), // 146
        new ResidueData("DDG", 12, 27), // 147
        new ResidueData("DDN", 12, 27), // 148
        new ResidueData("DDX", 12, 27), // 149
        new ResidueData("DFC", 12, 27), // 150
        new ResidueData("DFG", 12, 27), // 151
        new ResidueData("DGI", 12, 27), // 152
        new ResidueData("DGP", 12, 27), // 153
        new ResidueData(" DI", 12, 27), // 154
        new ResidueData("DNR", 12, 27), // 155
        new ResidueData("DOC", 12, 27), // 156
        new ResidueData("DPB", 12, 27), // 157
        new ResidueData("DPY", 12, 27), // 158
        new ResidueData("DRM", 12, 27), // 159
        new ResidueData("DRP", 12, 27), // 160
        new ResidueData("DRT", 12, 27), // 161
        new ResidueData("DRZ", 12, 27), // 162
        new ResidueData(" DU", 12, 27), // 163
        new ResidueData("DXD", 12, 27), // 164
        new ResidueData("DXN", 12, 27), // 165
        new ResidueData("E1X", 12, 27), // 166
        new ResidueData("EDA", 12, 27), // 167
        new ResidueData("EIT", 12, 27), // 168
        new ResidueData("FA2", 12, 27), // 169
        new ResidueData("FAG", 12, 27), // 170
        new ResidueData("FOX", 12, 27), // 171
        new ResidueData("G2S", 12, 27), // 172
        new ResidueData("G31", 12, 27), // 173
        new ResidueData("G33", 12, 27), // 174
        new ResidueData("G36", 12, 27), // 175
        new ResidueData("G38", 12, 27), // 176
        new ResidueData("G47", 12, 27), // 177
        new ResidueData("G49", 12, 27), // 178
        new ResidueData("GCK", 12, 27), // 179
        new ResidueData("GDR", 12, 27), // 180
        new ResidueData("GFL", 12, 27), // 181
        new ResidueData("GMS", 12, 27), // 182
        new ResidueData("GMU", 12, 27), // 183
        new ResidueData("GNE", 12, 27), // 184
        new ResidueData("GPN", 12, 27), // 185
        new ResidueData("HDP", 12, 27), // 186
        new ResidueData("HEU", 12, 27), // 187
        new ResidueData("HOB", 12, 27), // 188
        new ResidueData("HOL", 12, 27), // 189
        new ResidueData("I5C", 12, 27), // 190
        new ResidueData("IGU", 12, 27), // 191
        new ResidueData("IMC", 12, 27), // 192
        new ResidueData("IPN", 12, 27), // 193
        new ResidueData("LCA", 12, 27), // 194
        new ResidueData("LCC", 12, 27), // 195
        new ResidueData("LCG", 12, 27), // 196
        new ResidueData("LCH", 12, 27), // 197
        new ResidueData("LGP", 12, 27), // 198
        new ResidueData("LKC", 12, 27), // 199
        new ResidueData("M1G", 12, 27), // 200
        new ResidueData("MA7", 12, 27), // 201
        new ResidueData("MCY", 12, 27), // 202
        new ResidueData("MDR", 12, 27), // 203
        new ResidueData("MG1", 12, 27), // 204
        new ResidueData("MMT", 12, 27), // 205
        new ResidueData("MRG", 12, 27), // 206
        new ResidueData("MTR", 12, 27), // 207
        new ResidueData("NCX", 12, 27), // 208
        new ResidueData("NMS", 12, 27), // 209
        new ResidueData("NMT", 12, 27), // 210
        new ResidueData("NP3", 12, 27), // 211
        new ResidueData("NYM", 12, 27), // 212
        new ResidueData("O2C", 12, 27), // 213
        new ResidueData("P2T", 12, 27), // 214
        new ResidueData("P2U", 12, 27), // 215
        new ResidueData("PBT", 12, 27), // 216
        new ResidueData("PDU", 12, 27), // 217
        new ResidueData("PG7", 12, 27), // 218
        new ResidueData("PGN", 12, 27), // 219
        new ResidueData("PPW", 12, 27), // 220
        new ResidueData("PRN", 12, 27), // 221
        new ResidueData("PST", 12, 27), // 222
        new ResidueData("RMP", 12, 27), // 223
        new ResidueData("S2M", 12, 27), // 224
        new ResidueData("S6G", 12, 27), // 225
        new ResidueData("SMP", 12, 27), // 226
        new ResidueData("SPT", 12, 27), // 227
        new ResidueData("T2T", 12, 27), // 228
        new ResidueData("T32", 12, 27), // 229
        new ResidueData("T36", 12, 27), // 230
        new ResidueData("T3P", 12, 27), // 231
        new ResidueData("T48", 12, 27), // 232
        new ResidueData("T49", 12, 27), // 233
        new ResidueData("T4S", 12, 27), // 234
        new ResidueData("TA3", 12, 27), // 235
        new ResidueData("TAF", 12, 27), // 236
        new ResidueData("TC1", 12, 27), // 237
        new ResidueData("TFE", 12, 27), // 238
        new ResidueData("TFO", 12, 27), // 239
        new ResidueData("TFT", 12, 27), // 240
        new ResidueData("TGP", 12, 27), // 241
        new ResidueData("THX", 12, 27), // 242
        new ResidueData("TLC", 12, 27), // 243
        new ResidueData("TLN", 12, 27), // 244
        new ResidueData("TP1", 12, 27), // 245
        new ResidueData("TPC", 12, 27), // 246
        new ResidueData("TPN", 12, 27), // 247
        new ResidueData(" TT", 12, 27), // 248
        new ResidueData("TTD", 12, 27), // 249
        new ResidueData("TTM", 12, 27), // 250
        new ResidueData("U33", 12, 27), // 251
        new ResidueData("UCL", 12, 27), // 252
        new ResidueData("UFP", 12, 27), // 253
        new ResidueData("UFR", 12, 27), // 254
        new ResidueData("UMS", 12, 27), // 255
        new ResidueData("US1", 12, 27), // 256
        new ResidueData("  X", 12, 27), // 257
        new ResidueData("X4A", 12, 27), // 258
        new ResidueData("XAD", 12, 27), // 259
        new ResidueData("XAE", 12, 27), // 260
        new ResidueData("XAL", 12, 27), // 261
        new ResidueData("XCL", 12, 27), // 262
        new ResidueData("XCS", 12, 27), // 263
        new ResidueData("XCT", 12, 27), // 264
        new ResidueData("XCY", 12, 27), // 265
        new ResidueData("XGA", 12, 27), // 266
        new ResidueData("XGL", 12, 27), // 267
        new ResidueData("XGU", 12, 27), // 268
        new ResidueData("XTH", 12, 27), // 269
        new ResidueData("XTL", 12, 27), // 270
        new ResidueData("XTY", 12, 27), // 271
        new ResidueData("XUG", 12, 27), // 272
        new ResidueData("YRR", 12, 27), // 273
        new ResidueData("  Z", 12, 27), // 274
        new ResidueData("ZDU", 12, 27), // 275
        new ResidueData("125", 12, 27), // 276
        new ResidueData("126", 12, 27), // 277
        new ResidueData("127", 12, 27), // 278
        new ResidueData("128", 12, 27), // 279
        new ResidueData("12A", 12, 27), // 280
        new ResidueData("1MA", 12, 27), // 281
        new ResidueData("1MG", 12, 27), // 282
        new ResidueData("1PR", 12, 27), // 283
        new ResidueData("1SC", 12, 27), // 284
        new ResidueData("2AU", 12, 27), // 285
        new ResidueData("2EG", 12, 27), // 286
        new ResidueData("2MA", 12, 27), // 287
        new ResidueData("2MG", 12, 27), // 288
        new ResidueData("2MU", 12, 27), // 289
        new ResidueData("2PR", 12, 27), // 290
        new ResidueData("2SA", 12, 27), // 291
        new ResidueData("4AC", 12, 27), // 292
        new ResidueData("4OC", 12, 27), // 293
        new ResidueData("4SU", 12, 27), // 294
        new ResidueData("4TA", 12, 27), // 295
        new ResidueData("5BU", 12, 27), // 296
        new ResidueData("5FA", 12, 27), // 297
        new ResidueData("5FU", 12, 27), // 298
        new ResidueData("5IC", 12, 27), // 299
        new ResidueData("5MC", 12, 27), // 300
        new ResidueData("5MU", 12, 27), // 301
        new ResidueData("6IA", 12, 27), // 302
        new ResidueData("6MA", 12, 27), // 303
        new ResidueData("6MC", 12, 27), // 304
        new ResidueData("6MT", 12, 27), // 305
        new ResidueData("6MZ", 12, 27), // 306
        new ResidueData("70U", 12, 27), // 307
        new ResidueData("7MG", 12, 27), // 308
        new ResidueData("A23", 12, 27), // 309
        new ResidueData("A2L", 12, 27), // 310
        new ResidueData("A2M", 12, 27), // 311
        new ResidueData("A3P", 12, 27), // 312
        new ResidueData("A44", 12, 27), // 313
        new ResidueData("ADX", 12, 27), // 314
        new ResidueData("AET", 12, 27), // 315
        new ResidueData("AVC", 12, 27), // 316
        new ResidueData("BMP", 12, 27), // 317
        new ResidueData("BT5", 12, 27), // 318
        new ResidueData("C2L", 12, 27), // 319
        new ResidueData("C31", 12, 27), // 320
        new ResidueData("C43", 12, 27), // 321
        new ResidueData("CBV", 12, 27), // 322
        new ResidueData("CCC", 12, 27), // 323
        new ResidueData(" CH", 12, 27), // 324
        new ResidueData("CM0", 12, 27), // 325
        new ResidueData("CS8", 12, 27), // 326
        new ResidueData("CSF", 12, 27), // 327
        new ResidueData("DBM", 12, 27), // 328
        new ResidueData("ENA", 12, 27), // 329
        new ResidueData("ENP", 12, 27), // 330
        new ResidueData("FA5", 12, 27), // 331
        new ResidueData("FHU", 12, 27), // 332
        new ResidueData("FMU", 12, 27), // 333
        new ResidueData("G25", 12, 27), // 334
        new ResidueData("G2L", 12, 27), // 335
        new ResidueData("G46", 12, 27), // 336
        new ResidueData("G48", 12, 27), // 337
        new ResidueData("G4P", 12, 27), // 338
        new ResidueData("G7M", 12, 27), // 339
        new ResidueData("GAO", 12, 27), // 340
        new ResidueData("GH3", 12, 27), // 341
        new ResidueData("GOM", 12, 27), // 342
        new ResidueData("H2U", 12, 27), // 343
        new ResidueData("  I", 12, 27), // 344
        new ResidueData(" IC", 12, 27), // 345
        new ResidueData(" IG", 12, 27), // 346
        new ResidueData(" IU", 12, 27), // 347
        new ResidueData("KAG", 12, 27), // 348
        new ResidueData(" LC", 12, 27), // 349
        new ResidueData(" LG", 12, 27), // 350
        new ResidueData("LHU", 12, 27), // 351
        new ResidueData("LMS", 12, 27), // 352
        new ResidueData("M2G", 12, 27), // 353
        new ResidueData("M5M", 12, 27), // 354
        new ResidueData("MA6", 12, 27), // 355
        new ResidueData("MAD", 12, 27), // 356
        new ResidueData("MIA", 12, 27), // 357
        new ResidueData("MNU", 12, 27), // 358
        new ResidueData("MTU", 12, 27), // 359
        new ResidueData("  N", 12, 27), // 360
        new ResidueData("N6G", 12, 27), // 361
        new ResidueData("NF2", 12, 27), // 362
        new ResidueData("OAD", 12, 27), // 363
        new ResidueData("ODP", 12, 27), // 364
        new ResidueData("OMC", 12, 27), // 365
        new ResidueData("OMG", 12, 27), // 366
        new ResidueData("OMU", 12, 27), // 367
        new ResidueData("ONE", 12, 27), // 368
        new ResidueData("P1P", 12, 27), // 369
        new ResidueData("P5P", 12, 27), // 370
        new ResidueData("PGP", 12, 27), // 371
        new ResidueData("PMT", 12, 27), // 372
        new ResidueData("PPU", 12, 27), // 373
        new ResidueData("PQ1", 12, 27), // 374
        new ResidueData("PR5", 12, 27), // 375
        new ResidueData("PSU", 12, 27), // 376
        new ResidueData(" PU", 12, 27), // 377
        new ResidueData("PUY", 12, 27), // 378
        new ResidueData("PYO", 12, 27), // 379
        new ResidueData("PYY", 12, 27), // 380
        new ResidueData("QUO", 12, 27), // 381
        new ResidueData("RIA", 12, 27), // 382
        new ResidueData("RTP", 12, 27), // 383
        new ResidueData("S4C", 12, 27), // 384
        new ResidueData("SMT", 12, 27), // 385
        new ResidueData("SRA", 12, 27), // 386
        new ResidueData("SSU", 12, 27), // 387
        new ResidueData("SUR", 12, 27), // 388
        new ResidueData("T23", 12, 27), // 389
        new ResidueData("T2S", 12, 27), // 390
        new ResidueData("T38", 12, 27), // 391
        new ResidueData("T39", 12, 27), // 392
        new ResidueData("T41", 12, 27), // 393
        new ResidueData("T6A", 12, 27), // 394
        new ResidueData("TAL", 12, 27), // 395
        new ResidueData("TLB", 12, 27), // 396
        new ResidueData("TPG", 12, 27), // 397
        new ResidueData("TYU", 12, 27), // 398
        new ResidueData("U2L", 12, 27), // 399
        new ResidueData("U2P", 12, 27), // 400
        new ResidueData("U31", 12, 27), // 401
        new ResidueData("U34", 12, 27), // 402
        new ResidueData("U36", 12, 27), // 403
        new ResidueData("U37", 12, 27), // 404
        new ResidueData("U8U", 12, 27), // 405
        new ResidueData("UAR", 12, 27), // 406
        new ResidueData("UD5", 12, 27), // 407
        new ResidueData("UDP", 12, 27), // 408
        new ResidueData("UMP", 12, 27), // 409
        new ResidueData("UR3", 12, 27), // 410
        new ResidueData("URD", 12, 27), // 411
        new ResidueData("XTS", 12, 27), // 412
        new ResidueData(" YG", 12, 27), // 413
        new ResidueData("YYG", 12, 27), // 414
        new ResidueData("004", 12, 20), // 415
        new ResidueData("005", 12, 20), // 416
        new ResidueData("006", 12, 20), // 417
        new ResidueData("00B", 12, 20), // 418
        new ResidueData("00C", 12, 20), // 419
        new ResidueData("01W", 12, 20), // 420
        new ResidueData("0A0", 12, 20), // 421
        new ResidueData("0A1", 12, 20), // 422
        new ResidueData("0A2", 12, 20), // 423
        new ResidueData("0A8", 12, 20), // 424
        new ResidueData("0A9", 12, 20), // 425
        new ResidueData("0AB", 12, 20), // 426
        new ResidueData("0AF", 12, 20), // 427
        new ResidueData("0AG", 12, 20), // 428
        new ResidueData("0AH", 12, 20), // 429
        new ResidueData("0AK", 12, 20), // 430
        new ResidueData("0AY", 12, 20), // 431
        new ResidueData("0AZ", 12, 20), // 432
        new ResidueData("0CS", 12, 20), // 433
        new ResidueData("0D5", 12, 20), // 434
        new ResidueData("0E2", 12, 20), // 435
        new ResidueData("0E3", 12, 20), // 436
        new ResidueData("0E4", 12, 20), // 437
        new ResidueData("0EZ", 12, 20), // 438
        new ResidueData("0G6", 12, 20), // 439
        new ResidueData("0HG", 12, 20), // 440
        new ResidueData("0NC", 12, 20), // 441
        new ResidueData("0PJ", 12, 20), // 442
        new ResidueData("0PN", 12, 20), // 443
        new ResidueData("0YG", 12, 20), // 444
        new ResidueData("0Z6", 12, 20), // 445
        new ResidueData("143", 12, 20), // 446
        new ResidueData("175", 12, 20), // 447
        new ResidueData("193", 12, 20), // 448
        new ResidueData("1PA", 12, 20), // 449
        new ResidueData("1PI", 12, 20), // 450
        new ResidueData("1TQ", 12, 20), // 451
        new ResidueData("1TY", 12, 20), // 452
        new ResidueData("1ZN", 12, 20), // 453
        new ResidueData("200", 12, 20), // 454
        new ResidueData("23F", 12, 20), // 455
        new ResidueData("23S", 12, 20), // 456
        new ResidueData("26B", 12, 20), // 457
        new ResidueData("2AD", 12, 20), // 458
        new ResidueData("2AG", 12, 20), // 459
        new ResidueData("2AO", 12, 20), // 460
        new ResidueData("2AS", 12, 20), // 461
        new ResidueData("2CO", 12, 20), // 462
        new ResidueData("2DO", 12, 20), // 463
        new ResidueData("2FM", 12, 20), // 464
        new ResidueData("2HF", 12, 20), // 465
        new ResidueData("2ML", 12, 20), // 466
        new ResidueData("2MR", 12, 20), // 467
        new ResidueData("2MT", 12, 20), // 468
        new ResidueData("2NC", 12, 20), // 469
        new ResidueData("2TY", 12, 20), // 470
        new ResidueData("2VA", 12, 20), // 471
        new ResidueData("2Z9", 12, 20), // 472
        new ResidueData("32S", 12, 20), // 473
        new ResidueData("32T", 12, 20), // 474
        new ResidueData("3AH", 12, 20), // 475
        new ResidueData("3AR", 12, 20), // 476
        new ResidueData("3FG", 12, 20), // 477
        new ResidueData("3GA", 12, 20), // 478
        new ResidueData("3MM", 12, 20), // 479
        new ResidueData("3MY", 12, 20), // 480
        new ResidueData("3TL", 12, 20), // 481
        new ResidueData("3TY", 12, 20), // 482
        new ResidueData("3XH", 12, 20), // 483
        new ResidueData("40A", 12, 20), // 484
        new ResidueData("40C", 12, 20), // 485
        new ResidueData("40G", 12, 20), // 486
        new ResidueData("40T", 12, 20), // 487
        new ResidueData("4AF", 12, 20), // 488
        new ResidueData("4BF", 12, 20), // 489
        new ResidueData("4DP", 12, 20), // 490
        new ResidueData("4F3", 12, 20), // 491
        new ResidueData("4FB", 12, 20), // 492
        new ResidueData("4FW", 12, 20), // 493
        new ResidueData("4HT", 12, 20), // 494
        new ResidueData("4IN", 12, 20), // 495
        new ResidueData("4MM", 12, 20), // 496
        new ResidueData("4PH", 12, 20), // 497
        new ResidueData("5CS", 12, 20), // 498
        new ResidueData("5OH", 12, 20), // 499
        new ResidueData("5PG", 12, 20), // 500
        new ResidueData("5ZA", 12, 20), // 501
        new ResidueData("6CL", 12, 20), // 502
        new ResidueData("6CW", 12, 20), // 503
        new ResidueData("6HN", 12, 20), // 504
        new ResidueData("7HA", 12, 20), // 505
        new ResidueData("A66", 12, 20), // 506
        new ResidueData("A70", 12, 20), // 507
        new ResidueData("A9D", 12, 20), // 508
        new ResidueData("AA4", 12, 20), // 509
        new ResidueData("AA6", 12, 20), // 510
        new ResidueData("AAR", 12, 20), // 511
        new ResidueData("ABA", 12, 20), // 512
        new ResidueData("ACB", 12, 20), // 513
        new ResidueData("ACL", 12, 20), // 514
        new ResidueData("ADD", 12, 20), // 515
        new ResidueData("AEA", 12, 20), // 516
        new ResidueData("AEI", 12, 20), // 517
        new ResidueData("AFA", 12, 20), // 518
        new ResidueData("AGD", 12, 20), // 519
        new ResidueData("AGM", 12, 20), // 520
        new ResidueData("AGT", 12, 20), // 521
        new ResidueData("AHB", 12, 20), // 522
        new ResidueData("AHH", 12, 20), // 523
        new ResidueData("AHO", 12, 20), // 524
        new ResidueData("AHP", 12, 20), // 525
        new ResidueData("AHS", 12, 20), // 526
        new ResidueData("AHT", 12, 20), // 527
        new ResidueData("AIB", 12, 20), // 528
        new ResidueData("AKL", 12, 20), // 529
        new ResidueData("ALC", 12, 20), // 530
        new ResidueData("ALG", 12, 20), // 531
        new ResidueData("ALM", 12, 20), // 532
        new ResidueData("ALN", 12, 20), // 533
        new ResidueData("ALO", 12, 20), // 534
        new ResidueData("ALS", 12, 20), // 535
        new ResidueData("ALT", 12, 20), // 536
        new ResidueData("ALY", 12, 20), // 537
        new ResidueData("APE", 12, 20), // 538
        new ResidueData("APH", 12, 20), // 539
        new ResidueData("API", 12, 20), // 540
        new ResidueData("APK", 12, 20), // 541
        new ResidueData("APM", 12, 20), // 542
        new ResidueData("APO", 12, 20), // 543
        new ResidueData("APP", 12, 20), // 544
        new ResidueData("AR2", 12, 20), // 545
        new ResidueData("AR4", 12, 20), // 546
        new ResidueData("ARF", 12, 20), // 547
        new ResidueData("ARM", 12, 20), // 548
        new ResidueData("ARO", 12, 20), // 549
        new ResidueData("ARV", 12, 20), // 550
        new ResidueData("AS2", 12, 20), // 551
        new ResidueData("AS9", 12, 20), // 552
        new ResidueData("ASA", 12, 20), // 553
        new ResidueData("ASB", 12, 20), // 554
        new ResidueData("ASK", 12, 20), // 555
        new ResidueData("ASL", 12, 20), // 556
        new ResidueData("ASM", 12, 20), // 557
        new ResidueData("AVN", 12, 20), // 558
        new ResidueData("AYA", 12, 20), // 559
        new ResidueData("AYG", 12, 20), // 560
        new ResidueData("AYI", 12, 20), // 561
        new ResidueData("AYQ", 12, 20), // 562
        new ResidueData("AZ0", 12, 20), // 563
        new ResidueData("AZK", 12, 20), // 564
        new ResidueData("AZS", 12, 20), // 565
        new ResidueData("AZY", 12, 20), // 566
        new ResidueData("B27", 12, 20), // 567
        new ResidueData("B2A", 12, 20), // 568
        new ResidueData("B2F", 12, 20), // 569
        new ResidueData("B2I", 12, 20), // 570
        new ResidueData("B2V", 12, 20), // 571
        new ResidueData("B3A", 12, 20), // 572
        new ResidueData("B3D", 12, 20), // 573
        new ResidueData("B3E", 12, 20), // 574
        new ResidueData("B3K", 12, 20), // 575
        new ResidueData("B3L", 12, 20), // 576
        new ResidueData("B3M", 12, 20), // 577
        new ResidueData("B3Q", 12, 20), // 578
        new ResidueData("B3S", 12, 20), // 579
        new ResidueData("B3T", 12, 20), // 580
        new ResidueData("B3U", 12, 20), // 581
        new ResidueData("B3X", 12, 20), // 582
        new ResidueData("B3Y", 12, 20), // 583
        new ResidueData("BAL", 12, 20), // 584
        new ResidueData("BB6", 12, 20), // 585
        new ResidueData("BB7", 12, 20), // 586
        new ResidueData("BB9", 12, 20), // 587
        new ResidueData("BBC", 12, 20), // 588
        new ResidueData("BCC", 12, 20), // 589
        new ResidueData("BCS", 12, 20), // 590
        new ResidueData("BCX", 12, 20), // 591
        new ResidueData("BE2", 12, 20), // 592
        new ResidueData("BFD", 12, 20), // 593
        new ResidueData("BG1", 12, 20), // 594
        new ResidueData("BHD", 12, 20), // 595
        new ResidueData("BIF", 12, 20), // 596
        new ResidueData("BIL", 12, 20), // 597
        new ResidueData("BIU", 12, 20), // 598
        new ResidueData("BJH", 12, 20), // 599
        new ResidueData("BLE", 12, 20), // 600
        new ResidueData("BLY", 12, 20), // 601
        new ResidueData("BMT", 12, 20), // 602
        new ResidueData("BNN", 12, 20), // 603
        new ResidueData("BNO", 12, 20), // 604
        new ResidueData("BOR", 12, 20), // 605
        new ResidueData("BPE", 12, 20), // 606
        new ResidueData("BSE", 12, 20), // 607
        new ResidueData("BTK", 12, 20), // 608
        new ResidueData("BTR", 12, 20), // 609
        new ResidueData("BUC", 12, 20), // 610
        new ResidueData("BUG", 12, 20), // 611
        new ResidueData("C12", 12, 20), // 612
        new ResidueData("C1T", 12, 20), // 613
        new ResidueData("C1X", 12, 20), // 614
        new ResidueData("C3Y", 12, 20), // 615
        new ResidueData("C4R", 12, 20), // 616
        new ResidueData("C5C", 12, 20), // 617
        new ResidueData("C66", 12, 20), // 618
        new ResidueData("C6C", 12, 20), // 619
        new ResidueData("C99", 12, 20), // 620
        new ResidueData("CAB", 12, 20), // 621
        new ResidueData("CAF", 12, 20), // 622
        new ResidueData("CAL", 12, 20), // 623
        new ResidueData("CAS", 12, 20), // 624
        new ResidueData("CAV", 12, 20), // 625
        new ResidueData("CCL", 12, 20), // 626
        new ResidueData("CCS", 12, 20), // 627
        new ResidueData("CCY", 12, 20), // 628
        new ResidueData("CDE", 12, 20), // 629
        new ResidueData("CDV", 12, 20), // 630
        new ResidueData("CFY", 12, 20), // 631
        new ResidueData("CGA", 12, 20), // 632
        new ResidueData("CGU", 12, 20), // 633
        new ResidueData("CH6", 12, 20), // 634
        new ResidueData("CH7", 12, 20), // 635
        new ResidueData("CHF", 12, 20), // 636
        new ResidueData("CHG", 12, 20), // 637
        new ResidueData("CHP", 12, 20), // 638
        new ResidueData("CHS", 12, 20), // 639
        new ResidueData("CIR", 12, 20), // 640
        new ResidueData("CJO", 12, 20), // 641
        new ResidueData("CLB", 12, 20), // 642
        new ResidueData("CLD", 12, 20), // 643
        new ResidueData("CLE", 12, 20), // 644
        new ResidueData("CLG", 12, 20), // 645
        new ResidueData("CLH", 12, 20), // 646
        new ResidueData("CLV", 12, 20), // 647
        new ResidueData("CME", 12, 20), // 648
        new ResidueData("CMH", 12, 20), // 649
        new ResidueData("CML", 12, 20), // 650
        new ResidueData("CMT", 12, 20), // 651
        new ResidueData("CPC", 12, 20), // 652
        new ResidueData("CPI", 12, 20), // 653
        new ResidueData("CR0", 12, 20), // 654
        new ResidueData("CR2", 12, 20), // 655
        new ResidueData("CR5", 12, 20), // 656
        new ResidueData("CR7", 12, 20), // 657
        new ResidueData("CR8", 12, 20), // 658
        new ResidueData("CRF", 12, 20), // 659
        new ResidueData("CRG", 12, 20), // 660
        new ResidueData("CRK", 12, 20), // 661
        new ResidueData("CRO", 12, 20), // 662
        new ResidueData("CRQ", 12, 20), // 663
        new ResidueData("CRU", 12, 20), // 664
        new ResidueData("CRW", 12, 20), // 665
        new ResidueData("CRX", 12, 20), // 666
        new ResidueData("CS1", 12, 20), // 667
        new ResidueData("CS3", 12, 20), // 668
        new ResidueData("CS4", 12, 20), // 669
        new ResidueData("CSA", 12, 20), // 670
        new ResidueData("CSB", 12, 20), // 671
        new ResidueData("CSD", 12, 20), // 672
        new ResidueData("CSE", 12, 20), // 673
        new ResidueData("CSH", 12, 20), // 674
        new ResidueData("CSI", 12, 20), // 675
        new ResidueData("CSJ", 12, 20), // 676
        new ResidueData("CSO", 12, 20), // 677
        new ResidueData("CSP", 12, 20), // 678
        new ResidueData("CSR", 12, 20), // 679
        new ResidueData("CSS", 12, 20), // 680
        new ResidueData("CSU", 12, 20), // 681
        new ResidueData("CSW", 12, 20), // 682
        new ResidueData("CSX", 12, 20), // 683
        new ResidueData("CSY", 12, 20), // 684
        new ResidueData("CSZ", 12, 20), // 685
        new ResidueData("CTE", 12, 20), // 686
        new ResidueData("CTH", 12, 20), // 687
        new ResidueData("CUD", 12, 20), // 688
        new ResidueData("CWR", 12, 20), // 689
        new ResidueData("CXM", 12, 20), // 690
        new ResidueData("CY0", 12, 20), // 691
        new ResidueData("CY1", 12, 20), // 692
        new ResidueData("CY3", 12, 20), // 693
        new ResidueData("CY4", 12, 20), // 694
        new ResidueData("CYD", 12, 20), // 695
        new ResidueData("CYF", 12, 20), // 696
        new ResidueData("CYG", 12, 20), // 697
        new ResidueData("CYJ", 12, 20), // 698
        new ResidueData("CYQ", 12, 20), // 699
        new ResidueData("CYR", 12, 20), // 700
        new ResidueData("CZ2", 12, 20), // 701
        new ResidueData("CZO", 12, 20), // 702
        new ResidueData("CZZ", 12, 20), // 703
        new ResidueData("D11", 12, 20), // 704
        new ResidueData("D3P", 12, 20), // 705
        new ResidueData("D4P", 12, 20), // 706
        new ResidueData("DA2", 12, 20), // 707
        new ResidueData("DAB", 12, 20), // 708
        new ResidueData("DAH", 12, 20), // 709
        new ResidueData("DAL", 12, 20), // 710
        new ResidueData("DAM", 12, 20), // 711
        new ResidueData("DAR", 12, 20), // 712
        new ResidueData("DAS", 12, 20), // 713
        new ResidueData("DBB", 12, 20), // 714
        new ResidueData("DBS", 12, 20), // 715
        new ResidueData("DBU", 12, 20), // 716
        new ResidueData("DBY", 12, 20), // 717
        new ResidueData("DBZ", 12, 20), // 718
        new ResidueData("DCL", 12, 20), // 719
        new ResidueData("DCY", 12, 20), // 720
        new ResidueData("DDE", 12, 20), // 721
        new ResidueData("DDZ", 12, 20), // 722
        new ResidueData("DFI", 12, 20), // 723
        new ResidueData("DFO", 12, 20), // 724
        new ResidueData("DGL", 12, 20), // 725
        new ResidueData("DGN", 12, 20), // 726
        new ResidueData("DHA", 12, 20), // 727
        new ResidueData("DHI", 12, 20), // 728
        new ResidueData("DHL", 12, 20), // 729
        new ResidueData("DHP", 12, 20), // 730
        new ResidueData("DIL", 12, 20), // 731
        new ResidueData("DIR", 12, 20), // 732
        new ResidueData("DIV", 12, 20), // 733
        new ResidueData("DLE", 12, 20), // 734
        new ResidueData("DLS", 12, 20), // 735
        new ResidueData("DLY", 12, 20), // 736
        new ResidueData("DM0", 12, 20), // 737
        new ResidueData("DMH", 12, 20), // 738
        new ResidueData("DMK", 12, 20), // 739
        new ResidueData("DMT", 12, 20), // 740
        new ResidueData("DNE", 12, 20), // 741
        new ResidueData("DNG", 12, 20), // 742
        new ResidueData("DNL", 12, 20), // 743
        new ResidueData("DNM", 12, 20), // 744
        new ResidueData("DNP", 12, 20), // 745
        new ResidueData("DNS", 12, 20), // 746
        new ResidueData("DOA", 12, 20), // 747
        new ResidueData("DON", 12, 20), // 748
        new ResidueData("DPL", 12, 20), // 749
        new ResidueData("DPN", 12, 20), // 750
        new ResidueData("DPP", 12, 20), // 751
        new ResidueData("DPQ", 12, 20), // 752
        new ResidueData("DPR", 12, 20), // 753
        new ResidueData("DSE", 12, 20), // 754
        new ResidueData("DSG", 12, 20), // 755
        new ResidueData("DSN", 12, 20), // 756
        new ResidueData("DTH", 12, 20), // 757
        new ResidueData("DTR", 12, 20), // 758
        new ResidueData("DTY", 12, 20), // 759
        new ResidueData("DVA", 12, 20), // 760
        new ResidueData("DYG", 12, 20), // 761
        new ResidueData("DYS", 12, 20), // 762
        new ResidueData("E13", 12, 20), // 763
        new ResidueData("E14", 12, 20), // 764
        new ResidueData("E15", 12, 20), // 765
        new ResidueData("E16", 12, 20), // 766
        new ResidueData("E17", 12, 20), // 767
        new ResidueData("E19", 12, 20), // 768
        new ResidueData("EFC", 12, 20), // 769
        new ResidueData("EOV", 12, 20), // 770
        new ResidueData("EP2", 12, 20), // 771
        new ResidueData("ESB", 12, 20), // 772
        new ResidueData("ESC", 12, 20), // 773
        new ResidueData("ETA", 12, 20), // 774
        new ResidueData("EXY", 12, 20), // 775
        new ResidueData("EYS", 12, 20), // 776
        new ResidueData("F2F", 12, 20), // 777
        new ResidueData("FCL", 12, 20), // 778
        new ResidueData("FFM", 12, 20), // 779
        new ResidueData("FGA", 12, 20), // 780
        new ResidueData("FGK", 12, 20), // 781
        new ResidueData("FGL", 12, 20), // 782
        new ResidueData("FGP", 12, 20), // 783
        new ResidueData("FH7", 12, 20), // 784
        new ResidueData("FHL", 12, 20), // 785
        new ResidueData("FHO", 12, 20), // 786
        new ResidueData("FLA", 12, 20), // 787
        new ResidueData("FLE", 12, 20), // 788
        new ResidueData("FLT", 12, 20), // 789
        new ResidueData("FME", 12, 20), // 790
        new ResidueData("FOE", 12, 20), // 791
        new ResidueData("FOG", 12, 20), // 792
        new ResidueData("FP9", 12, 20), // 793
        new ResidueData("FPR", 12, 20), // 794
        new ResidueData("FRD", 12, 20), // 795
        new ResidueData("FT6", 12, 20), // 796
        new ResidueData("FTR", 12, 20), // 797
        new ResidueData("FTY", 12, 20), // 798
        new ResidueData("FYI", 12, 20), // 799
        new ResidueData("FYQ", 12, 20), // 800
        new ResidueData("FZN", 12, 20), // 801
        new ResidueData("G01", 12, 20), // 802
        new ResidueData("GAU", 12, 20), // 803
        new ResidueData("GHC", 12, 20), // 804
        new ResidueData("GHG", 12, 20), // 805
        new ResidueData("GHP", 12, 20), // 806
        new ResidueData("GHW", 12, 20), // 807
        new ResidueData("GL3", 12, 20), // 808
        new ResidueData("GLH", 12, 20), // 809
        new ResidueData("GLM", 12, 20), // 810
        new ResidueData("GLQ", 12, 20), // 811
        new ResidueData("GLZ", 12, 20), // 812
        new ResidueData("GMA", 12, 20), // 813
        new ResidueData("GME", 12, 20), // 814
        new ResidueData("GND", 12, 20), // 815
        new ResidueData("GPL", 12, 20), // 816
        new ResidueData("GSC", 12, 20), // 817
        new ResidueData("GSU", 12, 20), // 818
        new ResidueData("GT9", 12, 20), // 819
        new ResidueData("GVE", 12, 20), // 820
        new ResidueData("GVL", 12, 20), // 821
        new ResidueData("GYC", 12, 20), // 822
        new ResidueData("GYS", 12, 20), // 823
        new ResidueData("H5M", 12, 20), // 824
        new ResidueData("HAQ", 12, 20), // 825
        new ResidueData("HAR", 12, 20), // 826
        new ResidueData("HBN", 12, 20), // 827
        new ResidueData("HCS", 12, 20), // 828
        new ResidueData("HF2", 12, 20), // 829
        new ResidueData("HFA", 12, 20), // 830
        new ResidueData("HGL", 12, 20), // 831
        new ResidueData("HHK", 12, 20), // 832
        new ResidueData("HIA", 12, 20), // 833
        new ResidueData("HIC", 12, 20), // 834
        new ResidueData("HIP", 12, 20), // 835
        new ResidueData("HIQ", 12, 20), // 836
        new ResidueData("HL2", 12, 20), // 837
        new ResidueData("HLU", 12, 20), // 838
        new ResidueData("HMF", 12, 20), // 839
        new ResidueData("HMR", 12, 20), // 840
        new ResidueData("HOX", 12, 20), // 841
        new ResidueData("HPE", 12, 20), // 842
        new ResidueData("HPH", 12, 20), // 843
        new ResidueData("HPQ", 12, 20), // 844
        new ResidueData("HQA", 12, 20), // 845
        new ResidueData("HRG", 12, 20), // 846
        new ResidueData("HRP", 12, 20), // 847
        new ResidueData("HS8", 12, 20), // 848
        new ResidueData("HS9", 12, 20), // 849
        new ResidueData("HSE", 12, 20), // 850
        new ResidueData("HSL", 12, 20), // 851
        new ResidueData("HSO", 12, 20), // 852
        new ResidueData("HTI", 12, 20), // 853
        new ResidueData("HTR", 12, 20), // 854
        new ResidueData("HV8", 12, 20), // 855
        new ResidueData("HY3", 12, 20), // 856
        new ResidueData("HZP", 12, 20), // 857
        new ResidueData("I58", 12, 20), // 858
        new ResidueData("IAM", 12, 20), // 859
        new ResidueData("IEL", 12, 20), // 860
        new ResidueData("IEY", 12, 20), // 861
        new ResidueData("IGL", 12, 20), // 862
        new ResidueData("IHN", 12, 20), // 863
        new ResidueData("IIC", 12, 20), // 864
        new ResidueData("IIL", 12, 20), // 865
        new ResidueData("ILG", 12, 20), // 866
        new ResidueData("ILX", 12, 20), // 867
        new ResidueData("IML", 12, 20), // 868
        new ResidueData("IOY", 12, 20), // 869
        new ResidueData("IPG", 12, 20), // 870
        new ResidueData("IT1", 12, 20), // 871
        new ResidueData("IYR", 12, 20), // 872
        new ResidueData("IYT", 12, 20), // 873
        new ResidueData("K1R", 12, 20), // 874
        new ResidueData("KBE", 12, 20), // 875
        new ResidueData("KCX", 12, 20), // 876
        new ResidueData("KGC", 12, 20), // 877
        new ResidueData("KOR", 12, 20), // 878
        new ResidueData("KPI", 12, 20), // 879
        new ResidueData("KST", 12, 20), // 880
        new ResidueData("KYN", 12, 20), // 881
        new ResidueData("KYQ", 12, 20), // 882
        new ResidueData("L2A", 12, 20), // 883
        new ResidueData("L3A", 12, 20), // 884
        new ResidueData("L3O", 12, 20), // 885
        new ResidueData("LA2", 12, 20), // 886
        new ResidueData("LAA", 12, 20), // 887
        new ResidueData("LAL", 12, 20), // 888
        new ResidueData("LBY", 12, 20), // 889
        new ResidueData("LCK", 12, 20), // 890
        new ResidueData("LDH", 12, 20), // 891
        new ResidueData("LE1", 12, 20), // 892
        new ResidueData("LED", 12, 20), // 893
        new ResidueData("LEF", 12, 20), // 894
        new ResidueData("LEH", 12, 20), // 895
        new ResidueData("LEI", 12, 20), // 896
        new ResidueData("LEM", 12, 20), // 897
        new ResidueData("LEN", 12, 20), // 898
        new ResidueData("LEP", 12, 20), // 899
        new ResidueData("LET", 12, 20), // 900
        new ResidueData("LHC", 12, 20), // 901
        new ResidueData("LLP", 12, 20), // 902
        new ResidueData("LLY", 12, 20), // 903
        new ResidueData("LME", 12, 20), // 904
        new ResidueData("LNT", 12, 20), // 905
        new ResidueData("LOL", 12, 20), // 906
        new ResidueData("LOV", 12, 20), // 907
        new ResidueData("LP6", 12, 20), // 908
        new ResidueData("LPD", 12, 20), // 909
        new ResidueData("LPG", 12, 20), // 910
        new ResidueData("LPL", 12, 20), // 911
        new ResidueData("LPS", 12, 20), // 912
        new ResidueData("LSO", 12, 20), // 913
        new ResidueData("LTA", 12, 20), // 914
        new ResidueData("LVG", 12, 20), // 915
        new ResidueData("LVN", 12, 20), // 916
        new ResidueData("LWY", 12, 20), // 917
        new ResidueData("LYM", 12, 20), // 918
        new ResidueData("LYN", 12, 20), // 919
        new ResidueData("LYR", 12, 20), // 920
        new ResidueData("LYX", 12, 20), // 921
        new ResidueData("LYZ", 12, 20), // 922
        new ResidueData("M0H", 12, 20), // 923
        new ResidueData("M2L", 12, 20), // 924
        new ResidueData("M3L", 12, 20), // 925
        new ResidueData("M3R", 12, 20), // 926
        new ResidueData(" MA", 12, 20), // 927
        new ResidueData("MAA", 12, 20), // 928
        new ResidueData("MAI", 12, 20), // 929
        new ResidueData("MBQ", 12, 20), // 930
        new ResidueData("MC1", 12, 20), // 931
        new ResidueData("MCG", 12, 20), // 932
        new ResidueData("MCL", 12, 20), // 933
        new ResidueData("MCS", 12, 20), // 934
        new ResidueData("MDH", 12, 20), // 935
        new ResidueData("MDO", 12, 20), // 936
        new ResidueData("MEA", 12, 20), // 937
        new ResidueData("MED", 12, 20), // 938
        new ResidueData("MEG", 12, 20), // 939
        new ResidueData("MEN", 12, 20), // 940
        new ResidueData("MEQ", 12, 20), // 941
        new ResidueData("MEU", 12, 20), // 942
        new ResidueData("MF3", 12, 20), // 943
        new ResidueData("MFC", 12, 20), // 944
        new ResidueData("MGG", 12, 20), // 945
        new ResidueData("MGN", 12, 20), // 946
        new ResidueData("MH6", 12, 20), // 947
        new ResidueData("MHL", 12, 20), // 948
        new ResidueData("MHO", 12, 20), // 949
        new ResidueData("MHS", 12, 20), // 950
        new ResidueData("MHU", 12, 20), // 951
        new ResidueData("MHV", 12, 20), // 952
        new ResidueData("MHW", 12, 20), // 953
        new ResidueData("MID", 12, 20), // 954
        new ResidueData("MIR", 12, 20), // 955
        new ResidueData("MIS", 12, 20), // 956
        new ResidueData("MIT", 12, 20), // 957
        new ResidueData("MK8", 12, 20), // 958
        new ResidueData("ML3", 12, 20), // 959
        new ResidueData("MLE", 12, 20), // 960
        new ResidueData("MLL", 12, 20), // 961
        new ResidueData("MLY", 12, 20), // 962
        new ResidueData("MLZ", 12, 20), // 963
        new ResidueData("MME", 12, 20), // 964
        new ResidueData("MNL", 12, 20), // 965
        new ResidueData("MNV", 12, 20), // 966
        new ResidueData("MOD", 12, 20), // 967
        new ResidueData("MP8", 12, 20), // 968
        new ResidueData("MPH", 12, 20), // 969
        new ResidueData("MPJ", 12, 20), // 970
        new ResidueData("MPQ", 12, 20), // 971
        new ResidueData("MSA", 12, 20), // 972
        new ResidueData("MSE", 12, 20), // 973
        new ResidueData("MSL", 12, 20), // 974
        new ResidueData("MSO", 12, 20), // 975
        new ResidueData("MSP", 12, 20), // 976
        new ResidueData("MT2", 12, 20), // 977
        new ResidueData("MTY", 12, 20), // 978
        new ResidueData("MVA", 12, 20), // 979
        new ResidueData("MYN", 12, 20), // 980
        new ResidueData("N10", 12, 20), // 981
        new ResidueData("N2C", 12, 20), // 982
        new ResidueData("N31", 12, 20), // 983
        new ResidueData("N7P", 12, 20), // 984
        new ResidueData("NAL", 12, 20), // 985
        new ResidueData("NAM", 12, 20), // 986
        new ResidueData("NBQ", 12, 20), // 987
        new ResidueData("NC1", 12, 20), // 988
        new ResidueData("NCB", 12, 20), // 989
        new ResidueData("NCY", 12, 20), // 990
        new ResidueData("NDF", 12, 20), // 991
        new ResidueData("NEP", 12, 20), // 992
        new ResidueData("NFA", 12, 20), // 993
        new ResidueData("NHL", 12, 20), // 994
        new ResidueData("NIY", 12, 20), // 995
        new ResidueData("NKS", 12, 20), // 996
        new ResidueData("NLE", 12, 20), // 997
        new ResidueData("NLN", 12, 20), // 998
        new ResidueData("NLO", 12, 20), // 999
        new ResidueData("NLP", 12, 20), // 1000
        new ResidueData("NLQ", 12, 20), // 1001
        new ResidueData("NMC", 12, 20), // 1002
        new ResidueData("NMM", 12, 20), // 1003
        new ResidueData("NNH", 12, 20), // 1004
        new ResidueData("NOR", 12, 20), // 1005
        new ResidueData("NOT", 12, 20), // 1006
        new ResidueData("NPH", 12, 20), // 1007
        new ResidueData("NRG", 12, 20), // 1008
        new ResidueData("NRP", 12, 20), // 1009
        new ResidueData("NRQ", 12, 20), // 1010
        new ResidueData("NSK", 12, 20), // 1011
        new ResidueData("NVA", 12, 20), // 1012
        new ResidueData("NYB", 12, 20), // 1013
        new ResidueData("NYC", 12, 20), // 1014
        new ResidueData("NYG", 12, 20), // 1015
        new ResidueData("NYS", 12, 20), // 1016
        new ResidueData("NZH", 12, 20), // 1017
        new ResidueData("O12", 12, 20), // 1018
        new ResidueData("OAS", 12, 20), // 1019
        new ResidueData("OBF", 12, 20), // 1020
        new ResidueData("OBS", 12, 20), // 1021
        new ResidueData("OCS", 12, 20), // 1022
        new ResidueData("OCY", 12, 20), // 1023
        new ResidueData("ODA", 12, 20), // 1024
        new ResidueData("ODS", 12, 20), // 1025
        new ResidueData("OHI", 12, 20), // 1026
        new ResidueData("OHS", 12, 20), // 1027
        new ResidueData("OIC", 12, 20), // 1028
        new ResidueData("OLT", 12, 20), // 1029
        new ResidueData("OLZ", 12, 20), // 1030
        new ResidueData("OMT", 12, 20), // 1031
        new ResidueData("OMY", 12, 20), // 1032
        new ResidueData("ONL", 12, 20), // 1033
        new ResidueData("OPR", 12, 20), // 1034
        new ResidueData("ORN", 12, 20), // 1035
        new ResidueData("ORQ", 12, 20), // 1036
        new ResidueData("OSE", 12, 20), // 1037
        new ResidueData("OTH", 12, 20), // 1038
        new ResidueData("OTT", 12, 20), // 1039
        new ResidueData("OTY", 12, 20), // 1040
        new ResidueData("OXX", 12, 20), // 1041
        new ResidueData("OZT", 12, 20), // 1042
        new ResidueData("P1L", 12, 20), // 1043
        new ResidueData("P2Y", 12, 20), // 1044
        new ResidueData("PAQ", 12, 20), // 1045
        new ResidueData("PAT", 12, 20), // 1046
        new ResidueData("PAU", 12, 20), // 1047
        new ResidueData("PBB", 12, 20), // 1048
        new ResidueData("PBF", 12, 20), // 1049
        new ResidueData("PCE", 12, 20), // 1050
        new ResidueData("PCS", 12, 20), // 1051
        new ResidueData("PDD", 12, 20), // 1052
        new ResidueData("PEC", 12, 20), // 1053
        new ResidueData("PF5", 12, 20), // 1054
        new ResidueData("PFF", 12, 20), // 1055
        new ResidueData("PFX", 12, 20), // 1056
        new ResidueData("PG1", 12, 20), // 1057
        new ResidueData("PG9", 12, 20), // 1058
        new ResidueData("PGL", 12, 20), // 1059
        new ResidueData("PHA", 12, 20), // 1060
        new ResidueData("PHD", 12, 20), // 1061
        new ResidueData("PHI", 12, 20), // 1062
        new ResidueData("PHL", 12, 20), // 1063
        new ResidueData("PHM", 12, 20), // 1064
        new ResidueData("PIV", 12, 20), // 1065
        new ResidueData("PKR", 12, 20), // 1066
        new ResidueData("PLE", 12, 20), // 1067
        new ResidueData("PM3", 12, 20), // 1068
        new ResidueData("PNZ", 12, 20), // 1069
        new ResidueData("POM", 12, 20), // 1070
        new ResidueData("PPH", 12, 20), // 1071
        new ResidueData("PPN", 12, 20), // 1072
        new ResidueData("PR0", 12, 20), // 1073
        new ResidueData("PR3", 12, 20), // 1074
        new ResidueData("PR9", 12, 20), // 1075
        new ResidueData("PRK", 12, 20), // 1076
        new ResidueData("PRQ", 12, 20), // 1077
        new ResidueData("PRR", 12, 20), // 1078
        new ResidueData("PRS", 12, 20), // 1079
        new ResidueData("PRV", 12, 20), // 1080
        new ResidueData("PS0", 12, 20), // 1081
        new ResidueData("PSA", 12, 20), // 1082
        new ResidueData("PSH", 12, 20), // 1083
        new ResidueData("PSI", 12, 20), // 1084
        new ResidueData("PSS", 12, 20), // 1085
        new ResidueData("PSW", 12, 20), // 1086
        new ResidueData("PTA", 12, 20), // 1087
        new ResidueData("PTH", 12, 20), // 1088
        new ResidueData("PTM", 12, 20), // 1089
        new ResidueData("PTR", 12, 20), // 1090
        new ResidueData("PVH", 12, 20), // 1091
        new ResidueData("PYA", 12, 20), // 1092
        new ResidueData("PYX", 12, 20), // 1093
        new ResidueData("QDS", 12, 20), // 1094
        new ResidueData("QLG", 12, 20), // 1095
        new ResidueData("R1A", 12, 20), // 1096
        new ResidueData("R1B", 12, 20), // 1097
        new ResidueData("R1F", 12, 20), // 1098
        new ResidueData("R2P", 12, 20), // 1099
        new ResidueData("R7A", 12, 20), // 1100
        new ResidueData("RC7", 12, 20), // 1101
        new ResidueData("RCY", 12, 20), // 1102
        new ResidueData("RDF", 12, 20), // 1103
        new ResidueData("RGI", 12, 20), // 1104
        new ResidueData("ROC", 12, 20), // 1105
        new ResidueData("S1H", 12, 20), // 1106
        new ResidueData("S2C", 12, 20), // 1107
        new ResidueData("S2D", 12, 20), // 1108
        new ResidueData("S2P", 12, 20), // 1109
        new ResidueData("SAC", 12, 20), // 1110
        new ResidueData("SAH", 12, 20), // 1111
        new ResidueData("SAR", 12, 20), // 1112
        new ResidueData("SBD", 12, 20), // 1113
        new ResidueData("SBL", 12, 20), // 1114
        new ResidueData("SC2", 12, 20), // 1115
        new ResidueData("SCH", 12, 20), // 1116
        new ResidueData("SCS", 12, 20), // 1117
        new ResidueData("SCY", 12, 20), // 1118
        new ResidueData("SD2", 12, 20), // 1119
        new ResidueData("SDP", 12, 20), // 1120
        new ResidueData("SEB", 12, 20), // 1121
        new ResidueData("SEC", 12, 20), // 1122
        new ResidueData("SEE", 12, 20), // 1123
        new ResidueData("SEL", 12, 20), // 1124
        new ResidueData("SEM", 12, 20), // 1125
        new ResidueData("SEN", 12, 20), // 1126
        new ResidueData("SEP", 12, 20), // 1127
        new ResidueData("SET", 12, 20), // 1128
        new ResidueData("SGB", 12, 20), // 1129
        new ResidueData("SHC", 12, 20), // 1130
        new ResidueData("SHP", 12, 20), // 1131
        new ResidueData("SHR", 12, 20), // 1132
        new ResidueData("SIB", 12, 20), // 1133
        new ResidueData("SIC", 12, 20), // 1134
        new ResidueData("SLA", 12, 20), // 1135
        new ResidueData("SLR", 12, 20), // 1136
        new ResidueData("SLZ", 12, 20), // 1137
        new ResidueData("SMC", 12, 20), // 1138
        new ResidueData("SME", 12, 20), // 1139
        new ResidueData("SMF", 12, 20), // 1140
        new ResidueData("SNC", 12, 20), // 1141
        new ResidueData("SNN", 12, 20), // 1142
        new ResidueData("SOC", 12, 20), // 1143
        new ResidueData("SOY", 12, 20), // 1144
        new ResidueData("STA", 12, 20), // 1145
        new ResidueData("SUB", 12, 20), // 1146
        new ResidueData("SUI", 12, 20), // 1147
        new ResidueData("SUN", 12, 20), // 1148
        new ResidueData("SVA", 12, 20), // 1149
        new ResidueData("SVZ", 12, 20), // 1150
        new ResidueData("SXE", 12, 20), // 1151
        new ResidueData("SYS", 12, 20), // 1152
        new ResidueData("T11", 12, 20), // 1153
        new ResidueData("T66", 12, 20), // 1154
        new ResidueData("TA4", 12, 20), // 1155
        new ResidueData("TAV", 12, 20), // 1156
        new ResidueData("TBG", 12, 20), // 1157
        new ResidueData("TBM", 12, 20), // 1158
        new ResidueData("TCK", 12, 20), // 1159
        new ResidueData("TCQ", 12, 20), // 1160
        new ResidueData("TCR", 12, 20), // 1161
        new ResidueData("TFQ", 12, 20), // 1162
        new ResidueData("THC", 12, 20), // 1163
        new ResidueData("THO", 12, 20), // 1164
        new ResidueData("THZ", 12, 20), // 1165
        new ResidueData("TIH", 12, 20), // 1166
        new ResidueData("TIS", 12, 20), // 1167
        new ResidueData("TMD", 12, 20), // 1168
        new ResidueData("TNB", 12, 20), // 1169
        new ResidueData("TNR", 12, 20), // 1170
        new ResidueData("TNY", 12, 20), // 1171
        new ResidueData("TOX", 12, 20), // 1172
        new ResidueData("TPL", 12, 20), // 1173
        new ResidueData("TPO", 12, 20), // 1174
        new ResidueData("TPQ", 12, 20), // 1175
        new ResidueData("TQQ", 12, 20), // 1176
        new ResidueData("TRF", 12, 20), // 1177
        new ResidueData("TRN", 12, 20), // 1178
        new ResidueData("TRO", 12, 20), // 1179
        new ResidueData("TRQ", 12, 20), // 1180
        new ResidueData("TRW", 12, 20), // 1181
        new ResidueData("TRX", 12, 20), // 1182
        new ResidueData("TS9", 12, 20), // 1183
        new ResidueData("TST", 12, 20), // 1184
        new ResidueData("TTQ", 12, 20), // 1185
        new ResidueData("TTS", 12, 20), // 1186
        new ResidueData("TY2", 12, 20), // 1187
        new ResidueData("TYB", 12, 20), // 1188
        new ResidueData("TYI", 12, 20), // 1189
        new ResidueData("TYN", 12, 20), // 1190
        new ResidueData("TYO", 12, 20), // 1191
        new ResidueData("TYQ", 12, 20), // 1192
        new ResidueData("TYS", 12, 20), // 1193
        new ResidueData("TYT", 12, 20), // 1194
        new ResidueData("TYX", 12, 20), // 1195
        new ResidueData("TYY", 12, 20), // 1196
        new ResidueData("TZB", 12, 20), // 1197
        new ResidueData("TZO", 12, 20), // 1198
        new ResidueData("UAL", 12, 20), // 1199
        new ResidueData("UB2", 12, 20), // 1200
        new ResidueData("UDS", 12, 20), // 1201
        new ResidueData("UM1", 12, 20), // 1202
        new ResidueData("UM2", 12, 20), // 1203
        new ResidueData("UMA", 12, 20), // 1204
        new ResidueData("UN1", 12, 20), // 1205
        new ResidueData("UN2", 12, 20), // 1206
        new ResidueData("VAD", 12, 20), // 1207
        new ResidueData("VAF", 12, 20), // 1208
        new ResidueData("VB1", 12, 20), // 1209
        new ResidueData("VDL", 12, 20), // 1210
        new ResidueData("VLL", 12, 20), // 1211
        new ResidueData("VLM", 12, 20), // 1212
        new ResidueData("VME", 12, 20), // 1213
        new ResidueData("VMS", 12, 20), // 1214
        new ResidueData("VOL", 12, 20), // 1215
        new ResidueData("WFP", 12, 20), // 1216
        new ResidueData("X2W", 12, 20), // 1217
        new ResidueData("X97", 12, 20), // 1218
        new ResidueData("X98", 12, 20), // 1219
        new ResidueData("X99", 12, 20), // 1220
        new ResidueData("X9A", 12, 20), // 1221
        new ResidueData("X9Q", 12, 20), // 1222
        new ResidueData("XCP", 12, 20), // 1223
        new ResidueData("XLI", 12, 20), // 1224
        new ResidueData("XPC", 12, 20), // 1225
        new ResidueData("XX1", 12, 20), // 1226
        new ResidueData("XXY", 12, 20), // 1227
        new ResidueData("XYG", 12, 20), // 1228
        new ResidueData("Y28", 12, 20), // 1229
        new ResidueData("YCM", 12, 20), // 1230
        new ResidueData("YCP", 12, 20), // 1231
        new ResidueData("YEN", 12, 20), // 1232
        new ResidueData("YNM", 12, 20), // 1233
        new ResidueData("YOF", 12, 20), // 1234
        new ResidueData("Z70", 12, 20), // 1235
        new ResidueData("ZAE", 12, 20), // 1236
        new ResidueData("ZAL", 12, 20), // 1237
        new ResidueData("ZFB", 12, 20), // 1238
        new ResidueData("ZUK", 12, 20), // 1239
        new ResidueData("ZZD", 12, 20), // 1240
        new ResidueData("ZZJ", 12, 20), // 1241
        new ResidueData("ZZU", 12, 20)  // 1242
    };

    private static Color[] _aminoColors = new Color[]
    {
        new Color(230,  10,  10), // Bright Red
        new Color(230, 230,   0), // Yellow
        new Color( 20,  90, 255), // Blue
        new Color(250, 150,   0), // Orange
        new Color( 50,  50, 170), // Mid Blue
        new Color(  0, 220, 220), // Cyan
        new Color(235, 235, 235), // Light Grey
        new Color( 15, 130,  15), // Green
        new Color(200, 200, 200), // Dark Grey
        new Color(180,  90, 180), // Purple
        new Color(130, 130, 210), // Pale Blue
        new Color(220, 150, 130), // Flesh
        new Color(190, 160, 110)  // Tan
    };

    private static Color[] _shapelyColors = new Color[]
    {
        new Color(140, 255, 140), // Medium Green
        new Color(255, 255, 255), // White
        new Color( 69,  94,  69), // Olive Green
        new Color(255, 112,  66), // Medium Orange
        new Color(255, 140, 255), // Light Purple
        new Color(184,  76,   0), // Dark Orange
        new Color( 71,  71, 184), // Royal Blue
        new Color(160,   0,  66), // Dark Rose
        new Color(  0,  76,   0), // Dark Green
        new Color(255, 124, 112), // Light Salmon
        new Color(102,   0,   0), // Dark Brown
        new Color( 82,  82,  82), // Dark Grey
        new Color(  0,   0, 124), // Dark Blue
        new Color( 83,  76,  66), // Olive Grey
        new Color(255,  76,  76), // Dark Salmon
        new Color(140, 112,  76), // Medium Brown
        new Color(112, 112, 255), // Medium Blue
        new Color(255, 255, 112), // Medium Yellow
        new Color(184, 160,  66), // Light Brown
        new Color( 79,  70,   0), // Olive Brown
        new Color(255,   0, 255), // Medium Purple
        new Color(160, 160, 255), // Light Blue
        new Color(255, 140,  75), // Light Orange
        new Color(255, 112, 112), // Medium Salmon
        new Color(160, 255, 160), // Light Green
        new Color(184, 184, 184), // Light Grey
        new Color( 94,   0,  94), // Dark Purple
        new Color(255,   0, 255)  // Medium Purple
    };

    private ResidueTable()
    {
    }

    /**
     * Returns the number of residues registered.
     */
    public static int counts()
    {
        return _residues.length;
    }

    /**
     * Returns the index of the specified residue name.
     */
    public static int getIndex(String residueName)
    {
        String name = fixIrregularName(residueName.toUpperCase());

        for(int i=0; i<_residues.length; i++){
            if( name.equals(_residues[i].name) ) return i;
        }
        return INDEX_OTHER;
    }

    /**
     * Returns the index of the specified residue name.
     */
    public static int getIndexVer3(String residueName) {
        String name = residueName.toUpperCase();
        
        for (int i = 0; i <=24; i++) {
            if (name.equals(_residues[i].name)) {
                return i;
            }
        }
        for (int i = 44; i <=44; i++) {
            if (name.equals(_residues[i].name)) {
                return i;
            }
        }
        for (int i = 47; i <=1242; i++) {
            if (name.equals(_residues[i].name)) {
                return i;
            }
        }
        return INDEX_OTHER;
    }

    /**
     * Returns the name of the specified residue.
     */
    public static String getName(int index)
    {
        return _residues[index].name;
    }

    /**
     * Returns the amino color of the specified residue.
     */
    public static Color getAminoColor(int index)
    {
        return _aminoColors[_residues[index].aminoColorIndex];
    }

    /**
     * Returns the shapely color of the specified residue.
     */
    public static Color getShapelyColor(int index)
    {
        return _shapelyColors[_residues[index].shapelyColorIndex];
    }

    /**
     * Tests whether the specified residue has the specified property.
     */
    public static boolean hasProperty(int index, int property)
    {
        switch(property)
        {
            case PROP_ACIDIC :
            case PROP_NEGATIVE :
                return ( index == INDEX_ASP || 
                         index == INDEX_GLU    );

            case PROP_ACYCLIC :
                return ( isInGroup(index, GROUP_AMINO_20) && 
                         !hasProperty(index, PROP_CYCLIC)    );

            case PROP_ALIPHATIC :
                return ( index == INDEX_ALA || 
                         index == INDEX_GLY ||
                         index == INDEX_ILE ||
                         index == INDEX_LEU ||
                         index == INDEX_VAL    );

            case PROP_AROMATIC :
                return ( index == INDEX_HIS || 
                         index == INDEX_PHE ||
                         index == INDEX_TRP ||
                         index == INDEX_TYR    );

            case PROP_BASIC :
            case PROP_POSITIVE :
                return ( index == INDEX_ARG || 
                         index == INDEX_HIS ||
                         index == INDEX_LYS    );

            case PROP_BURIED :
                return ( index == INDEX_ALA || 
                         index == INDEX_CYS ||
                         index == INDEX_ILE ||
                         index == INDEX_LEU ||
                         index == INDEX_MET ||
                         index == INDEX_PHE ||
                         index == INDEX_TRP ||
                         index == INDEX_VAL    );

            case PROP_CHARGED :
                return ( hasProperty(index, PROP_ACIDIC) || 
                         hasProperty(index, PROP_BASIC)    );

            case PROP_CYCLIC :
                return ( index == INDEX_HIS || 
                         index == INDEX_PHE ||
                         index == INDEX_PRO ||
                         index == INDEX_TRP ||
                         index == INDEX_TYR    );

            case PROP_HYDROPHOBIC :
                return ( index == INDEX_ALA || 
                         index == INDEX_GLY ||
                         index == INDEX_ILE ||
                         index == INDEX_LEU ||
                         index == INDEX_MET ||
                         index == INDEX_PHE ||
                         index == INDEX_PRO ||
                         index == INDEX_TRP ||
                         index == INDEX_TYR ||
                         index == INDEX_VAL    );

            case PROP_LARGE :
                return ( isInGroup(index, GROUP_AMINO_20) && 
                         !hasProperty(index, PROP_MEDIUM) &&
                         !hasProperty(index, PROP_SMALL)     );

            case PROP_MEDIUM :
                return ( index == INDEX_ASN || 
                         index == INDEX_ASP ||
                         index == INDEX_CYS ||
                         index == INDEX_PRO ||
                         index == INDEX_THR ||
                         index == INDEX_VAL    );

            case PROP_NEUTRAL :
                return ( isInGroup(index, GROUP_AMINO_20) && 
                         !hasProperty(index, PROP_CHARGED)    );

            case PROP_POLAR :
                return ( isInGroup(index, GROUP_AMINO_20) && 
                         !hasProperty(index, PROP_HYDROPHOBIC) );

            case PROP_SMALL :
                return ( index == INDEX_ALA || 
                         index == INDEX_GLY    );

            case PROP_SURFACE :
                return ( isInGroup(index, GROUP_AMINO_20) && 
                         !hasProperty(index, PROP_BURIED)    );

            default :
                return false;
        }
    }

    /**
     * Tests whether the specified residue belongs to the specified group.
     */
    public static boolean isInGroup(int index, int group)
    {
        switch(group)
        {
            case GROUP_AMINO_20 :
                return (index >= 1 && index <= 20);

            case GROUP_AMINO :
                return (index >= 1 && index <= 24 ||
                        index >= 415 && index <= 1242);

            case GROUP_PROTEIN :
                return (index >= 1 && index <= 24 ||
                        index >= 44 && index <= 46 ||
                        index >= 415 && index <= 1242);

            case GROUP_NUCLEOTIDE :
                return (index >= 25 && index <= 43)
                    || (index >= 55 && index <= 414);

            case GROUP_DNA :
                return (index >= 25 && index <= 28)
                    || (index >= 55 && index <= 58)
                    || (index >= 63 && index <= 275);

            case GROUP_RNA :
                return (index >= 25 && index <= 43 && index != 28)
                    || (index >= 59 && index <= 62)
                    || (index >= 276 && index <= 414);

            case GROUP_SOLVENT :
                return (index >= 47 && index <= 50);

            case GROUP_WATER :
                return (index >= 47 && index <= 48);

            case GROUP_ION :
                return (index >= 49 && index <= 50);

            case GROUP_COENZYME :
                return (index >= 51 && index <= 54);

            default :
                return false;
        }        
    }

    /**
     * Tests whether the specified residue is adenine in DNA.
     */
    public static boolean isDNA_A(int index) {
        return (index == INDEX_A || index == INDEX_V3_DA);
    }
    
    /**
     * Tests whether the specified residue is cytosine in DNA.
     */
    public static boolean isDNA_C(int index) {
        return (index == INDEX_C || index == INDEX_V3_DC);
    }
    
    /**
     * Tests whether the specified residue is guanine in DNA.
     */
    public static boolean isDNA_G(int index) {
        return (index == INDEX_G || index == INDEX_V3_DG);
    }
    
    /**
     * Tests whether the specified residue is thymine in DNA.
     */
    public static boolean isDNA_T(int index) {
        return (index == INDEX_T || index == INDEX_V3_DT);
    }
    
    /**
     * Tests whether the specified residue is adenine in RNA.
     */
    public static boolean isRNA_A(int index) {
        return (index == INDEX_A || index == INDEX_V3_A);
    }
    
    /**
     * Tests whether the specified residue is cytosine in RNA.
     */
    public static boolean isRNA_C(int index) {
        return (index == INDEX_C || index == INDEX_V3_C);
    }
    
    /**
     * Tests whether the specified residue is guanine in RNA.
     */
    public static boolean isRNA_G(int index) {
        return (index == INDEX_G || index == INDEX_V3_G);
    }
    
    /**
     * Tests whether the specified residue is uracil in RNA.
     */
    public static boolean isRNA_U(int index) {
        return (index == INDEX_U || index == INDEX_V3_U);
    }
    
    //--------------------------------------------------------------------
    // fix irregular names
    //--------------------------------------------------------------------
    private static String fixIrregularName(String name)
    {
        if( name.equals("ADE") ){
            return "  A";
        }
        else if( name.equals("CYH") ||
                 name.equals("CSH") ||
                 name.equals("CSM") )
        {
            return "CYS";
        }
        else if( name.equals("CYT") ){
            return "  C";
        }
        else if( name.equals("CPR") ){
            return "PRO";
        }
        else if( name.equals("D2O") ){
            return "DOD";
        }
        else if( name.equals("GUA") ){
            return "  G";
        }
        else if( name.equals("H2O") ||
                 name.equals("SOL") ||
                 name.equals("TIP") ||
                 name.equals("WAT") )
        {
            return "HOH";
        }
        else if( name.equals("SUL") ){
            return "SO4";
        }
        else if( name.equals("THY") ){
            return "  T";
        }
        else if( name.equals("TRY") ){
            return "TRP";
        }
        else if( name.equals("URA") ||
                 name.equals("URI") )
        {
            return "  U";
        }
        else{
            return name;
        }
    }
}
