/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.utils;

/**
 * Four dimensional matrix.
 */
public class Matrix4f
{
    /**
     * (1,1) element.
     */
    public float m11;

    /**
     * (1,2) element.
     */
    public float m12;

    /**
     * (1,3) element.
     */
    public float m13;

    /**
     * (1,4) element.
     */
    public float m14;

    /**
     * (2,1) element.
     */
    public float m21;

    /**
     * (2,2) element.
     */
    public float m22;

    /**
     * (2,3) element.
     */
    public float m23;

    /**
     * (2,4) element.
     */
    public float m24;

    /**
     * (3,1) element.
     */
    public float m31;

    /**
     * (3,2) element.
     */
    public float m32;

    /**
     * (3,3) element.
     */
    public float m33;

    /**
     * (3,4) element.
     */
    public float m34;

    /**
     * (4,1) element.
     */
    public float m41;

    /**
     * (4,2) element.
     */
    public float m42;

    /**
     * (4,3) element.
     */
    public float m43;

    /**
     * (4,4) element.
     */
    public float m44;

    /**
     * Returns true if all elements of this matrix are equal to the corresponding 
     * elements in matrix m1.
     */
    public boolean equals(Matrix4f m1)
    {
        return
        (
            m11 == m1.m11 && m12 == m1.m12 && m13 == m1.m13 && m14 == m1.m14 && 
            m21 == m1.m21 && m22 == m1.m22 && m23 == m1.m23 && m24 == m1.m24 &&
            m31 == m1.m31 && m32 == m1.m32 && m33 == m1.m33 && m34 == m1.m34 &&
            m41 == m1.m41 && m42 == m1.m42 && m43 == m1.m43 && m44 == m1.m44
        );
    }

    /**
     * Returns an identity matrix.
     */
    public static Matrix4f identity()
    {
        Matrix4f m = new Matrix4f();

        m.m11 = m.m22 = m.m33 = m.m44 = 1;

        return m;
    }

    /**
     * Sets this matrix to a matrix multiplication of matrices m1 and m2.
     */
    public void multiply(Matrix4f m1, Matrix4f m2)
    {
        float t11 = m1.m11 * m2.m11 + m1.m12 * m2.m21 + m1.m13 * m2.m31 + m1.m14 * m2.m41;
        float t12 = m1.m11 * m2.m12 + m1.m12 * m2.m22 + m1.m13 * m2.m32 + m1.m14 * m2.m42;
        float t13 = m1.m11 * m2.m13 + m1.m12 * m2.m23 + m1.m13 * m2.m33 + m1.m14 * m2.m43;
        float t14 = m1.m11 * m2.m14 + m1.m12 * m2.m24 + m1.m13 * m2.m34 + m1.m14 * m2.m44;

        float t21 = m1.m21 * m2.m11 + m1.m22 * m2.m21 + m1.m23 * m2.m31 + m1.m24 * m2.m41;
        float t22 = m1.m21 * m2.m12 + m1.m22 * m2.m22 + m1.m23 * m2.m32 + m1.m24 * m2.m42;
        float t23 = m1.m21 * m2.m13 + m1.m22 * m2.m23 + m1.m23 * m2.m33 + m1.m24 * m2.m43;
        float t24 = m1.m21 * m2.m14 + m1.m22 * m2.m24 + m1.m23 * m2.m34 + m1.m24 * m2.m44;

        float t31 = m1.m31 * m2.m11 + m1.m32 * m2.m21 + m1.m33 * m2.m31 + m1.m34 * m2.m41;
        float t32 = m1.m31 * m2.m12 + m1.m32 * m2.m22 + m1.m33 * m2.m32 + m1.m34 * m2.m42;
        float t33 = m1.m31 * m2.m13 + m1.m32 * m2.m23 + m1.m33 * m2.m33 + m1.m34 * m2.m43;
        float t34 = m1.m31 * m2.m14 + m1.m32 * m2.m24 + m1.m33 * m2.m34 + m1.m34 * m2.m44;

        float t41 = m1.m41 * m2.m11 + m1.m42 * m2.m21 + m1.m43 * m2.m31 + m1.m44 * m2.m41;
        float t42 = m1.m41 * m2.m12 + m1.m42 * m2.m22 + m1.m43 * m2.m32 + m1.m44 * m2.m42;
        float t43 = m1.m41 * m2.m13 + m1.m42 * m2.m23 + m1.m43 * m2.m33 + m1.m44 * m2.m43;
        float t44 = m1.m41 * m2.m14 + m1.m42 * m2.m24 + m1.m43 * m2.m34 + m1.m44 * m2.m44;

        m11 = t11;  m12 = t12;  m13 = t13;  m14 = t14;
        m21 = t21;  m22 = t22;  m23 = t23;  m24 = t24;
        m31 = t31;  m32 = t32;  m33 = t33;  m34 = t34;
        m41 = t41;  m42 = t42;  m43 = t43;  m44 = t44;
    }

    /**
     * Sets this matrix to a rotation matrix around the x axis.
     */
    public void rotationX(float angle)
    {
        float sin = (float)Math.sin(angle);
        float cos = (float)Math.cos(angle);

        m11 = 1;  m12 =   0;  m13 =    0;  m14 = 0;
        m21 = 0;  m22 = cos;  m23 = -sin;  m24 = 0;
        m31 = 0;  m32 = sin;  m33 =  cos;  m34 = 0;
        m41 = 0;  m42 =   0;  m43 =    0;  m44 = 1;
    }

    /**
     * Sets this matrix to a rotation matrix around the y axis.
     */
    public void rotationY(float angle)
    {
        float sin = (float)Math.sin(angle);
        float cos = (float)Math.cos(angle);

        m11 =  cos;  m12 = 0;  m13 = sin;  m14 = 0;
        m21 =    0;  m22 = 1;  m23 =   0;  m24 = 0;
        m31 = -sin;  m32 = 0;  m33 = cos;  m34 = 0;
        m41 =    0;  m42 = 0;  m43 =   0;  m44 = 1;
    }

    /**
     * Sets this matrix to a rotation matrix around the z axis.
     */
    public void rotationZ(float angle)
    {
        float sin = (float)Math.sin(angle);
        float cos = (float)Math.cos(angle);

        m11 = cos;  m12 = -sin;  m13 = 0;  m14 = 0;
        m21 = sin;  m22 =  cos;  m23 = 0;  m24 = 0;
        m31 =   0;  m32 =    0;  m33 = 1;  m34 = 0;
        m41 =   0;  m42 =    0;  m43 = 0;  m44 = 1;
    }

    /**
     * Sets this matrix to a scale matrix.
     */
    public void scale(float sx, float sy, float sz)
    {
        m11 = sx;  m12 =  0;  m13 =  0;  m14 = 0;
        m21 =  0;  m22 = sy;  m23 =  0;  m24 = 0;
        m31 =  0;  m32 =  0;  m33 = sz;  m34 = 0;
        m41 =  0;  m42 =  0;  m43 =  0;  m44 = 1;
    }

    /**
     * Sets this matrix to a copy of the passed matrix m1.
     */
    public void set(Matrix4f m1)
    {
        m11 = m1.m11;
        m12 = m1.m12;
        m13 = m1.m13;
        m14 = m1.m14;
        m21 = m1.m21;
        m22 = m1.m22;
        m23 = m1.m23;
        m24 = m1.m24;
        m31 = m1.m31;
        m32 = m1.m32;
        m33 = m1.m33;
        m34 = m1.m34;
        m41 = m1.m41;
        m42 = m1.m42;
        m43 = m1.m43;
        m44 = m1.m44;
    }
    
    /**
     * Sets this matrix to an identity matrix.
     */
    public void setIdentity()
    {
        m11 = 1;  m12 = 0;  m13 = 0;  m14 = 0;
        m21 = 0;  m22 = 1;  m23 = 0;  m24 = 0;
        m31 = 0;  m32 = 0;  m33 = 1;  m34 = 0;
        m41 = 0;  m42 = 0;  m43 = 0;  m44 = 1;
    }

    /**
     * Sets this matrix to a translate matrix.
     */
    public void translation(float x, float y, float z)
    {
        m11 = 1;  m12 = 0;  m13 = 0;  m14 = x;
        m21 = 0;  m22 = 1;  m23 = 0;  m24 = y;
        m31 = 0;  m32 = 0;  m33 = 1;  m34 = z;
        m41 = 0;  m42 = 0;  m43 = 0;  m44 = 1;
    }

    /**
     * Sets this matrix to a translate matrix.
     */
    public void translation(Vector3f v1)
    {
        m11 = 1;  m12 = 0;  m13 = 0;  m14 = v1.x;
        m21 = 0;  m22 = 1;  m23 = 0;  m24 = v1.y;
        m31 = 0;  m32 = 0;  m33 = 1;  m34 = v1.z;
        m41 = 0;  m42 = 0;  m43 = 0;  m44 =    1;
    }
}
