/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.utils;

import java.util.*;

/**
 * Represents XML node for SAX parsing.
 */
public class SAXNode
{
    private String    _localName;
    private SAXNode   _parent;
    private ArrayList _children;

    /**
     * Returns the local name.
     */
    public String getLocalName()
    {
        return _localName;
    }

    /**
     * Sets the parent node.
     */
    public void setParent(SAXNode parent)
    {
        _parent = parent;
    }

    /**
     * Returns the parent node.
     */
    public SAXNode getParent()
    {
        return _parent;
    }

    /**
     * Returns the children.
     */
    public ArrayList getChildren()
    {
        return _children;
    }

    /**
     * Constructor.
     */
    public SAXNode(String localName)
    {
        _localName = localName;
        _children = new ArrayList();
    }

    /**
     * Creates a child specified by its name and returns it.
     */
    public SAXNode createChild(String localName)
    {
        SAXNode child = this.getChild(localName);

        if(child == null){
            child = new SAXNode(localName);
            child.setParent(this);
            _children.add(child);
        }

        return child;
    }

    /**
     * Creates a node specified by its path and returns it.
     */
    public SAXNode createNode(String localNamePath)
    {
        StringTokenizer st = new StringTokenizer(localNamePath, "/");
        
        SAXNode curr = this;
        while( st.hasMoreTokens() )
        {
            curr = curr.createChild( st.nextToken() );
        }
        return curr;
    }

    /**
     * Returns the child specified by name.
     */
    public SAXNode getChild(String localName)
    {
        for(int i=0; i<_children.size(); i++)
        {
            SAXNode child = (SAXNode)_children.get(i);
            if( child.getLocalName().equals(localName) ) return child;
        }
        return null;
    }
}
