/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.utils;

import java.util.*;

/**
 * Handles XML node tree for SAX parsing.
 */
public class SAXNodeHandler
{
    private SAXNode _rootNode;
    private SAXNode _currNode;

    private ArrayList _nodeList;
    private boolean   _tracing;
    private int       _restartDepth;

    /**
     * Returns the current node.
     */
    public SAXNode getCurrentNode()
    {
        return _tracing ? _currNode : null;
    }

    /**
     * Constructor.
     */
    public SAXNodeHandler(SAXNode rootNode)
    {
        _rootNode = rootNode;
        _nodeList = new ArrayList();

        this.initialize();
    }

    /**
     * Initialize.
     */
    public void initialize()
    {
        _nodeList.clear();
        _currNode = null;
        _tracing = false;
        _restartDepth = -1;
    }

    /**
     * Enters into a node.
     */
    public void enter(String localName)
    {
        _nodeList.add(localName);

        if(_currNode == null && localName.equals(_rootNode.getLocalName()) )
        {
            _currNode = _rootNode;
            _tracing = true;
        }
        else if(_tracing)
        {
            SAXNode node = _currNode.getChild(localName);
            if(node != null){
                _currNode = node;
            }
            else{
                _tracing = false;
                _restartDepth = _nodeList.size() - 1;
            }
        }
    }

    /**
     * Leaves a node.
     */
    public void leave()
    {
        _nodeList.remove(_nodeList.size()-1);

        if(_tracing){
            _currNode = _currNode.getParent();
        }
        else if(_nodeList.size() == _restartDepth){
            _tracing = true;
        }
    }
}
