/*
* Binary and Source Code License Agreement for jV Version 4.3.1
* Copyright (c) 2003-2013, Protein Data Bank Japan
* All rights reserved.
* 
* The software, jV, and the associated documentation files (the 
* "Software") were developed by Drs. Kengo Kinoshita and Haruki Nakamura 
* in Protein Data Bank Japan at Institute for Protein Research, Osaka 
* University (the "Contributors"), which is supported by grant-in-aid 
* from National Bioscience Database Center, Japan Science and Technology
* Agancy (JST-NBDC) and Osaka University.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions 
* are met:
* 
* *  Redistributions of the source code for the Software must retain the
*    above copyright notice, this list of conditions and the following
*    disclaimer.
* 
* *  Redistributions in the binary form for the Software must reproduce
*    the above copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials provided with
*    the distribution.
* 
* *  Neither the name of the Institute for Protein Research, Osaka University
*    nor the names of the Contributors may be used to endorse or promote
*    products derived from this software without specific prior written
*    permission.
* 
*    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
*    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
*    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
*    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
*    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
*    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
*    POSSIBILITY OF SUCH DAMAGE.
*/
package org.pdbj.viewer.utils;

/**
 * Class that determines the center and radius of multiple spheres.
 */
public class SphereUtil
{
    private Vector3f _center;
    private float    _radius;
    private boolean  _first;

    /**
     * Constructor.
     */
    public SphereUtil()
    {
        this.Clear();
    }

    /**
     * Initializes.
     */
    public void Clear()
    {
        _center = new Vector3f();
        _radius = 0;

        _first = true;
    }

    /**
     * Adds sphere.
     */
    public void addSphere(Vector3f center, float radius)
    {
        if(_first){
            _center.set(center);
            _radius = radius;
            _first = false;
            return;
        }

        Vector3f dir = new Vector3f();
        dir.sub(center, _center);

        float d = dir.length();
        if(d == 0){
            if(radius > _radius) _radius = radius;
            return;
        }

        dir.multiply(1/d); // normalize

        float r1 = (d + radius > _radius) ? d + radius : _radius;
        float r2 = (d + _radius > radius) ? d + _radius : radius;

        Vector3f edge1 = new Vector3f();
        Vector3f edge2 = new Vector3f();
        Vector3f v = new Vector3f();

        v.multiply( r1, dir); edge1.add(_center, v);
        v.multiply(-r2, dir); edge2.add( center, v);

        v.add(edge1,  edge2);  _center.multiply(0.5f, v);
        v.sub(edge1, _center); _radius = v.length();
    }

    /**
     * Adds sphere.
     * The w component of the vector center is ignored.
     */
    public void addSphere(Vector4f center, float radius)
    {
        Vector3f v = new Vector3f(center.x, center.y, center.z);
        this.addSphere(v, radius);
    }

    /**
     * Returns the current sphere.
     */
    public Sphere getSphere()
    {
        return new Sphere(_center, _radius);
    }
}
